@@ -9,6 +9,15 @@ int main() { return 0; }
 
 //-------------------------------------
 
+#ifdef VCL_HAS_LONG_LONG
+
+void function(int i, void *ptr, long long v) {}
+
+int main() { return 0; }
+#endif // VCL_HAS_LONG_LONG
+
+//-------------------------------------
+
 #ifdef VCL_HAS_TYPENAME
 
 template <typename T>
@@ -1039,9 +1048,13 @@ double cast( THE_TYPE a )
 }
 #endif // INTEGRAL_TYPE
 
+// These declarations conflict unless the sizes match.
+extern int (*verify_size)[sizeof(THE_TYPE) * CHAR_BIT];
+extern int (*verify_size)[THE_SIZE];
+
 int main()
 {
-  return sizeof(THE_TYPE) * CHAR_BIT == THE_SIZE ? 0 : 1;
+  return 0;
 }
 
 #endif // VXL_HAS_TYPE_OF_SIZE
