@@ -91,9 +91,9 @@ bgui3d_viewer_tableau::set_scene_root(SoNode* scene_root)
   trans->translation = SbVec3f(-.98f,.93f,0);
   super_root->addChild( trans );
 
-  _text = new SoText2;
-  _text->string.deleteValues(0, -1); // empty the string
-  super_root->addChild( _text );
+  text_ = new SoText2;
+  text_->string.deleteValues(0, -1); // empty the string
+  super_root->addChild( text_ );
 
   //: Make a group of all the cameras in the scene
   camera_group_ = new SoSwitch;
@@ -365,7 +365,7 @@ bgui3d_viewer_tableau::toggle_camera_type()
 void
 bgui3d_viewer_tableau::view_all()
 {
-    scene_camera_->viewAll( user_scene_root_, get_viewport_region() );
+  scene_camera_->viewAll( user_scene_root_, get_viewport_region() );
 }
 
 
@@ -421,7 +421,7 @@ bgui3d_viewer_tableau::reset_to_home_position()
     camera_type_ = PERSPECTIVE;
   }
   // otherwise, cameras have changed in ways we don't understand since
-  // the last saveHomePosition() invokation, and so we're just going
+  // the last saveHomePosition() invocation, and so we're just going
   // to ignore the reset request
 }
 
@@ -456,16 +456,16 @@ bgui3d_viewer_tableau::headlight() const
 
 //-------------Text2 Methods-------------------
 
-static void setTextCallback( void *data, SoSensor *sensor )
+static void setTextCallback( void *data, SoSensor * /*sensor*/ )
 {
   ((SoText2*)data)->string.deleteValues(0, 1);
 }
 
 void bgui3d_viewer_tableau::setText( const vcl_string& string )
 {
-  int numStrings = _text->string.getNum();
-  _text->string.set1Value( numStrings, string.c_str() );
-  SoAlarmSensor* alarm = new SoAlarmSensor( setTextCallback, _text );
+  int numStrings = text_->string.getNum();
+  text_->string.set1Value( numStrings, string.c_str() );
+  SoAlarmSensor* alarm = new SoAlarmSensor( setTextCallback, text_ );
   alarm->setTimeFromNow( 7.0 );
   alarm->schedule();
 }
@@ -590,8 +590,8 @@ bgui3d_viewer_tableau::set_clipping_planes()
       glGetIntegerv(GL_DEPTH_BITS, depthbits);
 #endif // 0
 
-      int use_bits = (int) (float(depthbits[0]) * (0.4f));
-      float r = (float) vcl_pow(2.0, (double) use_bits);
+      int use_bits = (int) (float(depthbits[0]) * 0.4f + 0.001f);
+      float r = (float)(1 << use_bits);
       nearlimit = farval / r;
 #if 0
     }
@@ -606,7 +606,7 @@ bgui3d_viewer_tableau::set_clipping_planes()
       nearlimit = farval / 5000.0f;
     }
 
-    // adjust the near plane if the the value is too small.
+    // adjust the near plane if the value is too small.
     if (nearval < nearlimit) {
       nearval = nearlimit;
     }
@@ -626,8 +626,8 @@ bgui3d_viewer_tableau::set_clipping_planes()
   }
   // Some slack around the bounding box, in case the scene fits
   // exactly inside it. This is done to minimize the chance of
-  // artifacts caused by the limitation of the z-buffer
-  // resolution. One common artifact if this is not done is that the
+  // artefacts caused by the limitation of the z-buffer
+  // resolution. One common artefact if this is not done is that the
   // near clipping plane cuts into the corners of the model as it's
   // rotated.
   const float SLACK = 0.001f;
