@@ -1,6 +1,7 @@
+#include <bil/algo/bil_blob_finder.h>
 #include <bil/algo/bil_cedt.h>
-#include <bil/algo/bil_compass_edge_detector.h>
 #include <bil/algo/bil_color_conversions.h>
+#include <bil/algo/bil_compass_edge_detector.h>
 #include <bil/algo/bil_detect_ridges.h>
 #include <bil/algo/bil_edge_indicator.h>
 #include <bil/algo/bil_edt.h>
@@ -12,6 +13,8 @@
 #include <bil/algo/bil_perform_tensor_decomposition.h>
 #include <bil/algo/bil_roi_mask.h>
 #include <bil/algo/bil_scale_image.h>
+#include <bil/algo/bil_trace_4con_boundary.h>
+#include <bil/algo/bil_trace_8con_boundary.h>
 #include <bil/algo/bil_wshed2d.h>
 
 int main() { return 0; }
