@@ -14,6 +14,8 @@
 //
 //-------------------------------------------------------------------------
 
+#include <bmsh3d/bmsh3d_vertex.h>
+#include <bmsh3d/bmsh3d_edge.h>
 #include <vcl_cassert.h>
 #include <vcl_iostream.h>
 
