@@ -4,6 +4,8 @@
 #include <vbl/vbl_smart_ptr.h>
 
 class bsta_joint_histogram_base;
+typedef vbl_smart_ptr<bsta_joint_histogram_base> bsta_joint_histogram_base_sptr;
+//shorter notation
 typedef vbl_smart_ptr<bsta_joint_histogram_base> bsta_joint_histogram_sptr;
 
 #endif
