@@ -14,13 +14,18 @@
 
 #include <bsta/bsta_attributes.h>
 #include <vsl/vsl_binary_io.h>
+#include <vcl_iostream.h>
 
 //: Binary save bsta_attributes to stream.
 template <class comp_>
 void
 vsl_b_write(vsl_b_ostream &os, const bsta_num_obs<comp_>& m)
 {
-  vsl_b_write(os,static_cast<comp_>(m));
+  comp_ n=static_cast<comp_>(m);
+
+  //vcl_cout<<sizeof(n)<<' '<<sizeof(m)<<':';
+  vsl_b_write(os,n);
+  //vsl_b_write(os,(int)1);
   vsl_b_write(os,m.num_observations);
 }
 
@@ -31,6 +36,7 @@ vsl_b_read(vsl_b_istream &is, bsta_num_obs<comp_>& m)
 {
   comp_ dstrb;
   vsl_b_read(is,dstrb);
+  // int a; vsl_b_read(is,a);
   m = bsta_num_obs<comp_>(dstrb);
   vsl_b_read(is,m.num_observations);
 }
