@@ -4,17 +4,19 @@
 #include <vcl_cmath.h>
 #include <bsta/bsta_histogram.h>
 #include <bsta/bsta_joint_histogram.h>
+#include <bsta/bsta_joint_histogram_3d.h>
 #include <bsta/bsta_int_histogram_1d.h>
 #include <bsta/bsta_int_histogram_2d.h>
 #include <vpl/vpl.h>
 #include <vcl_iostream.h>
+#include <vcl_fstream.h>
 #include <bsta/io/bsta_io_histogram.h>
 #include <vsl/vsl_binary_io.h>
 
 #include <bsta/bsta_histogram_sptr.h>
 #include <bsta/bsta_joint_histogram_sptr.h>
 
-#include <bsta/bsta_gauss_f1.h>
+#include <bsta/bsta_gauss_sf1.h>
 
 static void test_int_hist()
 {
@@ -93,7 +95,7 @@ void test_bsta_histogram()
     jh.avg_and_variance_bin_for_row_a(a, avg, var);
     vcl_cout << "avg: " << avg << " var: " << var << vcl_endl;
 
-    bsta_gauss_f1 g(static_cast<float>(avg), static_cast<float>(var));
+    bsta_gauss_sf1 g(static_cast<float>(avg), static_cast<float>(var));
     for (int b = 0; b < bins; b++) {
       float b_val = g.prob_density(static_cast<float>((b+1)*delta));
       new_jh.upcount(static_cast<float>((a+1)*delta), 0.0f, static_cast<float>((b+1)*delta), b_val);
@@ -117,77 +119,48 @@ void test_bsta_histogram()
   double pv = jh_m.p(0.0, 0.0);
   double pb = jh_m.p(r0, c0);
   TEST_NEAR("test min, max joint histogram ", (vol-1.0)+(pv-pb), 0.0, 0.0001);
- //=================================================
-  // test binary io for histogram classes
-  // 1-d histogram
-  double nbinsd = h.nbins();
-  double cn = h.counts(3);
-  double max = h.max();
-  vsl_b_ofstream os("./temp.bin");
-  vsl_b_write(os, h);
-  os.close();
-  vsl_b_ifstream is("./temp.bin");
-  bsta_histogram<double> h_in;
-  vsl_b_read(is, h_in);
-  double nbins_in = h_in.nbins();
-  double max_in = h_in.max();
-  double cn_in = h_in.counts(3);
-  double error = vcl_fabs(nbins_in-nbinsd)+
-    vcl_fabs(max-max_in)+vcl_fabs(cn-cn_in);
-  TEST_NEAR("histogram binary io", error, 0.0, 0.001);
-  vpl_unlink("./temp.bin");
-
-  vsl_b_ofstream sos("./sptr_temp.bin");
-  bsta_histogram_sptr hptr = new bsta_histogram<double>(h);
-  vsl_b_write(sos, hptr);
-  sos.close();
-  vsl_b_ifstream sis("./sptr_temp.bin");
-  bsta_histogram_sptr hptr_in = 0;
-  vsl_b_read(sis, hptr_in);
-  TEST("histogram sptr read", hptr_in!=0, true);
-  if (hptr_in!=0) {
-    bsta_histogram<double>* hp =
-      static_cast<bsta_histogram<double>*>(hptr_in.ptr());
-    nbins_in = hp->nbins();
-    max_in = hp->max();
-    cn_in = hp->counts(3);
-    error = vcl_fabs(nbins_in-nbinsd)+
-      vcl_fabs(max-max_in)+vcl_fabs(cn-cn_in);
-    TEST_NEAR("histogram pointer binary io", error, 0.0, 0.001);
-  }
-  vpl_unlink("./sptr_temp.bin");
-  // joint histogram
-  double nbinsjd = jh.nbins();
-  unsigned ia= 1, ib = 1;
-  double pj = jh.p(ia,ib);
-  double rangej = jh.range();
-  vsl_b_ofstream jos("./temp.bin");
-  vsl_b_write(jos, jh);
-  jos.close();
-
-  vsl_b_ifstream jis("./temp.bin");
-  bsta_joint_histogram<double> jh_in;
-  vsl_b_read(jis, jh_in);
-  double nbinsj_in = jh_in.nbins();
-  double rangej_in = jh_in.range();
-  double pj_in = jh_in.p(ia,ib);
-  double jerror = vcl_fabs(nbinsj_in-nbinsjd)+
-    vcl_fabs(rangej-rangej_in)+vcl_fabs(pj-pj_in);
-
-  TEST_NEAR("joint_histogram binary io", jerror, 0.0, 0.001);
-  vpl_unlink("./temp.bin");
-
-  //: test vrml
-  vcl_ofstream jos_vrml("./temp.wrl");
-  jh.print_to_vrml(jos_vrml);
-  jos_vrml.close();
-  vpl_unlink("./temp.wrl");
 
   //Test smart pointer
-  hptr = new bsta_histogram<double>(10.0, 10);
+  bsta_histogram_sptr hptr = new bsta_histogram<double>(10.0, 10);
   bsta_histogram<double>* dcast = dynamic_cast<bsta_histogram<double>*>(hptr.ptr());
   bsta_histogram<float>* fcast = dynamic_cast<bsta_histogram<float>*>(hptr.ptr());
   TEST("dynamic cast histogram", dcast&&!fcast, true);
+
+  //Test Mutual Information
+  bsta_joint_histogram<double> joint_histogram_mi(2,2);
+  joint_histogram_mi.upcount(1,1,1,1);
+  joint_histogram_mi.upcount(1,3,2,3);
+  joint_histogram_mi.upcount(2,2,1,2);
+  joint_histogram_mi.upcount(2,4,2,4);
+  double mutual_information_error = joint_histogram_mi.mutual_information() - double(0.005802149014346);
+  TEST_NEAR("Mutual Information",mutual_information_error,0.0,0.0001);
+
+  // ---- test bsta_joint_histogram_3d
+  bsta_joint_histogram_3d<float> hist_default;
+  bsta_joint_histogram_3d<float> hist_cons1(1.0, 10);
+  bsta_joint_histogram_3d<float> hist_cons2(1.0, 10,
+                                            2.0, 20,
+                                            3.0, 30);
+  bsta_joint_histogram_3d<float> hist_cons3(0.0, 1.0, 10,
+                                            1.0, 2.0, 20,
+                                            2.0, 3.0, 30);
+  hist_cons3.upcount(0.5f, 1.0f, 1.5f,1.0f, 2.5f, 1.0f);
+  unsigned bina = 4, binb = 9, binc =14;
+  float pbin = hist_cons3.p(bina, binb, binc);
+  float bval = hist_cons3.p(0.5f, 1.5f, 2.5f);
+  float volume = hist_cons3.volume();
+  float err3d = pbin+bval+volume - 5.0f;
+  TEST_NEAR("3-d histogram", err3d, 0.0f, 0.00001f);
+  bsta_joint_histogram_3d<float> hist_3d(1.0, 10, 1.0, 10, 1.0, 10);
+  vcl_string hpath = "./test_3d_hist_plot.wrl";
+  hist_3d.upcount(0.5,1.0, 0.5,1.0, 0.5,1.0);
+  hist_3d.upcount(0.25,1.0, 0.25, 1.0, 0.25, 1.0);
+  vcl_ofstream os_3d(hpath.c_str());
+  if (os_3d.is_open()){
+    hist_3d.print_to_vrml(os_3d);
+    os_3d.close();
+    vpl_unlink("./test_3d_hist_plot.wrl");
+  }
 }
 
 TESTMAIN(test_bsta_histogram);
