@@ -8,6 +8,7 @@
 // \date April 22, 2009
 
 #include <vcl_iostream.h>
+#include <vcl_sstream.h>
 #include <bsta/bsta_histogram.h>
 #include <bsta/bsta_joint_histogram.h>
 #include <bxml/bsvg/bsvg_plot.h>
@@ -21,22 +22,38 @@ void write_svg(const bsta_histogram<T>& h, const vcl_string& outfile,
                float width = 600.0f, float height = 600.0f, float margin = 40.0f, int font_size = 30)
 {
   bsvg_plot pl(width, height);
-#if 0
-  pl.set_margin(margin);
-  pl.set_font_size(font_size);
-#endif
+  if (false) pl.set_margin(margin); // TODO
+  if (false) pl.set_font_size(font_size); // TODO
+  T min = h.min();
+  T max = h.max();
+  T delta = h.delta();
+  vcl_cout << "min: " << min << " max: " << max << vcl_endl;
+  T abs_min = T(10);
+  T abs_max = T(0);
+  for (unsigned a = 0; a < h.nbins(); a++) {
+    if (h.p(a) < min) abs_min = h.p(a);
+    if (h.p(a) > max) abs_max = h.p(a);
+  }
+  vcl_stringstream mss; mss << "abs min: " << abs_min << " max: " << abs_max;
+  vcl_stringstream mss2; mss2 << "ent: " << h.entropy();
+  bsvg_text* tmm = new bsvg_text(mss.str());
+  tmm->set_location(margin, margin);
+  pl.add_element(tmm);
+  bsvg_text* tmm2 = new bsvg_text(mss2.str());
+  tmm2->set_location(margin, margin+font_size);
+  pl.add_element(tmm2);
 
-  float min = float(h.min());
-  float delta = float(h.delta());
+  float minf = float(min);
+  float deltaf = float(delta);
 
   pl.add_axes(0, 1, 0, 1);
   pl.add_y_increments(0.1f);
 
   vcl_vector<float> ps;
   vcl_vector<float> x_labels;
-  for (unsigned i = 0; i < h.nbins(); ++i, min+=delta) {
+  for (unsigned i = 0; i < h.nbins(); ++i, minf+=deltaf) {
     ps.push_back(float(h.p(i)));
-    x_labels.push_back(min);
+    x_labels.push_back(minf);
   }
 
   pl.add_bars(ps, x_labels, true, "red");
@@ -97,7 +114,7 @@ void write_svg_angle_distance(const bsta_joint_histogram<T>& h, const vcl_string
   }
 
   for (float vala = (float)mina; vala < maxa; vala += delta_a) {
-    vcl_stringstream rs; rs << (int)(vala*180.0*vnl_math::one_over_pi);
+    vcl_stringstream rs; rs << (int)(vala*vnl_math::deg_per_rad);
     bsvg_text* t = new bsvg_text(rs.str());
     float radius = maxb*factor+font_size;
     t->set_location((float)(300.0f+(radius)*vcl_cos(vala+vnl_math::pi*0.01)), (float)(300.0f+(radius)*-vcl_sin(vala+vnl_math::pi*0.01)));
