@@ -13,14 +13,15 @@
 #include <brip/brip_roi.h>
 #include <brip/brip_vil_float_ops.h>
 #include <vtol/vtol_edge_2d_sptr.h>
-
+#include <vsol/vsol_box_2d.h>
 #include <vsol/vsol_box_2d_sptr.h>
 #include <vsol/vsol_line_2d_sptr.h>
 #include <vsol/vsol_digital_curve_2d_sptr.h>
 
 #include <vil/vil_image_resource.h>
 
-void bwm_image_processor::hist_plot(bgui_image_tableau_sptr img)
+void bwm_image_processor::hist_plot(bgui_image_tableau_sptr img,
+                                    vsol_polygon_2d_sptr p)
 {
   if (!img)
   {
@@ -35,7 +36,7 @@ void bwm_image_processor::hist_plot(bgui_image_tableau_sptr img)
     return;
   }
 
-  bgui_image_utils iu(res);
+  bgui_image_utils iu(res, p);
   bgui_graph_tableau_sptr g = iu.hist_graph();
 
   if (!g)
@@ -280,16 +281,13 @@ scan_regions(  bgui_image_tableau_sptr const& img,
 
   vcl_vector<vcl_vector<float > > temp(n_regions);
   float gmin, gmax;
-  for (unsigned r = 0; r< n_regions; ++r)
+  temp[0] = brip_vil_float_ops::scan_region(image, regions[0], gmin, gmax);
+  for (unsigned r = 1; r< n_regions; ++r)
   {
-    float min,  max;
-    vcl_vector<float> v =
-      brip_vil_float_ops::scan_region(image, regions[r], min, max);
-    temp[r]=v;
-    if (r == 0)
-    { gmin = min; gmax = max; }
-    else
-    { if (min<gmin) gmin = min; if (max>gmax) gmax = max; }
+    float min, max;
+    temp[r] = brip_vil_float_ops::scan_region(image, regions[r], min, max);
+    if (min<gmin) gmin = min;
+    if (max>gmax) gmax = max;
   }
 
   //make sure the lower bound is a multiple of 10
@@ -335,3 +333,29 @@ scan_regions(  bgui_image_tableau_sptr const& img,
   }
   delete ip_dialog;
 }
+
+bool bwm_image_processor::crop_to_box(bgui_image_tableau_sptr const& img,
+                                      vsol_box_2d_sptr const& roi,
+                                      vil_image_resource_sptr& chip)
+{
+  
+  vil_image_resource_sptr image = img->get_image_resource();
+  if (!image||!image->ni()||!image->nj())
+  {
+    vcl_cerr << "In bwm_observer_img::step_edges_vd() - no image\n";
+    return false;
+  }
+  double xmin = roi->get_min_x(), xmax = roi->get_max_x(),
+    ymin = roi->get_min_y(), ymax=roi->get_max_y();
+  vcl_cout << "croping subset of image(" << image->ni() << ' ' 
+           << image->nj() << ")->org(" << xmin << ' ' << ymin << "):size("
+           << xmax-xmin << ' ' << ymax-ymin << ")\n" << vcl_flush;
+  brip_roi_sptr roi_ptr = new brip_roi(image->ni(), image->nj());
+  roi_ptr->add_region(roi);
+  if (!brip_vil_float_ops::chip(image, roi_ptr, chip))
+  {
+    vcl_cout << "Crop operation failed\n";
+    return false;
+  }
+  return true;
+}
