@@ -9,6 +9,7 @@
 #include <vgui/vgui_range_map_params_sptr.h>
 
 #include <vsol/vsol_box_2d_sptr.h>
+#include <vsol/vsol_polygon_2d_sptr.h>
 #include <vsol/vsol_line_2d_sptr.h>
 #include <vsol/vsol_digital_curve_2d_sptr.h>
 
@@ -17,7 +18,8 @@
 class bwm_image_processor
 {
  public:
-  static void hist_plot(bgui_image_tableau_sptr img);
+  static void hist_plot(bgui_image_tableau_sptr img,
+                        vsol_polygon_2d_sptr p = 0);
 
   static void intensity_profile(bgui_image_tableau_sptr img,
                                 float start_col, float start_row, 
@@ -41,6 +43,11 @@ class bwm_image_processor
 
   static void scan_regions(bgui_image_tableau_sptr const& img,
                            vcl_vector<vgl_polygon<double> > const& regions);
+
+  static bool crop_to_box(bgui_image_tableau_sptr const& img,
+                          vsol_box_2d_sptr const& roi,
+                          vil_image_resource_sptr& chip);
+
 };
 
 #endif
