@@ -19,7 +19,7 @@ class bwm_soview2D_vertex : public vgui_soview2D_circle
   virtual vcl_string type_name() const { return "bwm_soview2D_vertex"; }
 
   bgui_vsol_soview2D* obj() { return obj_; }
-  int vertex_indx() { return v_index_; }
+  int vertex_indx() const { return v_index_; }
 
  private:
   //: the id of the soview2D object that vertex belongs to
