@@ -21,7 +21,7 @@
 #include <vsol/vsol_polygon_3d_sptr.h>
 #include <vsol/vsol_point_3d_sptr.h>
 #include <vsol/vsol_line_3d_sptr.h>
-#include <vpgl/bgeo/bgeo_lvcs.h>
+#include <vpgl/vpgl_lvcs.h>
 
 
 class bwm_observable : public vgui_observable, public vbl_ref_count
@@ -29,24 +29,24 @@ class bwm_observable : public vgui_observable, public vbl_ref_count
  public:
 
   // constructor
-  bwm_observable() {}
+  bwm_observable(): path_("") {}
 
-  bwm_observable(const bwm_observable&) {}
+  bwm_observable(const bwm_observable&) : vgui_observable(), vbl_ref_count() {}
 
   virtual ~bwm_observable() {}
 
   virtual vcl_string type_name() const { return "bwm_observable"; }
 
-  virtual int obj_type()=0;
+  virtual int obj_type() const=0;
 
-  // removes the object from 3D scene by notifiying the observers of deletion
+  // removes the object from 3D scene by notifying the observers of deletion
   virtual void remove()=0;
 
   void virtual set_object(vsol_polygon_3d_sptr poly3d)=0;
 
   virtual vgl_box_3d<double> bounding_box()=0;
 
-  virtual unsigned num_faces()=0;
+  virtual unsigned num_faces() const=0;
 
   virtual void translate(vgl_vector_3d<double> T)=0;
 
@@ -91,13 +91,23 @@ class bwm_observable : public vgui_observable, public vbl_ref_count
 
   virtual void label_wall(unsigned face_id)=0;
 
-  virtual bwm_observable_sptr global_to_local(bgeo_lvcs* lvcs, double& min_z)=0;
+  virtual bwm_observable_sptr global_to_local(vpgl_lvcs* lvcs, double& min_z)=0;
 
-  virtual void save(const char* filename, bgeo_lvcs* lvcs)=0;
+  virtual void save(const char* filename, vpgl_lvcs* lvcs)=0;
 
   virtual void save(const char* filename)=0;
 
+  vcl_string path() const { return path_; }
+  void set_path(vcl_string const& path) { path_=path; }
+
+  vcl_string site() const { return site_; }
+  void set_site(vcl_string const& site) { site_=site; }
+
  protected:
+  //: the observable file path
+  vcl_string path_;
+  //: the observable site name
+  vcl_string site_;
 
   vgl_vector_3d<double> last_translation_;
 };
