@@ -17,42 +17,51 @@
 
 #include <bmsh3d/bmsh3d_mesh_mc.h>
 #include <bmsh3d/bmsh3d_face_mc.h>
+#include <vpgl/vpgl_camera.h>
 
-typedef enum {RoofSurface, WallSurface, None} BWM_FACE_LABEL;
+typedef enum { RoofSurface, WallSurface, None } BWM_FACE_LABEL;
 
 class bwm_observable_mesh : public bwm_observable
 {
  public:
 
-  typedef enum {BWM_MESH_IMAGE_PROCESSING, BWM_MESH_FEATURE, BWM_MESH_TERRAIN } BWM_MESH_TYPES;
+  typedef enum { BWM_MESH_IMAGE_PROCESSING, BWM_MESH_FEATURE, BWM_MESH_TERRAIN } BWM_MESH_TYPES;
 
-  virtual vcl_string type_name() const {return "bwm_observable_mesh"; }
+  virtual vcl_string type_name() const { return "bwm_observable_mesh"; }
 
   //: constructors
   bwm_observable_mesh();
   bwm_observable_mesh(BWM_MESH_TYPES type);
   bwm_observable_mesh(bmsh3d_mesh_mc* object);
   bwm_observable_mesh(vsol_polygon_3d_sptr poly);
+  bwm_observable_mesh(vgl_box_3d<double> box);
 
   //: destructor
   virtual ~bwm_observable_mesh();
 
+  bwm_observable_mesh& operator=(bwm_observable_mesh& m);
+
   void set_mesh_type(BWM_MESH_TYPES type) { mesh_type_ = type; }
 
-  int obj_type() { return mesh_type_; }
+  int obj_type() const { return mesh_type_; }
 
   void remove();
 
   vgl_box_3d<double> bounding_box();
 
-  unsigned num_faces()  { return object_->facemap().size(); }
-  unsigned num_edges() { return object_->edgemap().size(); }
-  unsigned num_vertices() { return object_->vertexmap().size(); }
+  unsigned num_faces() const  { return object_->facemap().size(); }
+  unsigned num_edges() const { return object_->edgemap().size(); }
+  unsigned num_vertices() const { return object_->vertexmap().size(); }
 
   void translate(vgl_vector_3d<double> T);
 
   bwm_observable_sptr transform(vgl_h_matrix_3d<double> T_);
 
+  //:move along the rays through the vertices of a polygon so as to leave the camera projection unchanged
+  bool move_poly_in_optical_cone(vpgl_camera<double> * cam,
+                                 unsigned face_id,
+                                 double da);
+
   void send_update();
 
   void extrude(int face_id);
@@ -98,9 +107,9 @@ class bwm_observable_mesh : public bwm_observable
 
   bool is_poly_in(unsigned id, unsigned& index);
 
-  void label_roof(unsigned face_id){ labels_[face_id] = RoofSurface; }
+  void label_roof(unsigned face_id) { labels_[face_id] = RoofSurface; }
 
-  void label_wall(unsigned face_id){ labels_[face_id] = WallSurface; }
+  void label_wall(unsigned face_id) { labels_[face_id] = WallSurface; }
 
   BWM_FACE_LABEL get_face_label(unsigned face_id);
 
@@ -117,16 +126,20 @@ class bwm_observable_mesh : public bwm_observable
 
   //SoSeparator* convert_coin3d(bool b_shape_hints, float transp, int colorcode);
 
-  bwm_observable_sptr global_to_local(bgeo_lvcs* lvcs, double& min_z);
+  bwm_observable_sptr global_to_local(vpgl_lvcs* lvcs, double& min_z);
 
-  void load_from(vcl_string filename);
+  bool load_from(vcl_string filename);
 
-  void save(const char* filename, bgeo_lvcs* lvcs);
+  void save(const char* filename, vpgl_lvcs* lvcs);
 
   void save(const char* filename);
 
  protected:
+  void notify_observers(vcl_string message_type);
 
+  //:useful for adjusting  the face vertices
+  bool single_face_with_vertices(unsigned face_id, vsol_polygon_3d_sptr& poly,
+                                 vcl_vector<bmsh3d_vertex*>& verts);
   bmsh3d_mesh_mc* object_;
 
   bmsh3d_face_mc* current_extr_face;
@@ -146,8 +159,6 @@ class bwm_observable_mesh : public bwm_observable
 
   bmsh3d_face_mc* extrude_face(bmsh3d_mesh_mc* M, bmsh3d_face_mc* F);
 
-  void notify_observers(vcl_string message_type);
-
   void move_points_to_plane(bmsh3d_face_mc* face);
 
   void shrink_mesh(bmsh3d_mesh_mc* mesh, double dist);
