@@ -25,7 +25,7 @@ class bwm_observer : public vgui_observer
   virtual void handle_update(vgui_message const& msg,
                              bwm_observable_sptr observable) = 0;
 
-  virtual void add_new_obj(bwm_observable_sptr observable){}
+  virtual void add_new_obj(bwm_observable_sptr /*observable*/) {}
 
 #if 0
   virtual void update_all()=0;
@@ -36,7 +36,7 @@ class bwm_observer : public vgui_observer
   virtual void translate(vgl_vector_3d<double> T)=0;
 #endif
 
-  //: connect the the given face as an inner face to the selected face
+  //: connect the given face as an inner face to the selected face
   virtual void connect_inner_face(vsol_polygon_2d_sptr poly)=0;
 
   //: create the interior of an objects, as a smaller copy of the outer object
