@@ -1,17 +1,20 @@
 #include "bwm_observer_cam.h"
 //:
 // \file
-#include "bwm_observer_mgr.h"
-#include "bwm_observable_mesh.h"
-#include "bwm_observable_mesh_circular.h"
-#include "algo/bwm_algo.h"
-#include "algo/bwm_plane_fitting_lsf.h"
-#include "algo/bwm_image_processor.h"
-#include "algo/bwm_delaunay_tri.h"
-#include "bwm_tableau_mgr.h"
-#include "bwm_world.h"
+#include <bwm/bwm_observer_mgr.h>
+#include <bwm/bwm_observable_mesh.h>
+#include <bwm/bwm_observable_point.h>
+#include <bwm/bwm_observable_point_sptr.h>
+#include <bwm/bwm_observable_mesh_circular.h>
+#include <bwm/algo/bwm_algo.h>
+#include <bwm/bwm_plane_fitting_lsf.h>
+#include <bwm/algo/bwm_image_processor.h>
+#include <bwm/algo/bwm_delaunay_tri.h>
+#include <bwm/bwm_tableau_mgr.h>
+#include <bwm/bwm_world.h>
 
 #include <vcl_iostream.h>
+#include <vcl_sstream.h>
 #include <vcl_iomanip.h>
 #include <vcl_cassert.h>
 #include <vgui/vgui.h>
@@ -23,6 +26,8 @@
 #include <vgl/vgl_vector_3d.h>
 #include <vgl/vgl_polygon.h>
 #include <vgl/vgl_point_3d.h>
+#include <vgl/xio/vgl_xio_point_3d.h>
+#include <vgl/xio/vgl_xio_vector_3d.h>
 #include <vgl/vgl_homg_plane_3d.h>
 #include <vgl/algo/vgl_convex_hull_2d.h>
 #include <vpgl/algo/vpgl_ray.h>
@@ -37,8 +42,15 @@
 #include <vsol/vsol_line_2d.h>
 
 #include <vgui/vgui_dialog.h>
+#include <vgui/vgui_dialog_extensions.h>
 #include <vgui/vgui_projection_inspector.h>
 #include <bgui/bgui_vsol_soview2D.h>
+#if 0
+#include <boxm/boxm_apm_traits.h>
+#include <boxm/boxm_scene_parser.h>
+#endif
+#include <vsl/vsl_basic_xml_element.h>
+#include <vpgl/algo/vpgl_camera_compute.h>
 
 bool bwm_observer_cam::geo_position(double u, double v,
                                     double& x, double& y, double& z)
@@ -161,7 +173,7 @@ bool bwm_observer_cam::handle(const vgui_event &e)
     if (moving_p_->type_name().compare(POLYGON_TYPE) == 0) {
       bgui_vsol_soview2D_polygon* polygon = (bgui_vsol_soview2D_polygon*) moving_p_;
       unsigned i = find_index_of_v(moving_v_, (bgui_vsol_soview2D_polygon*)moving_p_);
-      if (i == -1)
+      if (i == (unsigned int)(-1))
         return true;
       moving_v_->translate(x_diff, y_diff);
       polygon->sptr()->vertex(i)->set_x(polygon->sptr()->vertex(i)->x() + x_diff );
@@ -195,7 +207,7 @@ bool bwm_observer_cam::handle(const vgui_event &e)
            moving_vertex_ && moving_face_)
   {
     unsigned i = find_index_of_v(moving_v_, (bgui_vsol_soview2D_polygon*)moving_p_);
-    if (i == -1)
+    if (i == (unsigned int)(-1))
       return true;
     if (moving_p_->type_name().compare(POLYGON_TYPE) == 0) {
       bgui_vsol_soview2D_polygon* polygon = (bgui_vsol_soview2D_polygon*) moving_p_;
@@ -220,8 +232,10 @@ bool bwm_observer_cam::handle(const vgui_event &e)
   {
       if (e.modifier == vgui_SHIFT)
         extrude_obj_->move_extr_face(1.0);
-      else
+      else if (e.modifier == vgui_CTRL)
         extrude_obj_->move_extr_face(0.1);
+      else
+        extrude_obj_->move_extr_face(0.01);
     in_jog_mode_ = true;
     return true;
   }
@@ -229,8 +243,10 @@ bool bwm_observer_cam::handle(const vgui_event &e)
   {
       if (e.modifier == vgui_SHIFT)
         extrude_obj_->move_extr_face(-1.0);
-      else
+      else if (e.modifier == vgui_CTRL)
         extrude_obj_->move_extr_face(-0.1);
+      else
+        extrude_obj_->move_extr_face(-0.01);
     in_jog_mode_ = true;
     return true;
   }
@@ -241,24 +257,52 @@ bool bwm_observer_cam::handle(const vgui_event &e)
   // moving along the optical axis
   if (e.type==vgui_KEY_PRESS && e.key == vgui_CURSOR_UP)
   {
-    if (this == bwm_observer_mgr::BWM_MASTER_OBSERVER)
+    if (this == bwm_observer_mgr::BWM_MASTER_OBSERVER) {
       if (e.modifier == vgui_SHIFT)
-        this->translate_along_optical_axis(1.0);
+        this->translate_along_optical_cone(1.0);
+      else if (e.modifier == vgui_CTRL)
+        this->translate_along_optical_cone(0.1);
       else
-        this->translate_along_optical_axis(0.1);
+        this->translate_along_optical_cone(0.01);
+    }
     in_jog_mode_ = true;
     return true;
   }
   if (e.type==vgui_KEY_PRESS && e.key == vgui_CURSOR_DOWN)
   {
-    if (this == bwm_observer_mgr::BWM_MASTER_OBSERVER)
+    if (this == bwm_observer_mgr::BWM_MASTER_OBSERVER) {
       if (e.modifier == vgui_SHIFT)
-        this->translate_along_optical_axis(-1.0);
+        this->translate_along_optical_cone(-1.0);
+      else if (e.modifier == vgui_CTRL)
+        this->translate_along_optical_cone(-0.1);
       else
-        this->translate_along_optical_axis(-0.1);
+        this->translate_along_optical_cone(-0.01);
+    }
     in_jog_mode_ = true;
     return true;
   }
+    // extrude mode, goes only in z direction (up and down)
+  if (shadow_mode_ && e.type==vgui_KEY_PRESS && e.modifier == vgui_CTRL)
+  {
+      if (e.key == 'w' )
+        sun_elev_angle_+=0.01;
+      else if (e.key == 's')
+        sun_elev_angle_-=0.01;
+      else if (e.key == 'a')
+        sun_azim_angle_-=0.01;
+      else if (e.key == 'd')
+        sun_azim_angle_+=0.01;
+
+      //sun_azim_angle_=vnl_math::angle_0_to_2pi(sun_azim_angle_);
+      //sun_elev_angle_=sun_elev_angle_<vnl_math::pi_over_2 ? vnl_math::pi_over_2 : sun_elev_angle_;
+      //sun_elev_angle_=sun_elev_angle_>vnl_math::pi        ? vnl_math::pi : sun_elev_angle_;
+      this->project_shadow();
+    return true;
+  }
+  // stops the extrude mode
+  if (shadow_mode_ && e.type==vgui_KEY_PRESS && e.key == vgui_END)
+    shadow_mode_ = false;
+
   // changing radius
   if (e.type==vgui_KEY_PRESS && e.key == vgui_CURSOR_LEFT && e.modifier == vgui_SHIFT) {
     vcl_vector<vgui_soview*> select_list = this->get_selected_soviews();
@@ -319,9 +363,11 @@ void bwm_observer_cam::set_ground_plane(double x1, double y1, double x2, double
   vgl_point_3d<double> world_point1, world_point2;
   vgl_plane_3d<double> xy_plane(0, 0, 1, 0);
 
-  intersect_ray_and_plane(vgl_point_2d<double> (x1, y1), xy_plane, world_point1);
-  intersect_ray_and_plane(vgl_point_2d<double> (x2, y2), xy_plane, world_point2);
-
+  if (!intersect_ray_and_plane(vgl_point_2d<double> (x1, y1), xy_plane, world_point1)||intersect_ray_and_plane(vgl_point_2d<double> (x2, y2), xy_plane, world_point2)) {
+    vcl_cout << "bwm_observer_cam::set_ground_plane(.) -"
+             << " intersect ray and plane failed\n";
+    return;
+  }
   // define the third point in z direction which is the normal to the z=0 plane
   vgl_point_3d<double> world_point3(world_point1.x(),
                                     world_point1.y(),
@@ -379,7 +425,6 @@ void bwm_observer_cam::move_ground_plane( vgl_plane_3d<double> master_plane,
     double b = master_plane.b();
     double c = master_plane.c();
 
-    double orig_d = d;
     vsol_point_3d_sptr old_pt3d;
     backproj_point(old_pt, old_pt3d);
     vgl_point_2d<double> master_img_pt;
@@ -411,7 +456,7 @@ void bwm_observer_cam::move_ground_plane( vgl_plane_3d<double> master_plane,
     vsol_point_3d_sptr new_pt3d;
     bwm_observer_mgr::BWM_MASTER_OBSERVER->backproj_point((new vsol_point_2d(master_img_pt)), new_pt3d, master_plane);
 
-    // find the translation bewteen the beginning 3d point and ending,
+    // find the translation between the beginning 3d point and ending,
     // after moving the plane
     vgl_vector_3d<double> t(new_pt3d->x() - old_pt3d->x(),
                             new_pt3d->y() - old_pt3d->y(),
@@ -422,6 +467,7 @@ void bwm_observer_cam::move_ground_plane( vgl_plane_3d<double> master_plane,
   vcl_cerr << "The original vertex to be moved is not selected!\n";
 }
 
+#if 0 //replaced by translate along optical cone
 //Translate along *this* observer's optical axis
 void bwm_observer_cam::translate_along_optical_axis(double da)
 {
@@ -467,6 +513,52 @@ void bwm_observer_cam::translate_along_optical_axis(double da)
   vcl_cerr << "In bwm_observer_cam::translate_along_optical_axis - "
            << "not exactly one selected vertex\n";
 }
+#endif
+
+// expand or contract the object boundary so that the projection in the
+// image is invariant to perspective scale change
+void bwm_observer_cam::translate_along_optical_cone(double da)
+{
+  vcl_vector<vgui_soview*> select_list = this->get_selected_soviews();
+#if 0
+  vcl_cout << "#selected before move = " << select_list.size() << '\n';
+#endif
+  if (select_list.size() == 1 &&
+      select_list[0]->type_name().compare("bgui_vsol_soview2D_polygon") == 0)
+  {
+    bgui_vsol_soview2D_polygon* poly =
+      static_cast<bgui_vsol_soview2D_polygon*> (select_list[0]);
+
+    //find the mesh this polygon belongs to
+    unsigned int face_id;
+    bwm_observable_sptr obs = find_object(poly->get_id(), face_id);
+    if (!obs)
+    {
+      vcl_cerr << "In bwm_observer_cam::translate_along_optical_axis - "
+               << "nothing selected to move\n";
+      return;
+    }
+    // cone method only available on observable_mesh, not in general
+    bwm_observable_mesh* omsh = 0;
+    if (obs->type_name()=="bwm_observable_mesh")
+      omsh = static_cast<bwm_observable_mesh*>(obs.ptr());
+    else return;
+
+    if (!omsh->move_poly_in_optical_cone(camera_,face_id,da))
+       return;
+#if 0
+     select_list = this->get_selected_soviews();
+    vcl_cout << "#selected after move = " << select_list.size() << '\n';
+#endif
+    //keep the object selected
+    this->select_object(obs);
+#if 0
+     select_list = this->get_selected_soviews();
+    vcl_cout << "#selected after select = " << select_list.size() << '\n';
+#endif
+    return;
+  }
+}
 
 void bwm_observer_cam::proj_point(vgl_point_3d<double> world_pt,
                                   vgl_point_2d<double> &image_pt)
@@ -496,17 +588,15 @@ void bwm_observer_cam::proj_poly(vsol_polygon_3d_sptr poly3d,
     return;
 
   vcl_vector<vsol_point_2d_sptr> vertices;
-
   for (unsigned i=0; i<poly3d->size(); i++) {
     double u = 0,v = 0;
 #ifdef DEBUG
-    vcl_cout << "point " << *(poly3d->vertex(i)) << vcl_endl;
+    vcl_cout << "3d point " << *(poly3d->vertex(i)) << vcl_endl;
 #endif
     camera_->project(poly3d->vertex(i)->x(), poly3d->vertex(i)->y(), poly3d->vertex(i)->z(),u,v);
     vsol_point_2d_sptr p = new vsol_point_2d(u,v);
     vertices.push_back(p);
   }
-
   poly2d = new vsol_polygon_2d (vertices);
 }
 
@@ -620,6 +710,14 @@ void bwm_observer_cam::world_pt_corr()
   vcl_cerr << "Please select only one object\n";
 }
 
+void bwm_observer_cam::scroll_to_point(double lx, double ly, double lz)
+{
+  vgl_point_3d<double> world_pt(lx,ly,lz);
+  vgl_point_2d<double> image_pt;
+  proj_point(world_pt,image_pt);
+  float x = static_cast<float>(image_pt.x()), y = static_cast<float>(image_pt.y());
+  this->move_to_point(x,y);
+}
 
 // ********************** Protected Methods
 
@@ -635,8 +733,10 @@ bool bwm_observer_cam::find_intersection_points(vgl_point_2d<double> const img_p
   vgl_plane_3d<double> poly_plane = poly3d->plane();
 
   vgl_point_3d<double> p1,p2;
-  intersect_ray_and_plane(img_point1, poly_plane, p1);
-  intersect_ray_and_plane(img_point2, poly_plane, p2);
+  if (!intersect_ray_and_plane(img_point1, poly_plane, p1)||
+      !intersect_ray_and_plane(img_point2, poly_plane, p2))
+    return false;
+  ;
 
   if (is_ideal(p1))
     vcl_cout << "p1 is ideal" << vcl_endl;
@@ -660,11 +760,11 @@ bool bwm_observer_cam::find_intersection_points(vgl_point_2d<double> const img_p
   {
     double point1_x, point1_y, point1_z,
       point2_x, point2_y, point2_z;
-
+    unsigned
     int edge_index1 = vgl_closest_point_to_closed_polygon(point1_x, point1_y, point1_z,
                                                           x_list, y_list, z_list, poly3d->size(),
                                                           non_homg_p1.x(), non_homg_p1.y(), non_homg_p1.z());
-
+    unsigned
     int edge_index2 = vgl_closest_point_to_closed_polygon(point2_x, point2_y, point2_z,
                                                           x_list, y_list, z_list, poly3d->size(),
                                                           non_homg_p2.x(), non_homg_p2.y(), non_homg_p2.z());
@@ -675,7 +775,7 @@ bool bwm_observer_cam::find_intersection_points(vgl_point_2d<double> const img_p
     }
 
     l1 = vgl_point_3d<double> (x_list[edge_index1], y_list[edge_index1], z_list[edge_index1]);
-    int next_index = edge_index1+1;
+    unsigned int next_index = edge_index1+1;
     if (next_index == poly3d->size())
       next_index = 0;
     l2 = vgl_point_3d<double> (x_list[next_index], y_list[next_index], z_list[next_index]);
@@ -828,8 +928,11 @@ bool bwm_observer_cam::find_intersection_point(vgl_point_2d<double> img_point,
   vgl_plane_3d<double> poly_plane = poly3d->plane(); //find_plane(poly3d);
   vgl_point_3d<double> p3d_homg;
 
-  if (!intersect_ray_and_plane(img_point,poly_plane,p3d_homg))
+  if (!intersect_ray_and_plane(img_point,poly_plane,p3d_homg)) {
+    vcl_cout << "in bwm_observer_cam::find_intersection_point(.) -"
+             << " intersect ray and plane failed\n";
     return false;
+  }
 
   if (is_ideal(p3d_homg)) {
     vcl_cout << "intersection point is ideal!" <<vcl_endl;
@@ -916,16 +1019,16 @@ void bwm_observer_cam::extrude_face(vsol_point_2d_sptr pt)
     // find the index of the selected vertices, by searching for the
     // closest 3-d vertex to the backprojected 2-d vertex
     double min_dist1 = 1e23, min_dist2 = 1e23;
-    unsigned index1 = -1, index2 = -1;
-    vcl_cout << vcl_endl << "-- Selected v1=" << picked_v1->get_p() << vcl_endl
-             <<  "-- Selected v2=" << picked_v2->get_p() << vcl_endl;
+    unsigned index1 = (unsigned int)(-1), index2 = (unsigned int)(-1);
+    vcl_cout << "\n-- Selected v1=" << picked_v1->get_p()
+             << "\n-- Selected v2=" << picked_v2->get_p() << vcl_endl;
     for (unsigned i=0; i<face2d->size(); i++)
     {
       vgl_point_2d<double> pt = face2d->vertex(i)->get_p();
 
       double dist1 = (pt - picked_v1->get_p()).length();
       double dist2 = (pt - picked_v2->get_p()).length();
-      vcl_cout << i << "-- Vertex" << pt << " dist=" << dist1 << vcl_endl
+      vcl_cout << i << "-- Vertex" << pt << " dist=" << dist1 << '\n'
                << i << "-- Vertex" << pt << " dist=" << dist2 << vcl_endl;
       if (dist1 < min_dist1) {
         min_dist1 = dist1;
@@ -936,7 +1039,7 @@ void bwm_observer_cam::extrude_face(vsol_point_2d_sptr pt)
         index2 = i;
       }
     }
-    if ((index1 == -1) || (index2 == -1)) {
+    if ((index1 == (unsigned int)(-1)) || (index2 == (unsigned int)(-1))) {
       vcl_cerr << "The vertices (one or both) cannot be found on the face\n";
       return;
     }
@@ -982,8 +1085,8 @@ void bwm_observer_cam::extrude_face(vsol_point_2d_sptr pt)
                             face->vertex(index1)->get_p().y(),
                             face->vertex(index1)->get_p().z()+1);
 
-    vcl_cout << "p0-->" << p0 << vcl_endl
-             << "p1-->" << p1 << vcl_endl
+    vcl_cout << "p0-->" << p0 << '\n'
+             << "p1-->" << p1 << '\n'
              << "p2-->" << p2 << vcl_endl;
     vgl_plane_3d<double> plane(p0, p2, p1);
   #ifdef CAM_DEBUG
@@ -1017,7 +1120,7 @@ void bwm_observer_cam::extrude_face(vsol_point_2d_sptr pt)
     double ninety_deg = vnl_math::pi/2.0;
 
 #ifdef CAM_DEBUG
-    vcl_cout << "angle " << a*180/vnl_math::pi << '\n';
+    vcl_cout << "angle " << a*vnl_math::deg_per_rad << '\n';
 #endif
 
   //magnitude of the distance from the selected vertex to the target point
@@ -1131,7 +1234,7 @@ void bwm_observer_cam::backproj_poly(vsol_polygon_2d_sptr poly2d,
   backproj_poly(poly2d, poly3d, trans_plane);
 }
 
-void bwm_observer_cam::backproj_poly(vsol_polygon_2d_sptr poly2d,
+bool bwm_observer_cam::backproj_poly(vsol_polygon_2d_sptr poly2d,
                                      vsol_polygon_3d_sptr& poly3d,
                                      vgl_plane_3d<double> proj_plane)
 {
@@ -1142,13 +1245,17 @@ void bwm_observer_cam::backproj_poly(vsol_polygon_2d_sptr poly2d,
     vsol_point_2d_sptr p = poly2d->vertex(i);
     vgl_point_2d<double> image_point(p->x(), p->y());
 
-    this->intersect_ray_and_plane(image_point,proj_plane,world_point);
+    if (!this->intersect_ray_and_plane(image_point,proj_plane,world_point)) {
+      vcl_cout << "Intersection failed in backproj_poly\n";
+      return false;
+    }
     double x = world_point.x();
     double y = world_point.y();
     double z = world_point.z();
     projected_list.push_back(new vsol_point_3d (x, y, z));
   }
   poly3d = new vsol_polygon_3d(projected_list);
+  return true;
 }
 
 bool bwm_observer_cam::intersect_ray_and_box(vgl_box_3d<double> box,
@@ -1182,7 +1289,10 @@ bool bwm_observer_cam::intersect_ray_and_box(vgl_box_3d<double> box,
 
   for (unsigned i=0; i<planes.size(); i++) {
     vgl_point_3d<double> p;
-    intersect_ray_and_plane(img_point,planes[i],p);
+    if (intersect_ray_and_plane(img_point,planes[i],p)) {
+    vcl_cout << "ray-plane intersection failed\n" << vcl_endl;
+      return false;
+    }
     vgl_point_3d<double> ip(p);
     if (box.contains(ip))
       intersection_points.push_back(ip);
@@ -1191,7 +1301,7 @@ bool bwm_observer_cam::intersect_ray_and_box(vgl_box_3d<double> box,
   if (intersection_points.size() > 0)
     return true;
   else {
-    vcl_cout << "Rays do not intersect the box" << vcl_endl;
+    vcl_cout << "Rays do not intersect the box\n" << vcl_endl;
     return false;
   }
 }
@@ -1221,7 +1331,7 @@ void bwm_observer_cam::save()
   vcl_string ext, file, empty="";
 
   params.file ("Save...", ext, file);
-  bool use_lvcs = false;
+  //bool use_lvcs = false;
   //params.checkbox("use lvcs",use_lvcs);
   if (!params.ask())
     return;
@@ -1242,7 +1352,7 @@ void bwm_observer_cam::save_all()
   vcl_string ext, file, empty="";
 
   params.file ("Save...", ext, file);
-  bool use_lvcs = false;
+  //bool use_lvcs = false;
   //params.checkbox("use lvcs",use_lvcs);
   if (!params.ask())
     return;
@@ -1279,7 +1389,7 @@ unsigned bwm_observer_cam::find_index_of_v(bwm_soview2D_vertex* vertex,
 {
   vsol_polygon_2d_sptr poly = polygon->sptr();
   double min_dist = 1e23;
-  unsigned index = -1;
+  unsigned index = (unsigned int)(-1);
   for (unsigned i=0; i<poly->size(); i++) {
     float x, y;
     vertex->get_centroid(&x, &y);
@@ -1335,6 +1445,78 @@ void bwm_observer_cam::scan_regions()
   bwm_image_processor::scan_regions(img_tab_, polygons);
 }
 
+void bwm_observer_cam::project_shadow()
+{
+  // get the selected objects
+  shadow_mode_=true;
+    vcl_vector<vgui_soview*> select_list = this->get_selected_soviews();
+  vcl_vector<vgl_polygon<double> > polygons;
+  for (unsigned i=0;i<shadow_line_segs_.size();i++)
+      this->remove(shadow_line_segs_[i]);
+  shadow_line_segs_.clear();
+  for (unsigned s=0; s<select_list.size();s++)
+  {
+    if (select_list[s]->type_name().compare("bgui_vsol_soview2D_line_seg") == 0)
+    {
+      bgui_vsol_soview2D_line_seg* lineseg;
+      lineseg = static_cast<bgui_vsol_soview2D_line_seg*> (select_list[s]);
+      vsol_line_2d_sptr line_sptr=lineseg->sptr();
+
+      double x0=line_sptr->p0()->x();
+      double y0=line_sptr->p0()->y();
+
+      double x1=line_sptr->p1()->x();
+      double y1=line_sptr->p1()->y();
+
+      double dist_min1=1e10; int index_min1=-1;
+      double dist_min2=1e10; int index_min2=-1;
+      unsigned edge_id;
+      bwm_observable_sptr obs = this->find_object(lineseg->get_id(), edge_id);
+
+      vcl_vector<vsol_point_3d_sptr> mesh_pts=obs->extract_vertices();
+      for (unsigned i=0;i<mesh_pts.size();i++)
+      {
+        double u,v;
+        camera_->project(mesh_pts[i]->x(),
+                         mesh_pts[i]->y(),
+                         mesh_pts[i]->z(),u,v);
+        double dist1=(x0-u)*(x0-u)+(y0-v)*(y0-v);
+        double dist2=(x1-u)*(x1-u)+(y1-v)*(y1-v);
+        if (dist_min1>dist1)
+        {
+          dist_min1=dist1;
+          index_min1=i;
+        }
+        if (dist_min2>dist2)
+        {
+          dist_min2=dist2;
+          index_min2=i;
+        }
+      }
+      int min_z_index=mesh_pts[index_min1]->z()<mesh_pts[index_min2]->z()?index_min1:index_min2;
+      double len=mesh_pts[index_min1]->distance(mesh_pts[index_min2]);
+      vsol_point_3d_sptr base_point= mesh_pts[min_z_index];
+      vsol_point_3d_sptr pnew=new vsol_point_3d(base_point->x()-len*vcl_tan(sun_elev_angle_)*vcl_cos(sun_azim_angle_),
+                                                base_point->y()-len*vcl_tan(sun_elev_angle_)*vcl_sin(sun_azim_angle_),
+                                                base_point->z());
+
+      double u0,v0,u1,v1;
+      camera_->project(base_point->x(),
+                       base_point->y(),
+                       base_point->z(),u0,v0);
+      camera_->project(pnew->x(),pnew->y(),pnew->z(),u1,v1);
+
+
+      vsol_line_2d_sptr shadow_line= new vsol_line_2d(new vsol_point_2d(u0,v0),
+                                                      new vsol_point_2d(u1,v1));
+
+      shadow_line_segs_.push_back(this->add_vsol_line_2d(shadow_line));
+    }
+  }
+  vcl_cout<<"(theta,phi) = ("<<sun_elev_angle_<<','<<sun_azim_angle_<<')'<<vcl_endl;
+  this->post_redraw();
+}
+
 void bwm_observer_cam::make_object_selectable(bwm_observable_sptr obj, bool status)
 {
   // find the soview objects belong to this object
@@ -1395,17 +1577,28 @@ void  bwm_observer_cam::position_vertex(bool show_as_geo)
     return;
   }
   vsol_point_3d_sptr p3d = (*vit).second;
+  double lx,ly,lz;
+  bool lvcs_valid = bwm_world::instance()->lvcs_valid();
+  if (lvcs_valid) {
+    vpgl_lvcs lvcs;
+    bwm_world::instance()->get_lvcs(lvcs);
+  // convert point to local
+  lvcs.global_to_local(p3d->x(), p3d->y(), p3d->z(), vpgl_lvcs::wgs84,lx, ly, lz);
+  }
+  else {
+    lx = p3d->x(); ly = p3d->y(); lz = p3d->z();
+  }
   vgui_text_tableau_sptr tt = img_tab_->text_tab();
   if (!tt) return;
   tt->clear();
   tt->set_colour(1.0, 1.0, 0.0);
   vcl_stringstream str;
-  if (show_as_geo)
+  if (show_as_geo&&lvcs_valid)
     str << vcl_fixed << vcl_setprecision(6)<< '(' << p3d->y()
         << ' '  << p3d->x() << vcl_setprecision(2)<< ' ' << p3d->z() << ')' << vcl_ends;
   else
-    str << vcl_fixed << vcl_setprecision(6)<< '(' << p3d->x()
-        << ' '  << p3d->y() << vcl_setprecision(2)<< ' ' << p3d->z() << ')' << vcl_ends;
+    str << vcl_fixed << vcl_setprecision(6)<< '(' << lx
+        << ' '  << ly << vcl_setprecision(2)<< ' ' << lz << ')' << vcl_ends;
   float x = static_cast<float>(u+2.0);
   float y = static_cast<float>(v-2.0);
   tt->add(x, y, str.str());
@@ -1502,3 +1695,236 @@ void bwm_observer_cam::project_meshes(vcl_vector<vcl_string> paths,
     }
   }
 }
+
+void bwm_project_meshes(vcl_vector<vcl_string> paths,
+                        vpgl_camera<double>* cam,
+                        vcl_vector<vgl_polygon<double> > &poly_2d_list)
+{
+  for (unsigned i=0; i<paths.size(); i++) {
+    bwm_observable_mesh_sptr mesh = new bwm_observable_mesh();
+    mesh->load_from(paths[i]);
+    if (!mesh)
+      vcl_cout << "There is a problem loading " << paths[i] << vcl_endl;
+    else {
+      vcl_map<int, vsol_polygon_3d_sptr > faces = mesh->extract_faces();
+      for (unsigned f=0; f<faces.size(); f++) {
+        vsol_polygon_3d_sptr face = faces[f];
+        vgl_polygon<double> poly2d(1);
+        for (unsigned i=0; i<face->size(); i++) {
+          double u = 0,v = 0;
+          cam->project(face->vertex(i)->x(), face->vertex(i)->y(), face->vertex(i)->z(),u,v);
+          poly2d.push_back(u,v);
+        }
+        poly_2d_list.push_back(poly2d);
+      }
+    }
+  }
+}
+#if 0
+void bwm_observer_cam::create_boxm_scene()
+{
+  vgui_soview2D* obj =  bwm_observer_img::get_selected_object(POLYGON_TYPE);
+  if (obj) {
+    // find the mesh containing this polygon?????
+    unsigned face_id;
+    bwm_observable_sptr mesh = find_object(obj->get_id(), face_id);
+    vgl_box_3d<double> bb = mesh->bounding_box();
+    vgl_point_3d<double> min = bb.min_point();
+    double x_dim = bb.width();
+    double y_dim = bb.height();
+    double z_dim = bb.depth();
+
+    double lx=min.x(), ly=min.y(), lz=min.z();
+    vpgl_lvcs lvcs(ly, lx, lz,vpgl_lvcs::wgs84, vpgl_lvcs::DEG, vpgl_lvcs::METERS);
+    double local_x, local_y, local_z;
+    lvcs.global_to_local(lx+x_dim,ly+y_dim,lz+z_dim,vpgl_lvcs::wgs84,local_x, local_y, local_z);
+
+    // create the dialog
+    vgui_dialog_extensions dialog("Enter the World Parameters");
+    vcl_string ext, file, empty="";
+    dialog.file ("File Path", ext, file);
+
+    // appearence model
+    vcl_vector<vcl_string> app_models;
+    for (int i=0; i < int(BOXM_APM_UNKNOWN); i++)
+      app_models.push_back(boxm_apm_types::app_model_strings[i]);
+
+    dialog.line_break();
+    int app_model_num;
+    dialog.choice("Appearence Model",app_models,app_model_num);
+    dialog.line_break();
+
+    // multi-bin?
+    int multi_bin=0;
+    dialog.choice("Multiple Bins", "false","true",multi_bin);
+    dialog.line_break();
+
+    // LVCS
+    dialog.message("LVCS from the box ");
+    dialog.field("lon:", lx);
+    dialog.field("lat:", ly);
+    dialog.field("elev:", lz);
+    dialog.line_break();
+
+    dialog.message("Dimensions of the World ");
+    dialog.field("X:", local_x);
+    dialog.field("Y:", local_y);
+    dialog.field("Z:", local_z);
+    dialog.line_break();
+
+    // Local origin
+    double x=0, y=0, z=0;
+    dialog.message("Local Origin ");
+    dialog.field("X:", x);
+    dialog.field("Y:", y);
+    dialog.field("Z:", z);
+    dialog.line_break();
+
+    //number of blocks
+    double bx=1, by=1, bz=1;
+    dialog.message("Number of Blocks ");
+    dialog.field("X:", bx);
+    dialog.field("Y:", by);
+    dialog.field("Z:", bz);
+    dialog.line_break();
+
+    // scene path
+    vcl_string path;
+    dialog.field("Scene Path:", path);
+
+    // block prefix
+    vcl_string prefix;
+    dialog.field("Block Prefix:", prefix);
+
+    int tree_max=1, tree_init=1;
+    dialog.message("Tree Levels ");
+    dialog.field("Max:", tree_max);
+    dialog.field("Init:", tree_init);
+    dialog.line_break();
+
+    int load_all_blocks=0;
+    dialog.choice("Load All Blocks", "false","true",load_all_blocks);
+
+    int save_internal_nodes=0;
+    dialog.choice("Save Internal Nodes", "false","true",save_internal_nodes);
+
+    int save_platform_independent=0;
+    dialog.choice("save_platform_independent", "false","true",save_platform_independent);
+
+    if (!dialog.ask())
+      return;
+
+    ////////// Write the XML file
+    vcl_ofstream os(file.c_str());
+    vsl_basic_xml_element scene_elm("boxm_scene");
+    scene_elm.x_write_open(os);
+
+    vsl_basic_xml_element app_model("appearence_model");
+    app_model.add_attribute("type", app_models[app_model_num]);
+    app_model.x_write(os);
+
+    vsl_basic_xml_element bin("multi_bin");
+    bin.add_attribute("value", multi_bin);
+    bin.x_write(os);
+
+    vsl_basic_xml_element save_nodes("save_internal_nodes");
+    save_nodes.add_attribute("value", save_internal_nodes);
+    save_nodes.x_write(os);
+
+    vsl_basic_xml_element sp("save_platform_independent");
+    sp.add_attribute("value", save_platform_independent);
+    sp.x_write(os);
+
+    vsl_basic_xml_element load_blocks("load_all_blocks");
+    load_blocks.add_attribute("value", load_all_blocks);
+    load_blocks.x_write(os);
+
+    lvcs.x_write(os, "lvcs");
+
+    // convert the world dimensions to local coordinate system (meters)
+    x_write(os, vgl_point_3d<double>(x,y,z), "local_origin");
+
+    // compute the block dimensions from the world dimensions
+    double xx=local_x/bx, yy=local_y/by, zz=local_z/bz;
+    x_write(os, vgl_vector_3d<double>(xx,yy,zz), "block_dimensions"); // dimensions of matrix of blocks
+
+    vsl_basic_xml_element blocks("blocks");
+    blocks.add_attribute("x_dimension", bx);
+    blocks.add_attribute("y_dimension", by);
+    blocks.add_attribute("z_dimension", bz);
+    blocks.x_write(os);
+
+    vsl_basic_xml_element paths("scene_paths");
+    paths.add_attribute("path", path);
+    paths.add_attribute("block_prefix", prefix);
+    paths.x_write(os);
+
+    vsl_basic_xml_element levels("octree_level");
+    levels.add_attribute("max", tree_max);
+    levels.add_attribute("max", tree_init);
+    levels.x_write(os);
+    scene_elm.x_write_close(os);
+    os.close();
+  }
+}
+
+void bwm_observer_cam::load_boxm_scene()
+{
+  vgui_dialog params("Load Scene File");
+  vcl_string ext, file, empty="";
+
+  params.file ("Load...", ext, file);
+  if (!params.ask())
+    return;
+
+  if (file == "") {
+    vgui_dialog error ("Error");
+    error.message ("Please specify a filename (prefix)." );
+    error.ask();
+    return;
+  }
+
+  boxm_scene_parser parser;
+  boxm_scene_base scene_base;
+  scene_base.load_scene(file, parser);
+  //parse_config(parser);
+  vgl_point_3d<double> world_min,world_max;
+  vgl_vector_3d<unsigned> dims = parser.block_nums();
+  vgl_point_3d<double> loc_origin =  parser.origin();
+  vgl_vector_3d<double> block_dim = parser.block_dim();
+  double x_size = dims.x()*block_dim.x();
+  double y_size = dims.y()*block_dim.y();
+  double z_size = dims.z()*block_dim.z();
+
+  vpgl_lvcs lvcs;
+  if (parser.lvcs(lvcs)) {
+    // set lvcs
+    bwm_world::instance()->set_lvcs(lvcs);
+    vcl_cout << "defining lvcs with origin = <" << lvcs << vcl_endl;
+
+    // create the world
+
+    // find the origin in global coordinates
+    double lon, lat, elev;
+    lvcs.local_to_global(loc_origin.x(), loc_origin.y(), loc_origin.z(), vpgl_lvcs::wgs84, lon, lat, elev);
+    world_min.set(lon,lat,elev);
+
+    //find the max point of world in local coordinates
+    double w_max_x = loc_origin.x() + x_size;
+    double w_max_y = loc_origin.y() + y_size;
+    double w_max_z = loc_origin.z() + z_size;
+    lvcs.local_to_global(w_max_x, w_max_y, w_max_z, vpgl_lvcs::wgs84, lon, lat, elev);
+    world_max.set(lon,lat,elev);
+  }
+  else {
+    world_min = loc_origin;
+    world_max.set(loc_origin.x()+x_size, loc_origin.y()+y_size,
+                  loc_origin.z()+z_size);
+  }
+  //create the observable mesh
+  vgl_box_3d<double> world(world_min, world_max);
+  bwm_observable_mesh_sptr mesh = new bwm_observable_mesh(world);
+  bwm_world::instance()->add(mesh);
+  bwm_observer_mgr::instance()->attach(mesh);
+}
+#endif
