@@ -3,15 +3,19 @@
 // \file
 #include "algo/bwm_utils.h"
 #include "bwm_world.h"
+#include "bwm_3d_corr.h"
 #include <vgl/vgl_point_2d.h>
 #include <vgl/vgl_vector_2d.h>
 #include <vgl/vgl_point_3d.h>
 #include <vgl/vgl_plane_3d.h>
-#include <vpgl/algo/vpgl_adjust_rational_trans_onept.h>
+#include <vpgl/algo/vpgl_rational_adjust_onept.h>
 #include <vsl/vsl_basic_xml_element.h>
+#include <vsol/vsol_point_3d.h>
+#include <vsol/vsol_polygon_3d.h>
+#include <vgui/vgui_soview.h>
 #include <vgui/vgui_dialog.h>
-
 #include <vcl_iostream.h>
+#include <vcl_fstream.h>
 
 bwm_observer_cam* bwm_observer_mgr::BWM_MASTER_OBSERVER = 0;
 bwm_observer_cam* bwm_observer_mgr::BWM_EO_OBSERVER = 0;
@@ -35,7 +39,7 @@ void bwm_observer_mgr::clear()
   corr_list_.clear();
 }
 
-vcl_vector<bwm_observer_cam*> bwm_observer_mgr::observers_cam()
+vcl_vector<bwm_observer_cam*> bwm_observer_mgr::observers_cam() const
 {
   vcl_vector<bwm_observer_cam*> v;
   for (unsigned i=0; i< observers_.size(); i++) {
@@ -51,7 +55,7 @@ vcl_vector<bwm_observer_cam*> bwm_observer_mgr::observers_cam()
   return v;
 }
 
-vcl_vector<bwm_observer_rat_cam*> bwm_observer_mgr::observers_rat_cam()
+vcl_vector<bwm_observer_rat_cam*> bwm_observer_mgr::observers_rat_cam() const
 {
   vcl_vector<bwm_observer_rat_cam*> v;
 
@@ -90,6 +94,12 @@ void bwm_observer_mgr::attach(bwm_observable_sptr obs)
     obs->attach(observers_[i]);
 }
 
+void bwm_observer_mgr::detach(bwm_observable_sptr obs)
+{
+  for (unsigned i=0; i<observers_.size(); i++)
+    obs->detach(observers_[i]);
+}
+
 void bwm_observer_mgr::remove(bwm_observer* observer)
 {
   for (unsigned i=0; i<observers_.size(); i++)
@@ -124,17 +134,17 @@ bool bwm_observer_mgr::comp_avg_camera_center(vgl_point_3d<double> &cam_center)
 }
 
 #if 0
-//Set a world point to be used in correspondences from world to image
+//: Set a world point to be used in correspondences from world to image
 void bwm_observer_mgr::set_world_pt(vgl_point_3d<double> world_pt)
 {
   corr_world_pt_ = world_pt;
   world_point_valid_ = true;
 }
 #endif
-//Set the correspodence mode which is either image_to_image or world_to_image
-//The world_to_image mode is only possible if there is a world point available
-//The existence of a valid world point is defined by the flag
-// world_point_valid_
+
+//: Set the correspondence mode which is either image_to_image or world_to_image
+// The world_to_image mode is only possible if there is a world point available
+// The existence of a valid world point is defined by the flag \a world_point_valid_
 void bwm_observer_mgr::set_corr_mode()
 {
   vgui_dialog params ("Correspondence Mode");
@@ -161,7 +171,7 @@ void bwm_observer_mgr::set_corr_mode()
 
   if (!params.ask())
     return;
-  if (mode ==bwm_observer_mgr::WORLD_TO_IMAGE)
+  if (mode ==bwm_observer_mgr::WORLD_TO_IMAGE) {
     if (bwm_world::instance()->world_pt_valid()) {
       corr_mode_ =  bwm_observer_mgr::WORLD_TO_IMAGE;
       return;
@@ -169,8 +179,9 @@ void bwm_observer_mgr::set_corr_mode()
     else {
       vcl_cout << "In bwm_observer_mgr::set_corr_mode() -\n"
                << " can't use WORLD_TO_IMAGE mode since the 3-d world"
-               << " point is not defined\n";
+               << " point is not defined" << vcl_endl;
     }
+  }
 
   if (t == bwm_observer_mgr::FEATURE_CORR) {
     corr_type_ = bwm_observer_mgr::FEATURE_CORR;
@@ -179,8 +190,7 @@ void bwm_observer_mgr::set_corr_mode()
     corr_type_ = bwm_observer_mgr::TERRAIN_CORR;
   }
   else
-    vcl_cout << "In bwm_observer_mgr::set_corr_mode() Undefined TYPE -\n" ;
-
+    vcl_cout << "In bwm_observer_mgr::set_corr_mode() Undefined TYPE - " << t << vcl_endl;
 
   corr_mode_ = bwm_observer_mgr::IMAGE_TO_IMAGE;
 
@@ -247,13 +257,14 @@ void bwm_observer_mgr::collect_corr()
 
 void bwm_observer_mgr::set_corr(bwm_corr_sptr corr)
 {
-  if (corr->num_matches() > 0)
+  if (corr->num_matches() > 0) {
     if (corr_type_ == FEATURE_CORR) {
       corr_list_.push_back(corr);
     }
     else if (corr_type_ == TERRAIN_CORR) {
       terrain_corr_list_.push_back(corr);
     }
+  }
 }
 
 void bwm_observer_mgr::update_corr(bwm_observer_cam* obs,
@@ -305,10 +316,10 @@ void bwm_observer_mgr::save_corr(vcl_ostream& s)
     vcl_cerr << "No correspondences to save yet!\n";
   else
   {
+#if 0
     vcl_string fname = bwm_utils::select_file();
     vcl_ofstream s(fname.data());
 
-#if 0
     s << "Cameras:" << vcl_endl;
 #endif
     // first write down the camera info
@@ -322,20 +333,20 @@ void bwm_observer_mgr::save_corr(vcl_ostream& s)
 
         // check if that camera is involved with any of the correspondences
         if (obs_in_corr(obs)) {
-          s << "CAM_TAB: " << i << vcl_endl
-            << "IMAGE: " << obs->image_tableau()->file_name() << vcl_endl
-            << "CAMERA_TYPE: " ;
+          s << "CAM_TAB: " << i << '\n'
+            << "IMAGE: " << obs->image_tableau()->file_name() << '\n'
+            << "CAMERA_TYPE: ";
           if (observers_[i]->type_name().compare("bwm_observer_rat_cam") == 0)
             s << "rational" << vcl_endl;
           else if (observers_[i]->type_name().compare("bwm_observer_cam_proj") == 0)
             s << "projective" << vcl_endl;
-          s << "CAMERA_PATH: " << obs->camera_path() << vcl_endl << vcl_endl;
+          s << "CAMERA_PATH: " << obs->camera_path() << '\n' << vcl_endl;
           camera_map[obs] = i;
         }
       }
     }
 
-    s << "CORRESPONDENCES: " << corr_list_.size() << vcl_endl
+    s << "CORRESPONDENCES: " << corr_list_.size() << '\n'
       << "CORR_MODE: ";
     if (corr_mode_ == IMAGE_TO_IMAGE)
       s << "IMAGE_TO_IMAGE" << vcl_endl;
@@ -373,7 +384,7 @@ void bwm_observer_mgr::save_corr_XML()
     vcl_string fname = bwm_utils::select_file();
     vcl_ofstream s(fname.data());
 
-    s << "<BWM_CONFIG>" << vcl_endl
+    s << "<BWM_CONFIG>" << '\n'
       << "<TABLEAUS>" << vcl_endl;
     // first write down the camera info
     vcl_map<bwm_observer_cam*, unsigned> camera_map;
@@ -523,7 +534,7 @@ void bwm_observer_mgr::adjust_camera_offsets()
   vcl_cout << "Executing adjust image offsets\n";
   vcl_vector<vgl_vector_2d<double> > cam_trans;
   vgl_point_3d<double> intersection;
-  if (!vpgl_adjust_rational_trans_onept::adjust(rcams, cpoints, cam_trans,
+  if (!vpgl_rational_adjust_onept::adjust(rcams, cpoints, cam_trans,
                                                 intersection))
   {
     vcl_cerr << "In bwm_observer_rat_cam::adjust_image_offsets - "
@@ -545,14 +556,14 @@ void bwm_observer_mgr::adjust_camera_offsets()
              << intersection.x() << ' ' << intersection.y()
              << ' ' << intersection.z() << ")\n";
     obsrc->shift_camera((*ti).x(), (*ti).y());
-    // here is where we would set the terrain plane an maybe not
+    // here is where we would set the terrain plane and maybe not
     // do anything to the projection plane of each observer.
     // but this approach works for now.
     obsrc->set_proj_plane(world_plane);
     obsrc->update_all();
   }
 
-  //send the objects in the world the fact that they need to redisplay
+  // send the objects in the world the fact that they need to redisplay
   vcl_vector<bwm_observable_sptr> objs = bwm_world::instance()->objects();
   for (vcl_vector<bwm_observable_sptr>::iterator oit = objs.begin();
        oit != objs.end(); ++oit)
@@ -561,7 +572,7 @@ void bwm_observer_mgr::adjust_camera_offsets()
   //
   // now that the 3-d intersection is available, the correspondence mode
   // should be changed to "world_to_image." The mode should only be
-  // chanaged back to "image_to_image" if a new image is added to the
+  // changed back to "image_to_image" if a new image is added to the
   // site and the intersection point is re-computed
   //
   for (vcl_vector<bwm_corr_sptr>::iterator cit = corr_list_.begin();
@@ -607,7 +618,7 @@ void bwm_observer_mgr::find_terrain_points(vcl_vector<vgl_point_3d<double> >& po
     vcl_cout << "Executing adjust image offsets\n";
     vcl_vector<vgl_vector_2d<double> > cam_trans;
     vgl_point_3d<double> intersection;
-    if (!vpgl_adjust_rational_trans_onept::adjust(rcams, cpoints, cam_trans,
+    if (!vpgl_rational_adjust_onept::adjust(rcams, cpoints, cam_trans,
                                                   intersection))
     {
       vcl_cerr << "In bwm_observer_rat_cam::find_terrain_points - "
@@ -618,3 +629,188 @@ void bwm_observer_mgr::find_terrain_points(vcl_vector<vgl_point_3d<double> >& po
   }
   terrain_corr_list_.clear();
 }
+
+//: find all selected polygons across all observers
+vcl_vector<bwm_observable_sptr> bwm_observer_mgr::
+all_selected_observables(vcl_string const& soview_type) const
+{
+  vcl_vector<bwm_observable_sptr> sel_obsbls;
+  vcl_vector<bwm_observer_cam*> obs_cam = this->observers_cam();
+
+  for (vcl_vector<bwm_observer_cam*>::iterator oit = obs_cam.begin();
+       oit != obs_cam.end(); ++oit) {
+    bwm_observer_cam* obs = *oit;
+    if (!obs) {
+    vcl_cout << "null observer in all_selected_observables\n";
+    return sel_obsbls;//empty
+    }
+    vcl_vector<vgui_soview*> soviews = obs->get_selected_soviews();
+    for (vcl_vector<vgui_soview*>::iterator sit = soviews.begin();
+         sit != soviews.end(); ++sit) {
+      if ((*sit)->type_name().compare(soview_type)==0) {
+        unsigned face_id;
+        bwm_observable_sptr obj=(*oit)->find_object(soviews[0]->get_id(),face_id);
+        if (obj) sel_obsbls.push_back(obj);
+      }
+    }
+  }
+  return sel_obsbls;
+}
+
+//: requires exactly two selected vertices each in a unique site
+bool bwm_observer_mgr::add_3d_corr_vertex()
+{
+  // not implemented yet
+  return true;
+}
+
+//: requires exactly two selected polygons each in a unique site. Corresponds centroids of the polygons
+bool bwm_observer_mgr::add_3d_corr_centroid()
+{
+  vcl_vector<bwm_observable_sptr> obs =
+    this->all_selected_observables("bgui_vsol_soview2D_polygon");
+  if (obs.size()!=2) {
+    vcl_cout << "must have exactly two polygons selected\n";
+    return false;
+  }
+  bwm_observable_sptr obs0 = obs[0], obs1 = obs[1];
+  if (obs0->site() == obs1->site()) {
+    vcl_cout << "each polygon must be from a different site\n";
+    return false;
+  }
+  vcl_map<int, vsol_polygon_3d_sptr> polys0 = obs0->extract_faces();
+  vcl_map<int, vsol_polygon_3d_sptr> polys1 = obs1->extract_faces();
+  if (polys0.size() !=1 || polys1.size() !=1) {
+   vcl_cout << "must be exactly 1 polygon in each observable\n";
+    return false;
+  }
+  vcl_map<int, vsol_polygon_3d_sptr>::iterator pit = polys0.begin();
+  vsol_polygon_3d_sptr poly0 = (*pit).second;
+  pit = polys1.begin();
+  vsol_polygon_3d_sptr poly1 = (*pit).second;
+  unsigned n0 = poly0->size(), n1 = poly1->size();
+  if (!n0||!n1) {
+   vcl_cout << "poly with no vertices in add_3d_corr";
+    return false;
+  }
+  double xc0 = 0.0, yc0 = 0.0, zc0 = 0.0;
+  double xc1 = 0.0, yc1 = 0.0, zc1 = 0.0;
+  for (unsigned i = 0; i<n0; ++i) {
+    vsol_point_3d_sptr vi = poly0->vertex(i);
+    xc0 += (*vi).x(); yc0 += (*vi).y(); zc0 += (*vi).z();
+  }
+  for (unsigned i = 0; i<n0; ++i) {
+    vsol_point_3d_sptr vi = poly1->vertex(i);
+    xc1 += (*vi).x(); yc1 += (*vi).y(); zc1 += (*vi).z();
+  }
+  bwm_3d_corr_sptr corr_3d = new bwm_3d_corr();
+  corr_3d->set_match(obs0->site(), xc0/n0, yc0/n0, zc0/n0);
+  corr_3d->set_match(obs1->site(), xc1/n1, yc1/n1, zc1/n1);
+  site_to_site_corr_list_.push_back(corr_3d);
+  return true;
+}
+
+//: save 3d_corrs
+void bwm_observer_mgr::save_3d_corrs() const
+{
+  vcl_string path = "";
+  vcl_string ext = "*.cor";
+  vgui_dialog corr_dlg("Save 3d Correspondences");
+  corr_dlg.file("Corr file", ext, path);
+  if (!corr_dlg.ask())
+    return;
+  bwm_observer_mgr::save_3d_corrs(path, site_to_site_corr_list_);
+}
+
+void bwm_observer_mgr::save_3d_corrs(vcl_string const& path,
+                                     vcl_vector<bwm_3d_corr_sptr> const& corrs)
+{
+  vcl_ofstream os(path.c_str());
+  if (!os.is_open())
+  {
+    vcl_cout << "couldn't open 3d_corr file path\n";
+    return ;
+  }
+  unsigned n = corrs.size();
+  if (!n) {
+    vcl_cout << "no 3d_corrs to save\n";
+    return ;
+  }
+  os << "Ncorrs: " << n << '\n';
+  for (unsigned i = 0; i<n; ++i)
+    os << *corrs[i];
+}
+
+//: load 3d_corrs
+void bwm_observer_mgr::load_3d_corrs()
+{
+  vcl_string path = "";
+  vcl_string ext = "*.cor";
+  vgui_dialog corr_dlg("Load 3d Correspondences");
+  corr_dlg.file("Corr file", ext, path);
+  if (!corr_dlg.ask())
+    return;
+  bwm_observer_mgr::load_3d_corrs(path, site_to_site_corr_list_);
+}
+
+void bwm_observer_mgr::load_3d_corrs(vcl_string const& path,
+                                     vcl_vector<bwm_3d_corr_sptr>& corrs)
+{
+  vcl_ifstream is(path.c_str());
+  if (!is.is_open())
+  {
+    vcl_cout << "couldn't open 3d_corr file path\n";
+    return ;
+  }
+  //clear out any existing correspondences
+  corrs.clear();
+  vcl_string temp, temp1, temp2;
+  is >> temp;
+  if (temp!="Ncorrs:") {
+    vcl_cout << "error in 3d_corr file\n";
+    return;
+  }
+  unsigned n_corrs = 0;
+  is >> n_corrs;
+  for (unsigned i = 0; i<n_corrs; ++i) {
+    is >> temp >> temp1 >> temp2;
+    if (temp2!="Sites:") {
+      vcl_cout << "error in 3d_corr file\n";
+      return;
+    }
+    unsigned n_sites = 0;
+    is >> n_sites;
+    double x = 0.0, y = 0.0, z = 0.0;
+    vcl_string site;
+    bwm_3d_corr_sptr corr = new bwm_3d_corr();
+    for (unsigned s = 0; s<n_sites; ++s) {
+      is >> temp >> temp1;
+      if (temp != "Site[") {
+        vcl_cout << "error in 3d_corr file\n";
+        return;
+      }
+      site = temp1;
+      is >> temp >> temp1;
+      if (temp1 != "X:") {
+        vcl_cout << "error in 3d_corr file\n";
+        return;
+      }
+      is >> x;
+      is >> temp;
+      if (temp != "Y:") {
+        vcl_cout << "error in 3d_corr file\n";
+        return;
+      }
+      is >> y;
+      is >> temp;
+      if (temp != "Z:") {
+        vcl_cout << "error in 3d_corr file\n";
+        return;
+      }
+      is >> z;
+      is >> temp;//eat up the trailing ")"
+      corr->set_match(site, x, y, z);
+    }
+    corrs.push_back(corr);
+  }
+}
