@@ -7,30 +7,28 @@
 #include "bwm_observer_cam.h"
 #include "bwm_tableau_img.h"
 
-#include <vcl_string.h>
-
 #include <vgui/vgui_menu.h>
 #include <vgui/vgui_event.h>
 #include <vgui/vgui_command.h>
 
 #include <bgui/bgui_picker_tableau.h>
 
-#include <vpgl/vpgl_camera.h>
-
 #include <vsol/vsol_point_3d_sptr.h>
 
+#include <vcl_string.h>
+
 class bwm_tableau_cam : public bwm_tableau_img
 {
  public:
   typedef enum {RATIONAL=0, PROJECTIVE=1} BWM_CAMERA_TYPES;
-  
+
   //: destructor
   // Tableaux are responsible for deleting their observers
-  virtual ~bwm_tableau_cam(){ delete my_observer_; }
+  virtual ~bwm_tableau_cam() { delete my_observer_; }
 
   virtual vcl_string type_name() const { return "bwm_tableau_cam"; }
 
-  bool bwm_tableau_cam::handle(const vgui_event& e);
+  bool handle(const vgui_event& e);
 
   void set_observer(bwm_observer_cam* obs) { my_observer_ = obs;}
 
@@ -58,7 +56,7 @@ class bwm_tableau_cam : public bwm_tableau_img
   //: draws a line onto a given face, dividing into two faces
   void divide_face();
 
-  //: Draws the hostogram on a graph (if the image is greyscale)
+  //: Draws the histogram on a graph (if the image is greyscale)
   void hist_plot();
 
   void set_corr(double X, double Y);
@@ -81,9 +79,13 @@ class bwm_tableau_cam : public bwm_tableau_img
 
   void local_position_vertex();
 
+  void scroll_to_point(double lx, double ly, double lz);
+
   void create_terrain();
 
   void create_circular_polygon();
+
+  void project_shadow();
   //------------ save methods
 
   //: saves the observables with their save method specific to the object
@@ -128,14 +130,16 @@ class bwm_tableau_cam : public bwm_tableau_img
   void set_face_mode() { my_observer_->set_face_mode(); }
   void set_edge_mode() { my_observer_->set_edge_mode(); }
   void set_vertex_mode() { my_observer_->set_vertex_mode(); }
-
+#if 0
+  void create_boxm_scene() { my_observer_->create_boxm_scene(); }
+  void load_boxm_scene() { my_observer_->load_boxm_scene(); }
+#endif
   bool show_vertices_;
 
  protected:
   bwm_observer_cam* my_observer_;
-  bwm_tableau_cam(bwm_observer_cam* obs) 
+  bwm_tableau_cam(bwm_observer_cam* obs)
     : bwm_tableau_img(obs), my_observer_(obs) {}
-  
 };
 
 #endif
