@@ -1,6 +1,7 @@
 #ifndef bwm_tableau_proj_cam_h_
 #define bwm_tableau_proj_cam_h_
-
+//:
+// \file
 #include "bwm_tableau_cam.h"
 #include "bwm_observer_proj_cam.h"
 
@@ -10,8 +11,7 @@
 #include <vgui/vgui_command.h>
 
 #include <bgui/bgui_picker_tableau.h>
-
-#include <vpgl/vpgl_proj_camera.h>
+#include <vul/vul_timer.h>
 
 class bwm_tableau_proj_cam : public bwm_tableau_cam
 {
@@ -28,10 +28,12 @@ class bwm_tableau_proj_cam : public bwm_tableau_cam
 
   void get_popup(vgui_popup_params const &params, vgui_menu &menu);
 
+  //: saves the camera with a new version number (if adjusted) and returns the path
+  vcl_string save_camera();
+
  protected:
-  vpgl_proj_camera<double> camera_;
   bwm_observer_proj_cam* my_observer_;
- 
+  vul_timer timer_; 
 };
 
 #endif
