@@ -20,6 +20,8 @@ class bwm_tableau_video : public bwm_tableau_cam
 
   bool handle(const vgui_event &);
 
+  virtual void clear_all_frames();
+
   //video actions
   void get_popup(vgui_popup_params const &params, vgui_menu &menu);
   void next_frame();
@@ -39,11 +41,15 @@ class bwm_tableau_video : public bwm_tableau_cam
   void display_video_corrs();
   void display_current_video_corrs();
   void clear_video_corrs_display();
+  void toggle_corr_display();
   void toggle_world_pt_display();
+  void display_selected_world_pt();
   void extract_world_plane();
   void extract_neighborhoods();
   void extract_histograms();
+  void set_world_pt();
   void set_corrs(vcl_vector<bwm_video_corr_sptr> const& corrs) { my_observer_->set_corrs(corrs); }
+  void add_match_at_vertex();
 protected:
   bwm_observer_video* my_observer_;
 };
