@@ -11,7 +11,7 @@
 #include <vcl_string.h>
 
 #include <vgl/vgl_vector_3d.h>
-#include <vpgl/bgeo/bgeo_lvcs.h>
+#include <vpgl/vpgl_lvcs.h>
 
 class bwm_texture_map_generator
 {
@@ -20,10 +20,10 @@ class bwm_texture_map_generator
   bwm_texture_map_generator() {observers_ = bwm_observer_mgr::instance()->observers_rat_cam();}
 
   //: generate the texture map
-  bool generate_texture_map(bwm_observable_mesh_sptr obj, vcl_string texture_filename, bgeo_lvcs lvcs);
+  bool generate_texture_map(bwm_observable_mesh_sptr obj, vcl_string texture_filename, vpgl_lvcs lvcs);
 
  private:
-  vgl_vector_3d<double> compute_face_normal_lvcs(bmsh3d_face* face, bgeo_lvcs lvcs);
+  vgl_vector_3d<double> compute_face_normal_lvcs(bmsh3d_face* face, vpgl_lvcs lvcs);
 
   vcl_vector<bwm_observer_rat_cam*> observers_;
 };
