@@ -31,7 +31,19 @@ void  bwm_world::set_world_pt(vgl_point_3d<double> const& pt)
   world_plane_ = vgl_plane_3d<double>(normal, pt);
   world_pt_valid_ = true;
 }
-
+// adds an observable to the world
+bool bwm_world::add(bwm_observable_sptr obj)
+{
+  // find the object
+  vcl_vector<bwm_observable_sptr>::iterator it = objects_.begin();
+  while (it != objects_.end()) {
+    if (*it == obj)
+      return false;
+    ++it;
+  }
+  objects_.push_back(obj); 
+  return true;
+}
 // removes an observable from the world
 bool bwm_world::remove(bwm_observable_sptr obj)
 {
@@ -44,36 +56,36 @@ bool bwm_world::remove(bwm_observable_sptr obj)
     }
     it++;
   }
-  return true;
+  return false; // object was not in the world
 }
 
 void bwm_world::set_lvcs(double lat, double lon, double elev)
 {
   // clean up the olde one, if any
-  lvcs_ = bgeo_lvcs(lat, lon, elev);
+  lvcs_ = vpgl_lvcs(lat, lon, elev);
   lvcs_valid_ = true;
 }
 
-bool bwm_world::get_lvcs(bgeo_lvcs &lvcs)
+bool bwm_world::get_lvcs(vpgl_lvcs &lvcs)
 {
   vgl_point_3d<double> center;
 
-#if 0 // commented out
+
   // if lvcs is set get that
   if (lvcs_valid_) {
     lvcs = lvcs_;
     return true;
   }
-
+#if 0 // commented out
   // else, create from the world point
   else if (world_pt_valid_) {
-    lvcs = bgeo_lvcs(world_pt_.x(), world_pt_.y(), world_pt_.z());
+    lvcs = vpgl_lvcs(world_pt_.x(), world_pt_.y(), world_pt_.z());
     return true;
   }
 
   // get from the tableau mgr, as the avg of the camera centers
   else if (bwm_observer_mgr::instance()->comp_avg_camera_center(center)) {
-    lvcs = bgeo_lvcs(center.x(), center.y(), center.z());
+    lvcs = vpgl_lvcs(center.x(), center.y(), center.z());
     return true;
   }
 #endif // 0
@@ -87,7 +99,8 @@ bool bwm_world::get_lvcs(bgeo_lvcs &lvcs)
   lvcs_dialog.field("Elevation:", elev);
   if (!lvcs_dialog.ask())
     return false;
-  lvcs = bgeo_lvcs(lat, lon, elev);
+  lvcs_ = vpgl_lvcs(lat, lon, elev);
+  lvcs_valid_ = true;
   return true;
 }
 
@@ -248,7 +261,7 @@ void bwm_world::save_gml()
 
 void bwm_world::save_kml()
 {
-  bgeo_lvcs lvcs;
+  vpgl_lvcs lvcs;
   if (!get_lvcs(lvcs)) {
     vcl_cerr << "Error: lvcs not defined.\n";
     return;
@@ -305,7 +318,7 @@ void bwm_world::save_kml()
 
 void bwm_world::save_x3d()
 {
-  bgeo_lvcs lvcs;
+  vpgl_lvcs lvcs;
   if (!get_lvcs(lvcs)) {
     vcl_cerr << "Error: lvcs not defined.\n";
     return;
@@ -349,7 +362,7 @@ void bwm_world::save_x3d()
 
 void bwm_world::save_kml_collada()
 {
-  bgeo_lvcs lvcs;
+  vpgl_lvcs lvcs;
   if (!get_lvcs(lvcs)) {
     vcl_cerr << "Error: lvcs not defined.\n";
     return;
@@ -375,7 +388,7 @@ void bwm_world::save_kml_collada()
 
   params.field("model name",model_name);
   params.field("ground height",ground_height);
-  params.field("lattitude offset",lat_offset);
+  params.field("latitude offset",lat_offset);
   params.field("longitude offset",lon_offset);
 
   params.file("Save...",ext,kmz_dir);
