@@ -29,16 +29,17 @@ class bwm_video_corr : public vbl_ref_count
   // Constructors/Initializers/Destructors-------------------------------------
 
   //: Constructor - default
-  bwm_video_corr() : observer_(0), world_pt_valid_(false), id_(unique_id_++) {}
+  bwm_video_corr() : id_(unique_id_++), observer_(0), world_pt_valid_(false) {}
 
   //: Constructor - from data
   bwm_video_corr(bwm_observer_video* obs, unsigned frame_index,
-                 vgl_point_2d<double> const& pt): observer_(obs),
-    world_pt_valid_(false), id_(unique_id_++)
-    { matches_[frame_index]=pt; }
+                 vgl_point_2d<double> const& pt)
+  : id_(unique_id_++), observer_(obs), world_pt_valid_(false)
+  { matches_[frame_index]=pt; }
 
   //: Constructor - don't copy the ref count
-  bwm_video_corr(bwm_video_corr const& c) : vbl_ref_count() {}
+  bwm_video_corr(bwm_video_corr const& c)
+  : vbl_ref_count(), world_pt_valid_(c.world_pt_valid()), world_pt_(c.world_pt()) {}
 
   // Destructor
   ~bwm_video_corr() {}
@@ -54,6 +55,9 @@ class bwm_video_corr : public vbl_ref_count
 
   //: is there a match for the specified frame
   bool match(unsigned frame);
+  
+  //: return matches map
+  vcl_map<unsigned, vgl_point_2d<double> >& matches() { return matches_; }
 
   //: add a match
   bool add(unsigned frame, vgl_point_2d<double> const& pt);
@@ -64,7 +68,9 @@ class bwm_video_corr : public vbl_ref_count
   //: Number of matches assigned, i.e. number of matched video frames.
   unsigned num_matches() const { return matches_.size(); }
 
+  //: A unique id
   unsigned id() const { return id_; }
+  void set_id(unsigned id){id_ = id;}
 
   //: the lowest frame number for which there is a match
   unsigned min_frame();
@@ -82,6 +88,11 @@ class bwm_video_corr : public vbl_ref_count
   vgl_point_3d<double> world_pt() const { return world_pt_; }
 
   bool world_pt_valid() const { return world_pt_valid_; }
+  
+  //: set 3-d point intensity
+  void set_intensity(vgl_vector_3d<int> const& intensity)
+  { intensity_ = intensity; }
+  vgl_vector_3d<int> intensity() { return intensity_; }
 
   //: Write the correspondence as xml
   void x_write(vcl_ostream &os);
@@ -98,6 +109,7 @@ class bwm_video_corr : public vbl_ref_count
   vcl_map<unsigned, vgl_point_2d<double> > matches_; // match in each frame
   bool world_pt_valid_;
   vgl_point_3d<double> world_pt_;
+  vgl_vector_3d<int>   intensity_; 
 };
 
 #include <bwm/video/bwm_video_corr_sptr.h>
