@@ -1,15 +1,15 @@
 #include "bwm_video_corr_processor.h"
-
+//:
+// \file
 #include <bwm/video/bwm_video_site_io.h>
 #include <bwm/video/bwm_video_corr.h>
-#include <vcl_cmath.h>
 #include <vnl/vnl_numeric_traits.h>
 #include <vnl/vnl_double_3.h>
 #include <vnl/algo/vnl_levenberg_marquardt.h>
 #include <vnl/algo/vnl_amoeba.h>
 #include <vul/vul_file.h>
 #include <vpl/vpl.h> // vpl_unlink()
-#include <vpgl/algo/vpgl_interpolate.h>
+#include <bpgl/algo/bpgl_interpolate.h>
 #include <vpgl/algo/vpgl_bundle_adjust.h>
 #include <vgl/vgl_point_2d.h>
 #include <vgl/vgl_homg_point_3d.h>
@@ -23,8 +23,16 @@
 #include <vidl/vidl_frame.h>
 #include <vidl/vidl_convert.h>
 #include <vidl/vidl_image_list_istream.h>
+
+#include <vpgl/vpgl_lvcs.h>
+
+#include <vcl_cmath.h>
+#include <vcl_cstdio.h> // for std::sprintf
+
 //Minimum number of correspondences on a frame to compute cameras
-static const unsigned min_corrs = 10;
+//static const unsigned min_corrs = 10;
+//static const unsigned min_corrs = 9;
+static const unsigned min_corrs = 6;
 // if an element of pixels is negative it indicates the point was outside the
 // image
 static void extract_window(float u, float v, int radius,
@@ -39,7 +47,7 @@ static void extract_window(float u, float v, int radius,
     for (float ui = umin; ui<=umax; ++ui)
       if (ui<0||vi<0||ui>=ni||vi>=nj)
         pixels.push_back(-1.0f);
-      else{
+      else {
         double val = brip_vil_float_ops::bilinear_interpolation(image, ui, vi);
         pixels.push_back(static_cast<float>(val));
       }
@@ -61,7 +69,7 @@ bwm_video_corr_lsqr_cost_func(vil_image_view<float> const& base_image,
 
 //the least squares cost function for minimizing intensity differences
 // x is a 2 element vector for correspondence position
-// f is an  M-element vector, where M = (2*match_radius_+1)^2
+// f is an M-element vector, where M = (2*match_radius_+1)^2
 // i.e. a window around each projected world point.
 void bwm_video_corr_lsqr_cost_func::f(vnl_vector<double> const& x,
                                       vnl_vector<double>& fx)
@@ -131,8 +139,13 @@ open_camera_istream(vcl_string const& camera_path)
     return false;
   cam_istr_ = new bwm_video_cam_istream(camera_path);
   bool open = cam_istr_->is_open();
-  if (open)
+  if (open) {
+    vcl_cout << "in bwm_video_corr_processor::open_camera_istream() -- input stream: " << camera_path << " is opened!\n";
     cam_istr_->seek_camera(0);
+  }
+  else {
+    vcl_cout << "in bwm_video_corr_processor::open_camera_istream() -- input stream: " << camera_path << " can NOT be opened!\n";
+  }
   return open;
 }
 
@@ -143,9 +156,26 @@ open_camera_ostream(vcl_string const& camera_path)
     return false;
   cam_ostr_ = new bwm_video_cam_ostream(camera_path);
   bool open = cam_ostr_->is_open();
+  if (open) {
+    vcl_cout << "in bwm_video_corr_processor::open_camera_ostream() -- output stream: " << camera_path << " is opened!\n";
+  }
+  else {
+    vcl_cout << "in bwm_video_corr_processor::open_camera_ostream() -- output stream: " << camera_path << " can NOT be opened!\n";
+  }
   return open;
 }
 
+void bwm_video_corr_processor::close_camera_ostream()
+{
+  cam_ostr_->close();
+}
+
+void bwm_video_corr_processor::close_camera_istream()
+{
+  cam_istr_->close();
+}
+
+
 void remove_dir(vcl_string const& dir)
 {
   vcl_string glob = dir + "/*";
@@ -167,7 +197,8 @@ bool bwm_video_corr_processor::open_video_site(vcl_string const& site_path,
   if (cameras_exist){
     if (!this->open_camera_istream(camera_path_))
       return false;
-  }else{
+  }
+  else {
     vcl_string dir = vul_file::dirname(site_path)+"/cameras";
     if (vul_file::exists(dir))
       remove_dir(dir);
@@ -183,23 +214,43 @@ bool bwm_video_corr_processor::open_video_site(vcl_string const& site_path,
   this->set_correspondences(corrs);
   return true;
 }
+
 void bwm_video_corr_processor::
 set_world_pts(vcl_vector<vgl_point_3d<double> > const& pts)
 {
   vcl_vector<vgl_point_3d<double> >::const_iterator pit = pts.begin();
-  for(vcl_vector<bwm_video_corr_sptr>::iterator cit = corrs_.begin();
-      cit != corrs_.end()&&pit!=pts.end(); ++cit, ++pit)
+  for (vcl_vector<bwm_video_corr_sptr>::iterator cit = corrs_.begin();
+       cit != corrs_.end()&&pit!=pts.end(); ++cit, ++pit)
     (*cit)->set_world_pt(*pit);
 }
+
 vcl_vector<vgl_point_3d<double> > bwm_video_corr_processor::world_pts()
 {
   vcl_vector<vgl_point_3d<double> > pts;
-  for(vcl_vector<bwm_video_corr_sptr>::iterator cit = corrs_.begin();
-      cit != corrs_.end(); ++cit)
-    if((*cit)->world_pt_valid())
+  for (vcl_vector<bwm_video_corr_sptr>::iterator cit = corrs_.begin();
+       cit != corrs_.end(); ++cit)
+    if ((*cit)->world_pt_valid())
       pts.push_back((*cit)->world_pt());
   return pts;
 }
+
+//: if the world coordinates are given in global coordinates of satellite cameras, convert them to local coordinate frame of the given lvcs
+void bwm_video_corr_processor::convert_world_pts_to_local(vpgl_lvcs_sptr lvcs)
+{
+  for (vcl_vector<bwm_video_corr_sptr>::iterator cit = corrs_.begin();
+       cit != corrs_.end(); ++cit)
+  {
+    if ((*cit)->world_pt_valid()) {
+      vgl_point_3d<double> pt = (*cit)->world_pt();
+      double x,y,z;
+      lvcs->global_to_local(pt.x(), pt.y(), pt.z(), lvcs->get_cs_name(), x,y,z);
+      vgl_point_3d<double> new_pt(x,y,z);
+      vcl_cout << "world pt: " << pt << " converted to " << new_pt << vcl_endl;
+      (*cit)->set_world_pt(new_pt);
+    }
+  }
+}
+
 bool bwm_video_corr_processor::write_video_site(vcl_string const& site_path)
 {
   if (site_name_ == "")
@@ -213,6 +264,26 @@ bool bwm_video_corr_processor::write_video_site(vcl_string const& site_path)
   return true;
 }
 
+void bwm_video_corr_processor::write_cameras_txt(vcl_string const& cam_txt_dir, vcl_vector<vpgl_perspective_camera<double> > const& cameras)
+{
+  char filename[1024];
+  if (vul_file::is_directory(cam_txt_dir.c_str()))
+  {
+    vcl_cout << "writing " << cameras.size() << " cams to: " << cam_txt_dir << vcl_endl;
+    for (unsigned i=0;i<cameras.size();i++)
+    {
+      vcl_sprintf(filename,"%s/camera%05d.txt",cam_txt_dir.c_str(),i);
+      vcl_ofstream ofile(filename);
+      if (ofile)
+      {
+        ofile<<cameras[i].get_calibration().get_matrix()<<'\n'
+             <<cameras[i].get_rotation().as_matrix()<<'\n'
+             <<cameras[i].get_translation().x()<<' '<<cameras[i].get_translation().y()<<' '<<cameras[i].get_translation().z()<<'\n';
+      }
+    }
+  }
+}
+
 bool bwm_video_corr_processor::
 interpolate_cameras(vcl_vector<vpgl_perspective_camera<double> > known_cams,
                     vcl_vector<bool> unknown,
@@ -274,7 +345,7 @@ interpolate_cameras(vcl_vector<vpgl_perspective_camera<double> > known_cams,
       if (verbose_)
         vcl_cout << "Interpolating between frames[" << fi-1
                  << ':' << ki-1 << "]\n";
-      if (!vpgl_interpolate::interpolate(c0, c1, n_interp, icams))
+      if (!bpgl_interpolate::interpolate(c0, c1, n_interp, icams))
       {
         vcl_cerr << "Interpolation failed\n";
         return false;
@@ -312,21 +383,24 @@ void min_max_frame(vcl_vector<bwm_video_corr_sptr> const& corrs,
     }
 }
 
-//
-//compute the mask on existing correspondences
-//the mask is m x n , where m = number of cameras and
-//n = number of world points (corrs)
-//
+//: return the number of cameras that observe the correspondences
+unsigned bwm_video_corr_processor::get_ncameras(unsigned& min_frame, unsigned& max_frame) const
+{
+  min_frame =0; max_frame = 0;
+  //get the start and end frame numbers. assume contiguous frames inbetween
+  min_max_frame(corrs_, min_frame, max_frame);
+  if (verbose_)
+    vcl_cout << "Start frame = " << min_frame << " End frame = " << max_frame << '\n';
+  return max_frame-min_frame +1;
+}
+
+//: compute the mask on existing correspondences
+// The mask is m x n , where m = number of cameras and
+// n = number of world points (corrs)
 void bwm_video_corr_processor::mask(unsigned& min_frame, unsigned& max_frame,
                                     vcl_vector<vcl_vector<bool> >& mask)
 {
-  //get the start and end frame numbers. assume contiguous frames inbetween
-  min_frame =0, max_frame = 0;
-  min_max_frame(corrs_, min_frame, max_frame);
-  if (verbose_)
-    vcl_cout << "Start frame = " << min_frame << " End frame = "
-             << max_frame << '\n';
-  unsigned ncameras = max_frame-min_frame +1;
+  unsigned ncameras = get_ncameras(min_frame, max_frame);
   unsigned npoints = corrs_.size();
   vcl_vector<bool> init(npoints);
   mask.resize(ncameras, init);
@@ -432,11 +506,11 @@ initialize_world_pts_and_cameras(vpgl_calibration_matrix<double> const& K,
   vgl_point_3d<double> pun(0.0, 0.0, 0.0);
   vcl_vector<vgl_point_3d<double> > unknown_world(npoints,pun);
 
-  // exectute the bundle adjustment
+  // execute the bundle adjustment
   vpgl_bundle_adjust adj;
-  bool success = adj.optimize(unknown_cameras,
-                              unknown_world, cimage_points,
-                              cmask);
+  /*bool success=*/ adj.optimize(unknown_cameras,
+                                 unknown_world, cimage_points,
+                                 cmask);
   //save the solved world points in the correspondences
   for (unsigned w = 0; w<npoints; ++w)
   {
@@ -809,7 +883,7 @@ bool bwm_video_corr_processor::refine_world_pts_and_cameras()
 
   //next populate the image points and the mask array
   //the mask appears to be m x n ,
-  // where m = number of cameras an n = number of world points (corrs)
+  // where m = number of cameras and n = number of world points (corrs)
   //
   vcl_vector<vgl_point_2d<double> > image_points(ncameras*npoints);
   for (unsigned w = 0; w<npoints; ++w)
@@ -868,11 +942,11 @@ bool bwm_video_corr_processor::refine_world_pts_and_cameras()
     if (corrs_[w]->world_pt_valid())
       unknown_world[w]=corrs_[w]->world_pt();
 
-  // exectute the bundle adjustment
+  // execute the bundle adjustment
   vpgl_bundle_adjust adj;
-  bool success = adj.optimize(unknown_cameras,
-                              unknown_world, cimage_points,
-                              cmask);
+  /*bool success=*/ adj.optimize(unknown_cameras,
+                                 unknown_world, cimage_points,
+                                 cmask);
   //save the solved world points in the correspondences
   for (unsigned w = 0; w<npoints; ++w)
   {
@@ -883,6 +957,7 @@ bool bwm_video_corr_processor::refine_world_pts_and_cameras()
   if (!this->interpolate_cameras(unknown_cameras, unknown_frames,
                                  interp_cameras))
     return false;
+  cameras_ = interp_cameras;
   // close the input camera stream
   if (cam_ostr_&&cam_ostr_->is_open())
     for (unsigned i = 0; i<ncameras; ++i)
