@@ -7,7 +7,10 @@
 DECLARE_FUNC_CONS(bsvg_plot_roc_process);
 DECLARE_FUNC_CONS(bsvg_bar_plot_initialize_process);
 DECLARE_FUNC_CONS(bsvg_bar_plot_add_process);
-DECLARE_FUNC_CONS(bsvg_bar_plot_write_process);
+DECLARE_FUNC_CONS(bsvg_plot_write_process);
+DECLARE_FUNC_CONS(bsvg_plot_roc_process2);
+DECLARE_FUNC_CONS(bsvg_plot_initialize_process);
+DECLARE_FUNC_CONS(bsvg_roc_plot_add_process);
 
 #endif  // bsvg_processes_h_
 
