@@ -112,9 +112,39 @@ class bxml_element : public bxml_data
     s >> value;
     return true;
   }
+  
+  
+  //: Return the values of all attributes with a given name
+  vcl_vector<vcl_string> attributes(const vcl_string& attr_name) const;
+  
+  //: Specialization for vcl_string.
+  bool get_attributea(const vcl_string& attr_name, vcl_vector<vcl_string>& values) const
+  {
+    values = this->attributes(attr_name);
+    return true;
+  }
+  
+  //: Return the value of an attribute.
+  // \see specialization for vcl_string.
+  template <class T>
+  bool get_attributes(const vcl_string& attr_name, vcl_vector<T>& values) const
+  {
+    values.clear();
+    vcl_vector<vcl_string> values_str = attributes(attr_name);
+    for (unsigned vi=0; vi<values_str.size(); vi++) {
+      vcl_stringstream s(values_str[vi]);
+      if (s.str() == "")
+        return false;
+      T value_t;
+      s >> value_t;
+      values.push_back(value_t);
+      
+    }
+    return true;
+  }
 
   //: Return the number of attributes
-  unsigned int num_attributes() const { return attributes_.size(); }
+  unsigned int num_attributes() const { return (unsigned int)attributes_.size(); }
 
   //: An iterator to the beginning of the attributes
   const_attr_iterator attr_begin() const { return attributes_.begin(); }
@@ -123,7 +153,7 @@ class bxml_element : public bxml_data
   const_attr_iterator attr_end() const { return attributes_.end(); }
 
   //: Return the number of data nodes
-  unsigned int num_data() const { return data_.size(); }
+  unsigned int num_data() const { return (unsigned int)data_.size(); }
 
   //: An iterator to the beginning of the data
   const_data_iterator data_begin() const { return data_.begin(); }
@@ -138,17 +168,18 @@ class bxml_element : public bxml_data
   void append_data(const bxml_data_sptr& el)
   { data_.push_back(el); }
 
-  void set_attribute(const vcl_string& attr_name, const vcl_string& attr_value)
-  { attributes_[attr_name] = attr_value; }
-
-  //: \see specialization for vcl_string below.
+  //: Set attribute with and optional precision.
   template <class T>
-  void set_attribute(const vcl_string& attr_name, const T& attr_value)
+  void set_attribute(const vcl_string& attr_name, const T& attr_value, unsigned p = 5)
   {
     vcl_stringstream s;
+    s.precision(p);
     s << attr_value;
     attributes_[attr_name] = s.str();
   }
+  //: Specialization for vcl_string below.
+  void set_attribute(const vcl_string& attr_name, const vcl_string& attr_value)
+  { attributes_[attr_name] = attr_value; }
 
  private:
   //: The name of the element
