@@ -77,7 +77,7 @@ imesh_project_verts(const imesh_vertex_array<3>& verts3d,
 
 void
 imesh_distort_verts(const vcl_vector<vgl_point_2d<double> >& in_verts,
-                    const vpgl_lens_distortion<double>& lens,
+                    const bpgl_lens_distortion<double>& lens,
                     vcl_vector<vgl_point_2d<double> >& out_verts)
 {
   out_verts.resize(in_verts.size());
@@ -86,7 +86,7 @@ imesh_distort_verts(const vcl_vector<vgl_point_2d<double> >& in_verts,
 }
 
 
-//: Render a triangle defined by it's vertices
+//: Render a triangle defined by its vertices
 void imesh_render_triangle(const vgl_point_2d<double>& v1,
                            const vgl_point_2d<double>& v2,
                            const vgl_point_2d<double>& v3,
@@ -223,7 +223,7 @@ imesh_render_faces_interp(const imesh_mesh& mesh,
 //  Set each pixel of the image to true if the mesh project onto it
 void imesh_project(const imesh_mesh& mesh,
                    const vpgl_proj_camera<double>& camera,
-                   const vpgl_lens_distortion<double>& lens,
+                   const bpgl_lens_distortion<double>& lens,
                    vil_image_view<bool>& image)
 {
   assert(mesh.vertices().dim() == 3);
@@ -242,7 +242,7 @@ void imesh_project(const imesh_mesh& mesh,
 void imesh_project(const imesh_mesh& mesh,
                    const vcl_vector<vgl_vector_3d<double> >& normals,
                    const vpgl_proj_camera<double>& camera,
-                   const vpgl_lens_distortion<double>& lens,
+                   const bpgl_lens_distortion<double>& lens,
                    vil_image_view<bool>& image,
                    vgl_box_2d<unsigned int>* bbox)
 {
@@ -491,7 +491,7 @@ int imesh_project_onto_mesh_barycentric(const imesh_mesh& mesh,
 //: back project an image point onto the mesh using the camera
 //  Then project from the mesh into normalized texture coordinate (UV)
 //  Assumes the mesh has both normals and texture coordinates
-//  \returns the index of the itersected triangle, or -1 for no intersection
+//  \returns the index of the intersected triangle, or -1 for no intersection
 int imesh_project_onto_mesh_texture(const imesh_mesh& mesh,
                                     const vcl_vector<vgl_point_2d<double> >& verts2d,
                                     const vpgl_perspective_camera<double>& camera,
@@ -538,7 +538,7 @@ int imesh_project_onto_mesh_texture(const imesh_mesh& mesh,
 
 
 //: project a texture point onto a mesh face index with barycentric coordinates
-//  \returns the index of the itersected triangle, or -1 for no intersection
+//  \returns the index of the intersected triangle, or -1 for no intersection
 int imesh_project_texture_to_barycentric(const imesh_mesh& mesh,
                                          const vgl_point_2d<double>& pt_2d,
                                          vgl_point_2d<double>& pt_uv)
@@ -921,6 +921,38 @@ imesh_project_texture_to_3d_map(const imesh_mesh& mesh, unsigned int tidx)
 }
 
 
+//: compute the affine matrix that maps triangle (a1,b1,c1) to (a2,b2,c2)
+vnl_matrix_fixed<double,3,3>
+imesh_affine_map(const vgl_point_2d<double>& a1,
+                 const vgl_point_2d<double>& b1,
+                 const vgl_point_2d<double>& c1,
+                 const vgl_point_2d<double>& a2,
+                 const vgl_point_2d<double>& b2,
+                 const vgl_point_2d<double>& c2)
+{
+  // triangle 1 to barycentric coordinates
+  vnl_matrix_fixed<double,3,3> M1;
+  {
+    vgl_vector_2d<double> v1(b1-a1), v2(c1-a1);
+    double s = 1.0 / (v2.y()*v1.x() - v2.x()*v1.y());
+    M1(0,0) = v2.y()*s;   M1(0,1) = -v2.x()*s;   M1(0,2) = (a1.y()*c1.x()-a1.x()*c1.y())*s;
+    M1(1,0) = -v1.y()*s;  M1(1,1) = v1.x()*s;    M1(1,2) = (a1.x()*b1.y()-a1.y()*b1.x())*s;
+    M1(2,0) = 0.0;        M1(2,1) = 0.0;         M1(2,2) = 1.0;
+  }
+
+  // barycentric coordinates to triangle 2
+  vnl_matrix_fixed<double,3,3> M2;
+  {
+    vgl_vector_2d<double> v1(b2-a2), v2(c2-a2);
+    M2(0,0) = v1.x();   M2(0,1) = v2.x();   M2(0,2) = a2.x();
+    M2(1,0) = v1.y();   M2(1,1) = v2.y();   M2(1,2) = a2.y();
+    M2(2,0) = 0.0;      M2(2,1) = 0.0;      M2(2,2) = 1.0;
+  }
+
+  return M2*M1;
+}
+
+
 //: project barycentric coordinates with an index to texture space
 //  \param idx is the face index
 vgl_point_2d<double>
