@@ -16,27 +16,27 @@ class bprb_null_process : public bprb_process
 {
  public:
   //: Copy Constructor (no local data)
-  bprb_null_process(const bprb_null_process& other): bprb_process(*static_cast<const bprb_process*>(&other)){}
+  bprb_null_process(const bprb_null_process& other)
+  : bprb_process(*static_cast<const bprb_process*>(&other)) {}
 
   bprb_null_process();
 
-  virtual ~bprb_null_process(){}
+  virtual ~bprb_null_process() {}
 
   //: Clone the process
-  virtual bprb_null_process* clone() const {return new bprb_null_process(*this);}
-  
-    //: The name of the process
-  virtual vcl_string name() {return "NullProcess";}
+  virtual bprb_null_process* clone() const { return new bprb_null_process(*this); }
+
+  //: The name of the process
+  virtual vcl_string name() const { return "NullProcess"; }
 
   //: Perform any initialization required by the process
-  virtual bool init() {return true;}
+  virtual bool init() { return true; }
 
-    //: Execute the process 
+  //: Execute the process
   virtual bool execute();
 
-  //: Perform any clean up or final computation 
-  virtual bool finish() {return true;}
-  
- private:
+  //: Perform any clean up or final computation
+  virtual bool finish() { return true; }
 };
+
 #endif // bprb_null_process_h_
