@@ -11,7 +11,7 @@ DECLARE_FUNC_CONS(vidl_get_frame_istream_process);
 DECLARE_FUNC_CONS(vidl_put_frame_ostream_process);
 DECLARE_FUNC_CONS(vidl_close_istream_process);
 DECLARE_FUNC_CONS(vidl_close_ostream_process);
-#if HAS_DIRECTSHOW
+#if defined(HAS_DIRECTSHOW) && HAS_DIRECTSHOW
 DECLARE_FUNC_CONS(vidl_open_dshow_istream_process);
 #endif
 
