@@ -7,7 +7,7 @@
 #include <vcl_iostream.h>
 #include <vcl_string.h>
 #include <vil/vil_image_view_base.h>
-#include <core/vil_pro/vil_io_image_view_base.h>
+#include <vil/io/vil_io_image_view_base.h>
 
 //: Constructor
 bool vil_load_image_view_binary_process_cons(bprb_func_process& pro)
