@@ -7,6 +7,7 @@
 #include <vcl_iostream.h>
 #include <vpgl/vpgl_camera.h>
 #include <vpgl/vpgl_rational_camera.h>
+#include <vpgl/vpgl_local_rational_camera.h>
 
 //: Init function
 bool vpgl_save_rational_camera_process_cons(bprb_func_process& pro)
@@ -32,16 +33,25 @@ bool vpgl_save_rational_camera_process(bprb_func_process& pro)
   // get the inputs
   vpgl_camera_double_sptr camera = pro.get_input<vpgl_camera_double_sptr>(0);
   vcl_string camera_filename = pro.get_input<vcl_string>(1);
-  vpgl_rational_camera<double> *cam = dynamic_cast<vpgl_rational_camera<double>*>(camera.as_pointer());
 
+  vpgl_local_rational_camera<double> *cam = dynamic_cast<vpgl_local_rational_camera<double>*>(camera.as_pointer());
+  
   if (!cam) {
-    vcl_cerr << "error: could not convert camera input to a vpgl_rational_camera\n";
-    return false;
-  }
+   vpgl_rational_camera<double> *cam2 = dynamic_cast<vpgl_rational_camera<double>*>(camera.as_pointer());
 
-  if (!cam->save(camera_filename)) {
-    vcl_cerr << "Failed to save file " << camera_filename << vcl_endl;
-    return false;
+    if (!cam2) {
+      vcl_cerr << "error: could not convert camera input to a vpgl_rational_camera or local rational camera\n";
+      return false;
+    }
+
+    if (!cam2->save(camera_filename)) {
+      vcl_cerr << "Failed to save file " << camera_filename << vcl_endl;
+      return false;
+    }
+  } else {
+    if (!cam->save(camera_filename)) {
+      vcl_cerr << "Failed to save file " << camera_filename << vcl_endl;
+    }
   }
 
   return true;
