@@ -2,7 +2,7 @@
 #include <vcl_cmath.h>
 #include <vcl_iostream.h>
 #include <bbgm/bbgm_image_of.h>
-#include <bsta/bsta_gauss_f1.h>
+#include <bsta/bsta_gauss_sf1.h>
 #include <vil/vil_image_view.h>
 #include <bbgm/pro/bbgm_neighborhood_functors.h>
 
@@ -16,8 +16,8 @@ static void test_neighborhood_ops()
   p(2,3) = 0.25f;  p(3,2) = 0.25f;
   p(3,4) = 0.25f;  p(4,3) = 0.25f;
   p(3,3) = 1.0f;
-  bbgm_image_of<bsta_gauss_f1> prop_dist;
-  bbgm_neighborhood_area<bsta_gauss_f1> neighbrhd_op;
+  bbgm_image_of<bsta_gauss_sf1> prop_dist;
+  bbgm_neighborhood_area<bsta_gauss_sf1> neighbrhd_op;
   property_dist(p, prop_dist, neighbrhd_op, 2);
   vcl_cout << " mean " << prop_dist(3,3).mean() << '\n'
            << " variance " << prop_dist(3,3).var() << '\n';
