@@ -166,12 +166,12 @@ bool bmdl_mesh::is_clipped(const vcl_vector<vgl_point_2d<double> >& poly,
 namespace
 {
   // return a reference to the edge bin corresponding the edge between p1 and p2
-  unsigned int& get_edge_bin(vil_image_view<unsigned int>& edge_bins, 
+  unsigned int& get_edge_bin(vil_image_view<unsigned int>& edge_bins,
                              const vgl_point_2d<double>& p1,
                              const vgl_point_2d<double>& p2)
   {
     unsigned int *binp = 0;
-    if(vcl_abs(p2.x() - p1.x()) < 0.5)
+    if (vcl_abs(p2.x() - p1.x()) < 0.5)
     {
       binp = &edge_bins(static_cast<unsigned int>(p1.x()+1.0),
                         static_cast<unsigned int>((p1.y()+p2.y())/2.0+0.5), 0);
@@ -186,8 +186,8 @@ namespace
 }
 
 
-//: extract shared boundary edges from the polygon boundarys
-unsigned int bmdl_mesh::link_boundary_edges(const vil_image_view<unsigned int>& labels, 
+//: extract shared boundary edges from the polygon boundaries
+unsigned int bmdl_mesh::link_boundary_edges(const vil_image_view<unsigned int>& labels,
                                             const vcl_vector<vgl_polygon<double> >& polygons,
                                             vcl_vector<bmdl_edge>& edges,
                                             vcl_vector<bmdl_region>& regions)
@@ -196,15 +196,15 @@ unsigned int bmdl_mesh::link_boundary_edges(const vil_image_view<unsigned int>&
   unsigned int nj = labels.nj();
   vil_image_view<unsigned int> edge_labels(ni+1, nj+1, 2);
   edge_labels.fill(0);
-  
+
   unsigned int joint_count = 0;
   unsigned int last_joint = static_cast<unsigned int>(-1);
-  
+
   regions.resize(polygons.size());
   for (unsigned int i=0; i<polygons.size(); ++i)
   {
     const vgl_polygon<double>& poly = polygons[i];
-    if(poly.num_sheets() < 1)
+    if (poly.num_sheets() < 1)
       continue;
     // determine which sheets are holes (CW vs CCW orientation)
     unsigned int num_cw=0, num_ccw=0;
@@ -213,32 +213,32 @@ unsigned int bmdl_mesh::link_boundary_edges(const vil_image_view<unsigned int>&
     {
       double area = vgl_area_signed(vgl_polygon<double>(poly[j]));
       is_hole[j] = (area > 0.0);
-      if(is_hole[j])  
+      if (is_hole[j])
         ++num_ccw;
-      else            
+      else
         ++num_cw;
     }
     // expect to find exactly 1 CW sheet
-    if(num_cw == 0)
+    if (num_cw == 0)
       continue;
-    else if(num_cw > 1)
+    else if (num_cw > 1)
     {
       vcl_cerr << "Ignoring polygon with multiple connected components "<< i << vcl_endl;
-      for(unsigned int k=0; k<is_hole.size(); ++k)
-        if(!is_hole[k])
+      for (unsigned int k=0; k<is_hole.size(); ++k)
+        if (!is_hole[k])
         {
           vcl_cout << "  "<<poly[k][0].x()<<", "<<poly[k][0].y()<<vcl_endl;
         }
       continue;
     }
     bmdl_region& region = regions[i];
-    if(num_ccw > 0)
+    if (num_ccw > 0)
       region.hole_edge_idxs.resize(num_ccw);
     unsigned int hole_count = 0;
     for (unsigned int j=0; j<poly.num_sheets(); ++j)
-    { 
+    {
       const vcl_vector<vgl_point_2d<double> >& pts = poly[j];
-      vcl_vector<unsigned int>& edge_idxs = (!is_hole[j]) ? 
+      vcl_vector<unsigned int>& edge_idxs = (!is_hole[j]) ?
                                             region.edge_idxs :
                                             region.hole_edge_idxs[hole_count++];
       for (unsigned int k1=pts.size()-1,k2=0; k2<pts.size(); k1=k2++)
@@ -249,22 +249,22 @@ unsigned int bmdl_mesh::link_boundary_edges(const vil_image_view<unsigned int>&
         int x = static_cast<int>(p.x()+0.5);
         int y = static_cast<int>(p.y()+0.5);
         unsigned l = 0;
-        if(x >= 0 && (unsigned)x < ni && y >=0 && (unsigned)y < nj)
+        if (x >= 0 && (unsigned)x < ni && y >=0 && (unsigned)y < nj)
         {
           l = labels(x,y);
-          if(l > 0)
+          if (l > 0)
             l -= 1;
         }
 
         // find the bin for storing indices of edges already created
         unsigned int& bin = get_edge_bin(edge_labels,pts[k1],pts[k2]);
-           
-        if(bin > 0) // the label already exists
+
+        if (bin > 0) // the label already exists
         {
-          if(edge_idxs.empty() || edge_idxs.back() != bin-1)
+          if (edge_idxs.empty() || edge_idxs.back() != bin-1)
           {
             // correct last joint if just created
-            if(!edge_idxs.empty() && edges[edge_idxs.back()].building1 == i+1)
+            if (!edge_idxs.empty() && edges[edge_idxs.back()].building1 == i+1)
             {
               edges[edge_idxs.back()].joint2 = edges[bin-1].joint2;
               --joint_count;
@@ -277,7 +277,7 @@ unsigned int bmdl_mesh::link_boundary_edges(const vil_image_view<unsigned int>&
         }
         else // create and build a new edge
         {
-          if(edge_idxs.empty() || edges[edge_idxs.back()].building2 != l)
+          if (edge_idxs.empty() || edges[edge_idxs.back()].building2 != l)
           {
             // start a new edge
             edge_idxs.push_back(edges.size());
@@ -292,22 +292,22 @@ unsigned int bmdl_mesh::link_boundary_edges(const vil_image_view<unsigned int>&
         }
       }
       // handle special cases at the starting point
-      if(edge_idxs.size() > 1)
+      if (edge_idxs.size() > 1)
       {
-        // A region may touch the same previously created edge at beginning and end 
-        if(edge_idxs.front() == edge_idxs.back() && 
-           edges[edge_idxs.front()].building2 == i+1) 
+        // A region may touch the same previously created edge at beginning and end
+        if (edge_idxs.front() == edge_idxs.back() &&
+            edges[edge_idxs.front()].building2 == i+1)
         {
           edge_idxs.pop_back();
         }
         // Created edges at beginning and end may touch the same region (merge them)
-        else if(edges[edge_idxs.front()].building2 == edges[edge_idxs.back()].building2 &&
-                edges[edge_idxs.front()].building2 != i+1)
+        else if (edges[edge_idxs.front()].building2 == edges[edge_idxs.back()].building2 &&
+                 edges[edge_idxs.front()].building2 != i+1)
         {
           vcl_vector<vgl_point_2d<double> >& pts1 = edges[edge_idxs.front()].pts;
           vcl_vector<vgl_point_2d<double> >& pts2 = edges[edge_idxs.back()].pts;
-          // relabel bins 
-          for(unsigned int k=1; k<pts2.size(); ++k)
+          // relabel bins
+          for (unsigned int k=1; k<pts2.size(); ++k)
           {
             unsigned int& bin = get_edge_bin(edge_labels,pts2[k-1],pts2[k]);
             bin = edge_idxs.front()+1;
@@ -332,7 +332,7 @@ unsigned int bmdl_mesh::link_boundary_edges(const vil_image_view<unsigned int>&
         }
       }
       // fix starting joint by completing the cycle
-      if(edges[edge_idxs.front()].building1 == i+1)
+      if (edges[edge_idxs.front()].building1 == i+1)
       {
         edges[edge_idxs.front()].joint1 = last_joint;
       }
@@ -434,11 +434,11 @@ void bmdl_mesh::simplify_edge( vcl_vector<vgl_point_2d<double> >& pts, double to
   {
     if (indices[i] < 0)
     {
-      if(i==0 || i==indices.size()-1)
+      if (i==0 || i==indices.size()-1)
         ++i;
       else if (new_pts.empty() || new_pts.back() != pts[i])
         new_pts.push_back(pts[i++]);
-            
+
       continue;
     }
     const vgl_line_segment_2d<double>& seg = segs[indices[i]];
@@ -452,23 +452,23 @@ void bmdl_mesh::simplify_edge( vcl_vector<vgl_point_2d<double> >& pts, double to
       new_pts.back() = isect;
     }
     // avoid duplicating the first point
-    else if(i>0 || (seg.point1()-pts.front()).length()>0.5)
+    else if (i>0 || (seg.point1()-pts.front()).length()>0.5)
       new_pts.push_back(seg.point1());
-    
+
     // remove duplicate points
-    if(new_pts.size()>1 && new_pts.back() == new_pts[new_pts.size()-2])
+    if (new_pts.size()>1 && new_pts.back() == new_pts[new_pts.size()-2])
       new_pts.pop_back();
-    
+
     // skip to the next point not part of this line
     for (int curr_seg_idx = indices[i];
          i<indices.size() && indices[i] == curr_seg_idx; ++i)
       ;
-    
+
     // avoid duplicating the last point
-    if(i<indices.size() || (seg.point2()-pts.back()).length()>0.5)
+    if (i<indices.size() || (seg.point2()-pts.back()).length()>0.5)
       new_pts.push_back(seg.point2());
-    
-    if(new_pts.size()>1 && new_pts.back() == new_pts[new_pts.size()-2])
+
+    if (new_pts.size()>1 && new_pts.back() == new_pts[new_pts.size()-2])
       new_pts.pop_back();
   }
   // the last point must be retained
@@ -480,20 +480,20 @@ void bmdl_mesh::simplify_edge( vcl_vector<vgl_point_2d<double> >& pts, double to
 //: simplify the linked edges by fitting lines
 void bmdl_mesh::simplify_edges( vcl_vector<bmdl_edge>& edges )
 {
-  for(unsigned int i=0; i<edges.size(); ++i)
+  for (unsigned int i=0; i<edges.size(); ++i)
   {
     vcl_vector<vgl_point_2d<double> >& pts = edges[i].pts;
-    
+
     // shift point to the edge centers (diagonals line up better this way)
     vcl_vector<vgl_point_2d<double> > new_pts;
     new_pts.push_back(pts.front());
     for (unsigned j=1; j<pts.size(); ++j) {
-      new_pts.push_back(vgl_point_2d<double>((pts[j-1].x()+pts[j].x())/2, 
+      new_pts.push_back(vgl_point_2d<double>((pts[j-1].x()+pts[j].x())/2,
                                              (pts[j-1].y()+pts[j].y())/2));
     }
     new_pts.push_back(pts.back());
     pts.swap(new_pts);
-    
+
     simplify_edge(pts, 0.01);
     simplify_edge(pts, 0.5);
   }
@@ -561,20 +561,20 @@ void bmdl_mesh::mesh_lidar(const vcl_vector<vgl_polygon<double> >& boundaries,
 
 namespace{
   unsigned int add_joint_vertex(imesh_vertex_array<3>& verts,
-                                vcl_vector<unsigned int>& vert_stack, 
+                                vcl_vector<unsigned int>& vert_stack,
                                 const imesh_vertex<3>& v)
-  {      
+  {
     bool found = false;
     vcl_vector<unsigned int>::iterator i=vert_stack.begin();
-    for(; i!=vert_stack.end() && verts[*i][2] <= v[2]; ++i)
+    for (; i!=vert_stack.end() && verts[*i][2] <= v[2]; ++i)
     {
-      if(verts[*i][2] == v[2])
+      if (verts[*i][2] == v[2])
       {
         found = true;
         break;
       }
     }
-    if(found)
+    if (found)
       return *i;
 
     unsigned int bi = verts.size();
@@ -582,19 +582,18 @@ namespace{
     vert_stack.insert(i,bi);
     return bi;
   }
-  
-  
+
+
   inline vcl_vector<unsigned int>::const_iterator
-  find_by_height(const vcl_vector<unsigned int>& idxs, 
+  find_by_height(const vcl_vector<unsigned int>& idxs,
                  const imesh_vertex_array<3>& verts,
                  double height)
   {
-    for(vcl_vector<unsigned int>::const_iterator i=idxs.begin(); i!=idxs.end(); ++i)
-      if(verts[*i][2] == height)
+    for (vcl_vector<unsigned int>::const_iterator i=idxs.begin(); i!=idxs.end(); ++i)
+      if (verts[*i][2] == height)
         return i;
     return idxs.end();
   }
-  
 }
 
 //: construct a mesh out of data and labels using linked edges
@@ -610,7 +609,7 @@ void bmdl_mesh::mesh_lidar(const vcl_vector<bmdl_edge>& edges,
 {
   unsigned ni = labels.ni();
   unsigned nj = labels.nj();
-  
+
   // recover the vector of building heights
   vcl_vector<double> bld_heights(regions.size());
   for (unsigned int j=0; j<nj; ++j)
@@ -622,79 +621,79 @@ void bmdl_mesh::mesh_lidar(const vcl_vector<bmdl_edge>& edges,
       }
     }
   }
-  
+
   vcl_vector<vcl_vector<unsigned int> > face_list(regions.size());
-  for(unsigned int i = 0; i<regions.size(); ++i)
+  for (unsigned int i = 0; i<regions.size(); ++i)
   {
     const vcl_vector<unsigned int>& edge_idxs = regions[i].edge_idxs;
-    for(unsigned int j = 0; j<edge_idxs.size(); ++j)
+    for (unsigned int j = 0; j<edge_idxs.size(); ++j)
     {
-      if(edges[edge_idxs[j]].building1 == i+1)
+      if (edges[edge_idxs[j]].building1 == i+1)
       {
-        face_list[i].push_back(edges[edge_idxs[j]].joint1);      
-        // insert two psuedo edge points for disambiguation
+        face_list[i].push_back(edges[edge_idxs[j]].joint1);
+        // insert two pseudo edge points for disambiguation
         face_list[i].push_back(num_joints + 2*edge_idxs[j]);
         face_list[i].push_back(num_joints + 2*edge_idxs[j] + 1);
       }
       else
       {
         face_list[i].push_back(edges[edge_idxs[j]].joint2);
-        // insert two psuedo edge points for disambiguation
+        // insert two pseudo edge points for disambiguation
         face_list[i].push_back(num_joints + 2*edge_idxs[j] + 1);
         face_list[i].push_back(num_joints + 2*edge_idxs[j]);
       }
     }
   }
   imesh_half_edge_set he2d(face_list);
-  
+
   // store the indices of vertices connected below each edge point
   vcl_vector<vcl_vector<unsigned int> > edge_to_mesh(edges.size());
   vcl_vector<vcl_vector<unsigned int> > joint_vert_stack(num_joints);
-  
+
   imesh_vertex_array<3> *verts = new imesh_vertex_array<3>;
   imesh_face_array *faces = new imesh_face_array;
-  
+
   // precompute a mesh vertices located at joints
-  for(unsigned int e=0; e<edges.size(); ++e)
+  for (unsigned int e=0; e<edges.size(); ++e)
   {
     const bmdl_edge& edge = edges[e];
     const vgl_point_2d<double>& pt1 = edge.pts.front();
     const vgl_point_2d<double>& pt2 = edge.pts.back();
     vcl_vector<unsigned int>& jvs1 = joint_vert_stack[edge.joint1];
     vcl_vector<unsigned int>& jvs2 = joint_vert_stack[edge.joint2];
-    
+
     bool b1_gnd = edge.building1 == 0 || regions[edge.building1-1].edge_idxs.empty();
     bool b2_gnd = edge.building2 == 0 || regions[edge.building2-1].edge_idxs.empty();
     // building 1 on ground
-    if(b1_gnd || b2_gnd)
+    if (b1_gnd || b2_gnd)
     {
       double g1 = vil_bilin_interp_safe_extend(ground, pt1.x(), pt1.y());
       add_joint_vertex(*verts, jvs1, imesh_vertex<3>(pt1.x(),-pt1.y(), g1));
       double g2 = vil_bilin_interp_safe_extend(ground, pt2.x(), pt2.y());
       add_joint_vertex(*verts, jvs2, imesh_vertex<3>(pt2.x(),-pt2.y(), g2));
     }
-    if(!b1_gnd)
+    if (!b1_gnd)
     {
       double h = bld_heights[edge.building1-1];
       add_joint_vertex(*verts, jvs1, imesh_vertex<3>(pt1.x(),-pt1.y(),h));
       add_joint_vertex(*verts, jvs2, imesh_vertex<3>(pt2.x(),-pt2.y(),h));
     }
-    if(!b2_gnd)
+    if (!b2_gnd)
     {
       double h = bld_heights[edge.building2-1];
       add_joint_vertex(*verts, jvs1, imesh_vertex<3>(pt1.x(),-pt1.y(),h));
       add_joint_vertex(*verts, jvs2, imesh_vertex<3>(pt2.x(),-pt2.y(),h));
     }
   }
-  
+
   typedef vcl_pair<unsigned int, unsigned int> uint_pair;
   vcl_map<uint_pair, vcl_vector<unsigned int> > revised_stack;
   // find non-manifold corner junctions
-  for(unsigned int i=0; i<joint_vert_stack.size(); ++i){
+  for (unsigned int i=0; i<joint_vert_stack.size(); ++i){
     // get the 4 adjacent faces (if there are 4)
     imesh_half_edge_set::v_const_iterator e1 = he2d.vertex_begin(i), ei = e1;
     imesh_half_edge_set::v_const_iterator invalid_e(imesh_invalid_idx,he2d);
-    if(ei == invalid_e)
+    if (ei == invalid_e)
       continue;
     int f1 = static_cast<int>(ei->face_index());
     if (e1 == ++ei)
@@ -707,12 +706,12 @@ void bmdl_mesh::mesh_lidar(const vcl_vector<bmdl_edge>& edges,
       continue;
     int f4 = static_cast<int>(ei->face_index());
     assert(e1 == ++ei);
-    
+
     // look for double peaks
-    if((f1 > f2 && f1 > f4 && f3 > f2 && f3 > f4) ||
-       (f2 > f1 && f2 > f3 && f4 > f1 && f4 > f3) )
+    if ((f1 > f2 && f1 > f4 && f3 > f2 && f3 > f4) ||
+        (f2 > f1 && f2 > f3 && f4 > f1 && f4 > f3) )
     {
-      if(f1 > f2) // shift
+      if (f1 > f2) // shift
       {
         int tmp = f1;
         f1 = f2;
@@ -720,50 +719,48 @@ void bmdl_mesh::mesh_lidar(const vcl_vector<bmdl_edge>& edges,
         f3 = f4;
         f4 = tmp;
       }
-      
+
       // split the old stack
       const vcl_vector<unsigned int>& jvs = joint_vert_stack[i];
-      
+
       double h1 = (f1<0)?(*verts)[jvs.front()][2]:bld_heights[f1];
       double h2 = bld_heights[f2];
       double h3 = (f3<0)?(*verts)[jvs.front()][2]:bld_heights[f3];
       vcl_vector<unsigned int> new_stack1;
-      for(unsigned int k=0; k<jvs.size(); ++k)
+      for (unsigned int k=0; k<jvs.size(); ++k)
       {
         double z = (*verts)[jvs[k]][2];
-        if(z == h1 || z == h2 || z == h3)
+        if (z == h1 || z == h2 || z == h3)
           new_stack1.push_back(jvs[k]);
       }
       revised_stack[uint_pair(f2,i)] = new_stack1;
-      
+
       h1 = (f3<0)?(*verts)[jvs.front()][2]:bld_heights[f3];
       h2 = bld_heights[f4];
       h3 = (f1<0)?(*verts)[jvs.front()][2]:bld_heights[f1];
       vcl_vector<unsigned int> new_stack2;
-      for(unsigned int k=0; k<jvs.size(); ++k)
+      for (unsigned int k=0; k<jvs.size(); ++k)
       {
         double z = (*verts)[jvs[k]][2];
-        if(z == h1 || z == h2 || z == h3)
+        if (z == h1 || z == h2 || z == h3)
           new_stack2.push_back(jvs[k]);
       }
       revised_stack[uint_pair(f4,i)] = new_stack2;
-      
     }
-    
   }
-  
+
 
   // create the buildings
   for (unsigned int b=0; b<regions.size(); ++b) {
     if (regions[b].edge_idxs.empty())
       continue;
     unsigned int roof_face = 0;
-    for(int h=-1; h<(int)regions[b].hole_edge_idxs.size(); ++h)
+    for (int h=-1; h<(int)regions[b].hole_edge_idxs.size(); ++h)
     {
-      const vcl_vector<unsigned int>& edge_idxs = (h<0) ? regions[b].edge_idxs : 
+      const vcl_vector<unsigned int>& edge_idxs = (h<0) ? regions[b].edge_idxs :
                                                           regions[b].hole_edge_idxs[h];
       vcl_vector< unsigned int > roof;
-      for(unsigned int e=0; e<edge_idxs.size(); ++e)
+      for (unsigned int e=0; e<edge_idxs.size(); ++e)
       {
         const bmdl_edge& edge = edges[edge_idxs[e]];
         vcl_vector<unsigned int> e2m = edge_to_mesh[edge_idxs[e]];
@@ -771,11 +768,11 @@ void bmdl_mesh::mesh_lidar(const vcl_vector<bmdl_edge>& edges,
         unsigned int other = 0;
         unsigned int j1 = edge.joint1;
         unsigned int j2 = edge.joint2;
-        if(edge.building1 == b+1)
+        if (edge.building1 == b+1)
         {
           other = edge.building2;
         }
-        else if(edge.building2 == b+1)
+        else if (edge.building2 == b+1)
         {
           other = edge.building1;
           vcl_reverse(pts.begin(), pts.end());
@@ -784,44 +781,44 @@ void bmdl_mesh::mesh_lidar(const vcl_vector<bmdl_edge>& edges,
         }
         else
           vcl_cout << "mismatch "<<b+1<<", "<<edge.building1<<", "<<edge.building2<<vcl_endl;
-        
+
         // if this has been marked as a non-manifold corner then a revised stack exists
         // otherwise use the original vertex stack
         vcl_map<uint_pair, vcl_vector<unsigned int> >::const_iterator rvs1 = revised_stack.find(uint_pair(b,j1));
         vcl_map<uint_pair, vcl_vector<unsigned int> >::const_iterator rvs2 = revised_stack.find(uint_pair(b,j2));
-        const vcl_vector<unsigned int>& jvs1 = (rvs1==revised_stack.end()) 
+        const vcl_vector<unsigned int>& jvs1 = (rvs1==revised_stack.end())
                                                ? joint_vert_stack[j1]
                                                : rvs1->second;
-        const vcl_vector<unsigned int>& jvs2 = (rvs2==revised_stack.end()) 
+        const vcl_vector<unsigned int>& jvs2 = (rvs2==revised_stack.end())
                                                 ? joint_vert_stack[j2]
                                                 : rvs2->second;
-        
+
         // is this edge attached to the ground?
         bool on_ground = other == 0 || regions[other-1].edge_idxs.empty();
-        
+
         typedef vcl_vector<unsigned int>::const_iterator vfitr;
         typedef vcl_vector<unsigned int>::const_reverse_iterator vritr;
-        
+
         vfitr i1beg = jvs1.begin(); // first vertex is on ground
         vfitr i1end = find_by_height(jvs1, *verts, bld_heights[b]);
         vfitr i2beg = jvs2.begin(); // first vertex is on ground
         vfitr i2end = find_by_height(jvs2, *verts, bld_heights[b]);
         assert(i1end != jvs1.end());
         assert(i2end != jvs2.end());
-        if(!on_ground)
+        if (!on_ground)
         {
           i1beg = find_by_height(jvs1, *verts, bld_heights[other-1]);
           i2beg = find_by_height(jvs2, *verts, bld_heights[other-1]);
           assert(i1beg != jvs1.end());
           assert(i2beg != jvs2.end());
-          if(bld_heights[other-1] > bld_heights[b])
+          if (bld_heights[other-1] > bld_heights[b])
           {
             vcl_swap(i1beg, i1end);
             vcl_swap(i2beg, i2end);
           }
         }
-        
-        if(!on_ground && edge.building1 == b+1) // don't create side faces yet
+
+        if (!on_ground && edge.building1 == b+1) // don't create side faces yet
         {
           // create the base vertices for later faces and attach the current roof
           vcl_vector<unsigned int>& e2m_set = edge_to_mesh[edge_idxs[e]];
@@ -835,15 +832,15 @@ void bmdl_mesh::mesh_lidar(const vcl_vector<bmdl_edge>& edges,
           }
           continue;
         }
-        
+
         vcl_vector<unsigned int> face;
         // start the next face
         roof.push_back(*i1end);
         ++i1end;
         face.insert(face.end(), vritr(i1end), vritr(i1beg));
-    
-        if(on_ground) // attach to the ground
-        {        
+
+        if (on_ground) // attach to the ground
+        {
           // add all faces in the middle
           for (unsigned int i=1; i<pts.size()-1; ++i) {
             const vgl_point_2d<double>& pt = pts[i];
@@ -864,7 +861,7 @@ void bmdl_mesh::mesh_lidar(const vcl_vector<bmdl_edge>& edges,
         }
         else // attach to previous level
         {
-          if(e2m.empty() && pts.size() > 2)
+          if (e2m.empty() && pts.size() > 2)
             continue;
           for (unsigned int i=1; i<pts.size()-1; ++i) {
             const vgl_point_2d<double>& pt = pts[i];
@@ -880,16 +877,16 @@ void bmdl_mesh::mesh_lidar(const vcl_vector<bmdl_edge>& edges,
             face.push_back(bi);
             face.push_back(e2m[i-1]);
           }
-        }      
+        }
         // finish the last face
         ++i2end;
         face.insert(face.end(), i2beg, i2end);
         faces->push_back(face);
         face.clear();
       }
-      if(roof.size() > 2)
+      if (roof.size() > 2)
       {
-        if(h<0){
+        if (h<0){
           roof_face = faces->size();
           faces->push_back(roof);
         }
@@ -898,7 +895,7 @@ void bmdl_mesh::mesh_lidar(const vcl_vector<bmdl_edge>& edges,
       }
     }
   }
-  
+
   vcl_auto_ptr<imesh_vertex_array_base> vb(verts);
   vcl_auto_ptr<imesh_face_array_base> fb(faces);
   mesh.set_vertices(vb);
@@ -908,50 +905,50 @@ void bmdl_mesh::mesh_lidar(const vcl_vector<bmdl_edge>& edges,
 
 //: Subtract a hole from an existing face in a mesh
 void bmdl_mesh::roof_subtract_hole(const imesh_vertex_array<3>& verts,
-                                   vcl_vector<unsigned int>& face, 
+                                   vcl_vector<unsigned int>& face,
                                    const vcl_vector<unsigned int>& hole)
 {
   unsigned int i1, i2;
   bool valid = false;
-  for(i1=0; i1<face.size(); ++i1)
+  for (i1=0; i1<face.size(); ++i1)
   {
     vgl_point_2d<double> v1(verts[face[i1]][0],verts[face[i1]][1]);
-    for(i2=0; i2<hole.size(); ++i2)
+    for (i2=0; i2<hole.size(); ++i2)
     {
       vgl_point_2d<double> v2(verts[hole[i2]][0],verts[hole[i2]][1]);
       // look for self intersections
       valid = true;
-      for(unsigned int j1 = face.size()-1, j2=0; j2<face.size() && valid; j1=j2, ++j2)
+      for (unsigned int j1 = face.size()-1, j2=0; j2<face.size() && valid; j1=j2, ++j2)
       {
-        if(j1 == i1 || j2 == i1)
+        if (j1 == i1 || j2 == i1)
           continue;
         vgl_point_2d<double> v3(verts[face[j1]][0],verts[face[j1]][1]);
         vgl_point_2d<double> v4(verts[face[j2]][0],verts[face[j2]][0]);
         valid = !vgl_lineseg_test_lineseg(v1.x(),v1.y(),v2.x(),v2.y(),
                                           v3.x(),v3.y(),v4.x(),v4.y());
       }
-      for(unsigned int j1 = hole.size()-1, j2=0; j2<hole.size() && valid; j1=j2, ++j2)
+      for (unsigned int j1 = hole.size()-1, j2=0; j2<hole.size() && valid; j1=j2, ++j2)
       {
-        if(j1 == i2 || j2 == i2)
+        if (j1 == i2 || j2 == i2)
           continue;
         vgl_point_2d<double> v3(verts[hole[j1]][0],verts[hole[j1]][1]);
         vgl_point_2d<double> v4(verts[hole[j2]][0],verts[hole[j2]][1]);
         valid = !vgl_lineseg_test_lineseg(v1.x(),v1.y(),v2.x(),v2.y(),
                                           v3.x(),v3.y(),v4.x(),v4.y());
       }
-      if(valid)
+      if (valid)
         break;
     }
-    if(valid)
+    if (valid)
       break;
   }
-  
-  if(!valid)
+
+  if (!valid)
   {
     vcl_cout << "couldn't find connection for hole"<<vcl_endl;
     return;
   }
-  
+
   vcl_vector<unsigned int> new_idxs;
   new_idxs.push_back(face[i1]);
   new_idxs.insert(new_idxs.end(), hole.begin()+i2, hole.end());
