@@ -6,7 +6,7 @@
 
 //: Averages the value of the 8 children in a dynamic programming manner
 // Specialization for float. Partial specialization is not part of c++ standard for this case
-// so we have to expiciltly write all template parameters
+// so we have to explicitly write all template parameters
 template<>
 void boct_tree_cell<short,float>::set_data_to_avg_children()
 {
@@ -18,7 +18,7 @@ void boct_tree_cell<short,float>::set_data_to_avg_children()
   data_=0; //remove previous data
   for (unsigned i=0; i<8; i++) {
     children_[i].set_data_to_avg_children();
-    data_+= children_[i].data()/8.0;
+    data_ += children_[i].data()/8.0f;
   }
 
   return;
