@@ -7,6 +7,7 @@ DECLARE( test_find_neighbors );
 DECLARE( test_binary_io );
 DECLARE( test_clone_tree );
 DECLARE( test_tree_cell_reader );
+DECLARE( test_bit_tree );
 
 void register_tests()
 {
@@ -17,6 +18,7 @@ void register_tests()
   REGISTER( test_binary_io );
   REGISTER( test_clone_tree );
   REGISTER( test_tree_cell_reader );
+  REGISTER( test_bit_tree );
 }
 
 
