@@ -1,7 +1,11 @@
+#include <boct/boct_bit_tree.h>
 #include <boct/boct_loc_code.h>
 #include <boct/boct_test_util.h>
 #include <boct/boct_tree.h>
 #include <boct/boct_tree_cell.h>
 #include <boct/boct_tree_cell_reader.h>
 
+#include <boct/util/boct_clone_tree.h>
+#include <boct/util/boct_construct_tree.h>
+
 int main() { return 0; }
