@@ -5,3 +5,6 @@
 
 typedef boct_tree<short, int > tree_type;
 VBL_ARRAY_3D_INSTANTIATE(boxm_block<tree_type>*);
+
+typedef boct_tree<short, short > short_tree_type;
+VBL_ARRAY_3D_INSTANTIATE(boxm_block<short_tree_type>*);
