@@ -9,16 +9,16 @@
 
 #include <bsta/bsta_attributes.h>
 #include <bsta/bsta_mixture_fixed.h>
-#include <bsta/bsta_gauss_f1.h>
+#include <bsta/bsta_gauss_sf1.h>
 #include <bsta/bsta_gauss_if3.h>
 #include <bsta/bsta_beta.h>
 #include <bsta/bsta_beta_f1.h>
 #include <vnl/vnl_vector_fixed.h>
 #include <vil/vil_rgb.h>
 #include <vsl/vsl_binary_io.h>
-#include <vcl_ostream.h>
-#include <boxm/boxm_edge_sample.h>
-#include <boxm/boxm_inf_line_sample.h>
+#include <boxm/sample/boxm_edge_sample.h>
+#include <boxm/sample/boxm_inf_line_sample.h>
+#include <vcl_iosfwd.h> // for std::ostream
 
 class boxm_mog_grey_processor;
 class boxm_mog_rgb_processor;
@@ -32,13 +32,25 @@ enum boxm_apm_type
   BOXM_APM_SIMPLE_GREY,
   BOXM_APM_SIMPLE_RGB,
   BOXM_APM_MOB_GREY,
-  FLOAT,
+  BOXM_FLOAT,
+  BOXM_INT,
+  BOXM_SHORT,
+  BOXM_CHAR,
+  BOXM_BOOL,
+  VNL_DOUBLE_10,
+  VNL_FLOAT_10,
+  VNL_FLOAT_3,
   BSTA_MOG_F1,
   BSTA_GAUSS_F1,
   BVPL_SAMPLE_FLOAT,
   BVPL_SAMPLE_BSTA_GAUSS_F1,
+  BVPL_PCA_BASIS_SAMPLE_10,
   BOXM_EDGE_FLOAT,
   BOXM_EDGE_LINE,
+  BOXM_EDGE_TANGENT_LINE,
+  BOXM_SCALAR_FLOAT,
+  DBREC3D_PART_INSTANCE,
+  DBREC3D_PAIR_COMPOSITE_INSTANCE,
   BOXM_APM_NA,
   BOXM_APM_UNKNOWN
 };
@@ -62,12 +74,12 @@ class boxm_apm_traits<BOXM_APM_MOG_GREY>
  public:
   static const unsigned int n_gaussian_modes_ = 3;
 
-  typedef bsta_num_obs<bsta_gauss_f1> gauss_type_f1;
-  typedef bsta_num_obs<bsta_mixture_fixed<gauss_type_f1, n_gaussian_modes_> > mix_gauss_f1_type;
+  typedef bsta_num_obs<bsta_gauss_sf1> gauss_type_sf1;
+  typedef bsta_num_obs<bsta_mixture_fixed<gauss_type_sf1, n_gaussian_modes_> > mix_gauss_sf1_type;
 
  public:
   static const unsigned int obs_dim = 1;
-  typedef  mix_gauss_f1_type apm_datatype;
+  typedef  mix_gauss_sf1_type apm_datatype;
   typedef float obs_datatype;
   typedef float obs_mathtype;
   typedef boxm_mog_grey_processor apm_processor;
@@ -101,10 +113,10 @@ class boxm_simple_grey
   boxm_simple_grey(float colour, float std_dev, float gauss_wght=1.0f) : color_(colour), one_over_sigma_(1/std_dev), gauss_weight_(gauss_wght)  { check_vals(); }
   boxm_simple_grey(vnl_vector_fixed<float,3> const& params) : color_(params[0]), one_over_sigma_(1.0f/params[1])  { check_vals(); }
   static short version_no() { return 1; }
-  inline float color() const {return color_;}
-  inline float sigma() const {return 1.0f/one_over_sigma_;}
-  inline float gauss_weight() const {return gauss_weight_;}
-  inline float one_over_sigma() const {return one_over_sigma_;}
+  inline float color() const { return color_; }
+  inline float sigma() const { return 1.0f/one_over_sigma_; }
+  inline float gauss_weight() const { return gauss_weight_; }
+  inline float one_over_sigma() const { return one_over_sigma_; }
 
  protected:
   inline void check_vals()
@@ -164,7 +176,9 @@ class boxm_apm_traits<BOXM_EDGE_FLOAT>
   typedef boxm_edge_sample<float> apm_datatype;
   typedef float obs_datatype;
   typedef float obs_mathtype;
-  //typedef boxm_edge_processor apm_processor;
+#if 0
+  typedef boxm_edge_processor apm_processor;
+#endif
 };
 
 template<>
