@@ -19,16 +19,18 @@
 
 #include <brdb/brdb_value.h>
 
-#include <vpgl/bgeo/bgeo_lvcs.h>
-#include <vpgl/bgeo/bgeo_lvcs_sptr.h>
+#include <vpgl/vpgl_lvcs.h>
+#include <vpgl/vpgl_lvcs_sptr.h>
 
 #include <vcl_string.h>
 #include <vcl_iostream.h>
 #include <vcl_fstream.h>
 
-#include <boxm/boxm_sample_multi_bin.h>
 #include <boxm/boxm_scene_parser.h>
-#include <boxm/boxm_inf_line_sample.h>
+#include <boxm/sample/boxm_sample_multi_bin.h>
+#include <boxm/sample/boxm_inf_line_sample.h>
+#include <boxm/sample/boxm_edge_tangent_sample.h>
+#include <boxm/sample/boxm_scalar_sample.h>
 
 //:global variables
 namespace boxm_create_scene_process_globals
@@ -41,19 +43,15 @@ namespace boxm_create_scene_process_globals
 //:sets input and output types
 bool boxm_create_scene_process_cons(bprb_func_process& pro)
 {
-  //set output types
   using namespace boxm_create_scene_process_globals;
 
   vcl_vector<vcl_string> input_types_(n_inputs_);
   input_types_[0] = "vcl_string";
-  if (!pro.set_input_types(input_types_))
-    return false;
 
   vcl_vector<vcl_string> output_types_(n_outputs_);
   output_types_[0] = "boxm_scene_base_sptr";
-  if (!pro.set_output_types(output_types_))
-    return false;
-  return true;
+
+  return pro.set_input_types(input_types_) && pro.set_output_types(output_types_);
 }
 
 //:creates a scene from parameters
@@ -66,6 +64,9 @@ bool boxm_create_scene_process(bprb_func_process& pro)
 
   boxm_scene_base_sptr scene_ptr=new boxm_scene_base();
   scene_ptr->load_scene(fname, parser);
+  vcl_cout << "Scene path: " << scene_ptr->filename()<< vcl_endl;
+  vcl_cout << "Scene appearance: " <<scene_ptr->appearence_model()<< vcl_endl;
+  
   if (scene_ptr->appearence_model() == BOXM_APM_MOG_GREY) {
     if (!scene_ptr->multi_bin())
     {
@@ -81,7 +82,8 @@ bool boxm_create_scene_process(bprb_func_process& pro)
       vcl_cout<<"Multi Bin set"<<vcl_endl;
       scene_ptr = scene;
     }
-  } else if (scene_ptr->appearence_model() == BOXM_APM_MOB_GREY) {
+  }
+  else if (scene_ptr->appearence_model() == BOXM_APM_MOB_GREY) {
     if (!scene_ptr->multi_bin())
     {
       typedef boct_tree<short,boxm_sample<BOXM_APM_MOB_GREY> > tree_type;
@@ -90,9 +92,10 @@ bool boxm_create_scene_process(bprb_func_process& pro)
       scene_ptr = scene;
     }
     else {
-      vcl_cout<<"Multi Bin for BOXM_APM_MOB_GREY is not defined yet "<<vcl_endl;
+      vcl_cout<<"Multi Bin for BOXM_APM_MOB_GREY is not defined yet"<<vcl_endl;
     }
-  } else if (scene_ptr->appearence_model() == BOXM_APM_SIMPLE_GREY) {
+  }
+  else if (scene_ptr->appearence_model() == BOXM_APM_SIMPLE_GREY) {
     if (!scene_ptr->multi_bin())
     {
       typedef boct_tree<short,boxm_sample<BOXM_APM_SIMPLE_GREY> > tree_type;
@@ -104,61 +107,109 @@ bool boxm_create_scene_process(bprb_func_process& pro)
     else {
       typedef boct_tree<short,boxm_sample_multi_bin<BOXM_APM_SIMPLE_GREY> > tree_type;
       boxm_scene<tree_type>* scene = new boxm_scene<tree_type>();
-      scene->load_scene(parser);
+      scene->load_scene(fname);
       vcl_cout<<"Multi Bin set"<<vcl_endl;
       scene_ptr = scene;
     }
 #endif
   }
-    else if (scene_ptr->appearence_model() == FLOAT) {
+  else if (scene_ptr->appearence_model() == BOXM_FLOAT) {
       if (!scene_ptr->multi_bin())
       {
         typedef boct_tree<short,float> tree_type;
         boxm_scene<tree_type>* scene = new boxm_scene<tree_type>();
-        scene->load_scene(parser);
+        scene->load_scene(fname);
         scene_ptr = scene;
+        vcl_cout << "Scene path: " << scene->filename()<< vcl_endl;
       }
+  }
+  else if (scene_ptr->appearence_model() == VNL_FLOAT_3) {
+    if (!scene_ptr->multi_bin())
+    {
+      typedef boct_tree<short,vnl_vector_fixed<float, 3> > tree_type;
+      boxm_scene<tree_type>* scene = new boxm_scene<tree_type>();
+      scene->load_scene(fname);
+      scene_ptr = scene;
+      vcl_cout << "Loading scene of type vnl_float_3" << vcl_endl;
+      vcl_cout << "Scene path: " << scene->filename()<< vcl_endl;
     }
-    else if (scene_ptr->appearence_model() == BSTA_MOG_F1) {
-      if (!scene_ptr->multi_bin())
-      {
-        typedef boct_tree<short,boxm_apm_traits<BOXM_APM_MOG_GREY>::apm_datatype > tree_type;
-        boxm_scene<tree_type>* scene = new boxm_scene<tree_type>();
-        scene->load_scene(parser);
-        scene_ptr = scene;
-      }
+  }
+  else if (scene_ptr->appearence_model() == VNL_FLOAT_10) {
+    if (!scene_ptr->multi_bin())
+    {
+      typedef boct_tree<short,vnl_vector_fixed<float, 10> > tree_type;
+      boxm_scene<tree_type>* scene = new boxm_scene<tree_type>();
+      scene->load_scene(fname);
+      scene_ptr = scene;
+      vcl_cout << "Loading scene of type vnl_float_10" << vcl_endl;
+      vcl_cout << "Scene path: " << scene->filename()<< vcl_endl;
     }
-    else if (scene_ptr->appearence_model() == BSTA_GAUSS_F1) {
-      if (!scene_ptr->multi_bin())
-      {
-        typedef boct_tree<short,bsta_num_obs<bsta_gauss_f1> > tree_type;
-        boxm_scene<tree_type>* scene = new boxm_scene<tree_type>();
-        scene->load_scene(parser);
-        scene_ptr = scene;
-      }
+  }
+  else if (scene_ptr->appearence_model() == BOXM_BOOL) {
+    if (!scene_ptr->multi_bin())
+    {
+      typedef boct_tree<short,bool> tree_type;
+      boxm_scene<tree_type>* scene = new boxm_scene<tree_type>();
+      scene->load_scene(fname);
+      scene_ptr = scene;
+      vcl_cout << "Scene path: " << scene->filename()<< vcl_endl;
     }
-    else if (scene_ptr->appearence_model() == BOXM_EDGE_FLOAT) {
-      if (!scene_ptr->multi_bin())
-      {
-        typedef boct_tree<short,boxm_edge_sample<float> > tree_type;
-        boxm_scene<tree_type>* scene = new boxm_scene<tree_type>();
-        scene->load_scene(parser);
-        scene_ptr = scene;
-      }
+  }
+  else if (scene_ptr->appearence_model() == BSTA_MOG_F1) {
+    if (!scene_ptr->multi_bin())
+    {
+      typedef boct_tree<short,boxm_apm_traits<BOXM_APM_MOG_GREY>::apm_datatype > tree_type;
+      boxm_scene<tree_type>* scene = new boxm_scene<tree_type>();
+      scene->load_scene(parser);
+      scene_ptr = scene;
     }
-    else if (scene_ptr->appearence_model() == BOXM_EDGE_LINE) {
-      if (!scene_ptr->multi_bin())
-      {
-        typedef boct_tree<short,boxm_inf_line_sample<float> > tree_type;
-        boxm_scene<tree_type>* scene = new boxm_scene<tree_type>();
-        scene->load_scene(parser);
-        scene_ptr = scene;
-      }
+  }
+  else if (scene_ptr->appearence_model() == BSTA_GAUSS_F1) {
+    if (!scene_ptr->multi_bin())
+    {
+      typedef boct_tree<short,bsta_num_obs<bsta_gauss_sf1> > tree_type;
+      boxm_scene<tree_type>* scene = new boxm_scene<tree_type>();
+      scene->load_scene(parser);
+      scene_ptr = scene;
     }
-    else {
-      vcl_cerr << "boxm_create_scene_process: undefined APM type\n";
-      return false;
+  }
+  else if (scene_ptr->appearence_model() == BOXM_EDGE_FLOAT) {
+    if (!scene_ptr->multi_bin())
+    {
+      typedef boct_tree<short,boxm_edge_sample<float> > tree_type;
+      boxm_scene<tree_type>* scene = new boxm_scene<tree_type>();
+      scene->load_scene(parser);
+      scene_ptr = scene;
     }
+  }
+  else if (scene_ptr->appearence_model() == BOXM_EDGE_LINE) {
+    if (!scene_ptr->multi_bin())
+    {
+      typedef boct_tree<short,boxm_inf_line_sample<float> > tree_type;
+      boxm_scene<tree_type>* scene = new boxm_scene<tree_type>();
+      scene->load_scene(parser);
+      scene_ptr = scene;
+    }
+  }
+  else if (scene_ptr->appearence_model() == BOXM_EDGE_TANGENT_LINE) {
+    if (!scene_ptr->multi_bin())
+    {
+      typedef boct_tree<short,boxm_edge_tangent_sample<float> > tree_type;
+      boxm_scene<tree_type>* scene = new boxm_scene<tree_type>();
+      scene->load_scene(parser);
+      scene_ptr = scene;
+    }
+  }
+  else if (scene_ptr->appearence_model() == BOXM_SCALAR_FLOAT) {
+    typedef boct_tree<short, boxm_scalar_sample<float> > tree_type;
+    boxm_scene<tree_type>* scene = new boxm_scene<tree_type>();
+    scene->load_scene(parser);
+    scene_ptr = scene;
+  }
+  else {
+    vcl_cerr << "boxm_create_scene_process: undefined APM type\n";
+    return false;
+  }
 
   //store output
   pro.set_output_val<boxm_scene_base_sptr>(0, scene_ptr);
