@@ -1,9 +1,9 @@
+#include "brec_part_gaussian.h"
 //:
 // \file
 // \author Ozge C Ozcanli (ozge@lems.brown.edu)
 // \date Oct 16, 2008
 
-#include "brec_part_gaussian.h"
 #include "brec_part_gaussian_sptr.h"
 
 #include <vil/vil_convert.h>
@@ -18,10 +18,11 @@
 #include <vnl/vnl_gamma.h>
 #include <vcl_iostream.h>
 #include <vcl_fstream.h>
+#include <vcl_sstream.h>
 
 #include <bsta/algo/bsta_fit_weibull.h>
 #include <bsta/bsta_histogram.h>
-#include <bsta/bsta_gauss_f1.h>
+#include <bsta/bsta_gauss_sf1.h>
 
 #include <vul/vul_file.h>
 #include <vul/vul_psfile.h>
@@ -30,7 +31,7 @@
 bool extract_gaussian_primitives(vil_image_resource_sptr img, float lambda0, float lambda1, float theta, bool bright, float cutoff_percentage, float strength_threshold, unsigned type, vcl_vector<brec_part_instance_sptr>& parts)
 {
   vil_image_view<float> fimg = brip_vil_float_ops::convert_to_float(img);
-  vil_image_view<float> extr = brip_vil_float_ops::extrema(fimg, lambda0, lambda1, theta, bright, true);
+  vil_image_view<float> extr = brip_vil_float_ops::extrema(fimg, lambda0, lambda1, theta, bright, false,true);
   if (extr.nplanes() < 2)
     return false;
 
@@ -48,7 +49,7 @@ bool extract_gaussian_primitives(vil_image_resource_sptr img, float lambda0, flo
   float min, max;
   vil_math_value_range(res, min, max);
 
-#if 1
+#if 0
   vcl_cout << "res min: " << min << " max: " << max << vcl_endl;
   vil_image_view<vxl_byte> res_o(ni, nj);
   vil_convert_stretch_range_limited(res, res_o, min, max);
@@ -63,7 +64,7 @@ bool extract_gaussian_primitives(vil_image_resource_sptr img, float lambda0, flo
 #endif // 0
   vil_image_view<float> strength_map(ni, nj);
   vil_convert_stretch_range_limited(res, strength_map, 0.0f, val, 0.0f, 1.0f);
-#if 1
+#if 0
   vil_math_value_range(strength_map, min, max);
   vcl_cout << "strength_map min: " << min << " max: " << max << vcl_endl;
   vil_convert_stretch_range_limited(strength_map, res_o, min, max);
@@ -92,7 +93,6 @@ bool extract_gaussian_primitives(vil_image_resource_sptr img, float lambda0, flo
   vcl_cout << "img min: " << min << " max: " << max << vcl_endl;
   vil_math_value_range(mask, min, max);
   vcl_cout << "mask min: " << min << " max: " << max << vcl_endl;
-#endif
 
   vil_image_view<bool> res_bool;
   vil_threshold_above(res, res_bool, max/2);
@@ -100,6 +100,7 @@ bool extract_gaussian_primitives(vil_image_resource_sptr img, float lambda0, flo
   vil_convert_cast(res_bool, res_bool_f);
   vil_convert_stretch_range_limited(res_bool_f, res_o, 0.0f, 1.0f);
   vil_save(res_o, "./temp_thresholded.png");
+#endif
 
   return true;
 }
@@ -231,7 +232,7 @@ vnl_vector_fixed<float,2>
 brec_part_gaussian::direction_vector(void)  // return a unit vector that gives direction of this instance in the image
 {
   vnl_vector_fixed<float,2> v;
-  double theta_rad = theta_*vnl_math::pi/180.0;
+  double theta_rad = theta_*vnl_math::pi_over_180;
   v(0) = (float)vcl_cos(theta_rad);
   v(1) = (float)vcl_sin(theta_rad);
   return v;
@@ -334,7 +335,7 @@ bool brec_part_gaussian::construct_bg_response_model(vil_image_view<float>& mean
   unsigned nj = mean_img.nj();
 
   // find the response img for this operator
-  vil_image_view<float> mean_res = brip_vil_float_ops::extrema(mean_img, lambda0_, lambda1_, theta_, bright_, true); // was "false"
+  vil_image_view<float> mean_res = brip_vil_float_ops::extrema(mean_img, lambda0_, lambda1_, theta_, bright_, false, true); // was "false"
 #if 0
   vil_save(mean_res, "mean_response_img.tiff");
 #endif // 0
@@ -374,7 +375,7 @@ bool brec_part_gaussian::construct_bg_response_model_gauss(vil_image_view<float>
   unsigned nj = mean_img.nj();
 
   // find the response img for this operator
-  vil_image_view<float> mean_res = brip_vil_float_ops::extrema(mean_img, lambda0_, lambda1_, theta_, bright_, true, true);
+  vil_image_view<float> mean_res = brip_vil_float_ops::extrema(mean_img, lambda0_, lambda1_, theta_, bright_, false, true, true);
   // find the sd dev of the operator at every pixel
   vbl_array_2d<float> kernel; vbl_array_2d<bool> mask;
   brip_vil_float_ops::extrema_kernel_mask(lambda0_, lambda1_, theta_, kernel, mask);
@@ -414,7 +415,7 @@ bool brec_part_gaussian::construct_class_response_models(vil_image_view<float>&
   unsigned nj = img.nj();
 
   // find the response img for this operator
-  vil_image_view<float> res = brip_vil_float_ops::extrema(img, lambda0_, lambda1_, theta_, bright_, true);
+  vil_image_view<float> res = brip_vil_float_ops::extrema(img, lambda0_, lambda1_, theta_, bright_, false, true);
   if (res.ni() != ni || res.nj() != nj)
     return false;
 
@@ -537,7 +538,7 @@ bool brec_part_gaussian::update_response_hist(vil_image_view<float>& img, vil_im
   unsigned nj = img.nj();
 
   // find the response img for this operator
-  vil_image_view<float> res = brip_vil_float_ops::extrema(img, lambda0_, lambda1_, theta_, bright_, false); // was: "true"
+  vil_image_view<float> res = brip_vil_float_ops::extrema(img, lambda0_, lambda1_, theta_, bright_, false, false); // was: "true"
   if (res.ni() != ni || res.nj() != nj)
     return false;
 
@@ -571,7 +572,7 @@ bool brec_part_gaussian::extract(vil_image_view<float>& img, vil_image_view<floa
   unsigned nj = img.nj();
 
   // find the response img for this operator
-  vil_image_view<float> op_res = brip_vil_float_ops::extrema(img, lambda0_, lambda1_, theta_+rot_angle, bright_, false);
+  vil_image_view<float> op_res = brip_vil_float_ops::extrema(img, lambda0_, lambda1_, theta_+rot_angle, bright_, false, false);
   if (op_res.ni() != ni || op_res.nj() != nj)
     return false;
 
@@ -641,13 +642,10 @@ bool brec_part_gaussian::extract(vil_image_view<float>& img, vil_image_view<floa
       float pos_c_b = 0.0f;
       float pos_nc_b = 0.0f;
 
-      if (i == 459 && j == 735)
-        vcl_cout << "here!\n";
-
       float pf = fg_prob_operator(fg_prob_image, i, j); // was: fg_prob_image(i, j);
 
       float pdb = 0.0f;
-      bsta_gauss_f1 pdbg(mu_bk, sigma_bk*sigma_bk);
+      bsta_gauss_sf1 pdbg(mu_bk, sigma_bk*sigma_bk);
       pdb = pdbg.prob_density(res);
 
       float pd_c = pd_class.prob_density(res); // prob density class
@@ -701,7 +699,7 @@ bool brec_part_gaussian::extract(vil_image_view<float>& img, vil_image_view<floa
   unsigned nj = img.nj();
 
   // find the response img for this operator
-  vil_image_view<float> op_res = brip_vil_float_ops::extrema(img, lambda0_, lambda1_, theta_+rot_angle, bright_, false);
+  vil_image_view<float> op_res = brip_vil_float_ops::extrema(img, lambda0_, lambda1_, theta_+rot_angle, bright_, false, false);
   if (op_res.ni() != ni || op_res.nj() != nj)
     return false;
 
@@ -748,7 +746,7 @@ bool brec_part_gaussian::extract(vil_image_view<float>& img, vil_image_view<floa
 //  Assumes that k_ and lambda_ for the foreground response model has already been set
 bool brec_part_gaussian::update_foreground_posterior(vil_image_view<float>& img,
                                                      vil_image_view<float>& fg_prob_img,
-                                                     vil_image_view<bool>& mask,
+                                                     vil_image_view<bool>& mask, // FIXME - unused
                                                      vil_image_view<float>& mean_img,
                                                      vil_image_view<float>& std_dev_img)
 {
@@ -761,7 +759,7 @@ bool brec_part_gaussian::update_foreground_posterior(vil_image_view<float>& img,
   unsigned nj = img.nj();
 
   // find the response img for this operator
-  vil_image_view<float> op_res = brip_vil_float_ops::extrema(img, lambda0_, lambda1_, theta_, bright_, false);
+  vil_image_view<float> op_res = brip_vil_float_ops::extrema(img, lambda0_, lambda1_, theta_, bright_, false, false);
   if (op_res.ni() != ni || op_res.nj() != nj)
     return false;
 
@@ -793,7 +791,7 @@ bool brec_part_gaussian::update_foreground_posterior(vil_image_view<float>& img,
             prob_back = 1.0f-prob_fore;
 #endif // 0
 
-      bsta_gauss_f1 pdbg(mu_bk, sigma_bk*sigma_bk);
+      bsta_gauss_sf1 pdbg(mu_bk, sigma_bk*sigma_bk);
       float pdb = pdbg.prob_density(res);
 
       float pdf = 0.0f; // was: = pdfg.prob_density(res); // prob density foreground
