@@ -248,13 +248,13 @@ bool brec_part_hierarchy_detector::detect(vil_image_view<float>& img, vil_image_
 // check for existence of upper_p with central_p as its central part and map will tell if all the other parts exist
 brec_part_instance_sptr
 brec_part_hierarchy_detector::exists(brec_part_base_sptr upper_p,
-                                     brec_part_instance_sptr central_p, unsigned ni, unsigned nj,
+                                     brec_part_instance_sptr central_p, unsigned /*ni*/, unsigned /*nj*/, // FIXME - ni and nj unused
                                      Rtree_type* lower_rtree,
                                      float det_threshold)
 {
   // first check if types and layers of central_p instance matches with upper_p's info
   if (upper_p->central_part()->type_ != central_p->type_ || upper_p->layer_ != central_p->layer_ + 1) {
-    vcl_cout << "central_p instance passed is not compatible with the upper layer part passes\n";
+    vcl_cout << "central_p instance passed is not compatible with the upper layer part passed\n";
     return 0;
   }
 
@@ -615,14 +615,14 @@ void brec_part_hierarchy_detector::extract_upper_layer(vcl_vector<brec_part_inst
 }
 
 //: Binary io, NOT IMPLEMENTED, signatures defined to use brec_part_hierarchy as a brdb_value
-void vsl_b_write(vsl_b_ostream & os, brec_part_hierarchy_detector const &ph)
+void vsl_b_write(vsl_b_ostream & /*os*/, brec_part_hierarchy_detector const & /*ph*/)
 {
   vcl_cerr << "vsl_b_write() -- Binary io, NOT IMPLEMENTED, signatures defined to use brec_part_hierarchy_learner as a brdb_value\n";
   return;
 }
 
 //: Binary io, NOT IMPLEMENTED, signatures defined to use brec_part_hierarchy as a brdb_value
-void vsl_b_read(vsl_b_istream & is, brec_part_hierarchy_detector &ph)
+void vsl_b_read(vsl_b_istream & /*is*/, brec_part_hierarchy_detector & /*ph*/)
 {
   vcl_cerr << "vsl_b_read() -- Binary io, NOT IMPLEMENTED, signatures defined to use brec_part_hierarchy_learner as a brdb_value\n";
   return;
