@@ -1,9 +1,9 @@
+#include "brec_part_hierarchy_learner.h"
 //:
 // \file
 // \author Ozge C Ozcanli (ozge@lems.brown.edu)
 // \date Jan 19, 2009
 
-#include "brec_part_hierarchy_learner.h"
 #include "brec_part_hierarchy_learner_sptr.h"
 
 #include <bsta/bsta_histogram.h>
@@ -15,6 +15,7 @@
 #include <vcl_algorithm.h> // for std::sort()
 #include <vcl_limits.h>
 #include <vcl_cmath.h> // for std::cos() and std::sin()
+#include <vcl_sstream.h>
 
 //: check the "true" part of the mask
 bool check_equal(vbl_array_2d<bool>& left_array, vbl_array_2d<bool>& right_array)
@@ -92,7 +93,7 @@ void brec_part_hierarchy_learner::initialize_layer0_as_gaussians(int ndirs, floa
   n_ = n; // visualization parameter to plot histograms into m files
   // stats for bright operators
   float theta = 0.0f;
-  float theta_inc = 180.0f/ndirs;
+  float theta_inc = 180.0f/(float)ndirs;
   unsigned type_cnt = 0;
 
   vcl_vector<vbl_array_2d<bool> > masks;
@@ -486,7 +487,7 @@ bool brec_part_hierarchy_learner::layer_n_fit_distributions(unsigned class_id, u
     brec_part_instance_sptr layer_n_part = (qit->second).first;
 
     unsigned d_nbins = d_hist->nbins();
-    float d_delta = float(radius_/d_nbins);
+    float d_delta = radius_/float(d_nbins);
 
     // create 1D marginalized distance sample set from nD set
     bsta_sample_set<double,1> d_set;
@@ -523,9 +524,9 @@ bool brec_part_hierarchy_learner::layer_n_fit_distributions(unsigned class_id, u
     else {
       // now replace the histogram with the mean shift fitted one
       for (unsigned aa = 0; aa < d_nbins; aa++) {
-        float pt = (aa+1)*d_delta;
+        float pt = float(aa+1)*d_delta;
         double val = d_out_dist.prob_density(pt);
-        d_hist->upcount((aa+1)*d_delta, val);
+        d_hist->upcount(float(aa+1)*d_delta, val);
       }
     }
 
@@ -553,9 +554,9 @@ bool brec_part_hierarchy_learner::layer_n_fit_distributions(unsigned class_id, u
     else {
       // now replace the histogram with the mean shift fitted one
       for (unsigned aa = 0; aa < a_nbins; aa++) {
-        float pt = (aa+1)*a_delta;
+        float pt = float(aa+1)*a_delta;
         double val = a_out_dist.prob_density(pt);
-        a_hist->upcount((aa+1)*a_delta, val);
+        a_hist->upcount(float(aa+1)*a_delta, val);
       }
     }
 
@@ -902,14 +903,14 @@ void brec_part_hierarchy_learner::print_to_m_file_layer0_fitted_dists(vcl_string
 }
 
 //: Binary io, NOT IMPLEMENTED, signatures defined to use brec_part_hierarchy as a brdb_value
-void vsl_b_write(vsl_b_ostream & os, brec_part_hierarchy_learner const &ph)
+void vsl_b_write(vsl_b_ostream & /*os*/, brec_part_hierarchy_learner const & /*ph*/)
 {
   vcl_cerr << "vsl_b_write() -- Binary io, NOT IMPLEMENTED, signatures defined to use brec_part_hierarchy_learner as a brdb_value\n";
   return;
 }
 
 //: Binary io, NOT IMPLEMENTED, signatures defined to use brec_part_hierarchy as a brdb_value
-void vsl_b_read(vsl_b_istream & is, brec_part_hierarchy_learner &ph)
+void vsl_b_read(vsl_b_istream & /*is*/, brec_part_hierarchy_learner & /*ph*/)
 {
   vcl_cerr << "vsl_b_read() -- Binary io, NOT IMPLEMENTED, signatures defined to use brec_part_hierarchy_learner as a brdb_value\n";
   return;
