@@ -11,9 +11,6 @@
 #include <bvxm/pro/bvxm_processes.h>
 #include <bvxm/pro/bvxm_register.h>
 
-#include <vcl_string.h>
-#include <vcl_iostream.h>
-
 #include <brdb/brdb_value.h>
 #include <brdb/brdb_selection.h>
 
@@ -22,6 +19,15 @@
 #include <bprb/bprb_macros.h>
 #include <bprb/bprb_parameters_sptr.h>
 #include <bprb/bprb_parameters.h>
+
+#include <brip/brip_vil_float_ops.h>
+#include <vpgl/vpgl_perspective_camera.h>
+#include <vpgl/vpgl_rational_camera.h>
+
+#include <brec/brec_bg_pair_density.h>
+#include <brec/pro/brec_processes.h>
+#include <brec/pro/brec_register.h>
+
 #include <vil/vil_image_view.h>
 #include <vnl/vnl_double_3x4.h>
 #include <vnl/vnl_math.h>
@@ -29,14 +35,10 @@
 #include <vgl/vgl_point_3d.h>
 #include <vgl/vgl_box_2d.h>
 #include <vgl/vgl_box_3d.h>
-
-#include <brip/brip_vil_float_ops.h>
 #include <vul/vul_file.h>
-#include <vpgl/vpgl_perspective_camera.h>
 
-#include <brec/brec_bg_pair_density.h>
-#include <brec/pro/brec_processes.h>
-#include <brec/pro/brec_register.h>
+#include <vcl_string.h>
+#include <vcl_iostream.h>
 
 //:
 vpgl_rational_camera<double>
@@ -44,16 +46,11 @@ perspective_to_rational(vpgl_perspective_camera<double>& cam_pers)
 {
   vnl_double_3x4 cam_pers_matrix = cam_pers.get_matrix();
   vcl_vector<double> neu_u,den_u,neu_v,den_v;
-  double x_scale = 1.0,
-         x_off = 0.0,
-         y_scale = 1.0,
-         y_off = 0.0,
-         z_scale = 1.0,
-         z_off = 0.0,
-         u_scale = 1.0,
-         u_off = 0.0,
-         v_scale = 1.0,
-         v_off = 0.0;
+  double x_scale = 1.0, x_off = 0.0,
+         y_scale = 1.0, y_off = 0.0,
+         z_scale = 1.0, z_off = 0.0,
+         u_scale = 1.0, u_off = 0.0,
+         v_scale = 1.0, v_off = 0.0;
 
   for (int i=0; i<20; i++) {
     neu_u.push_back(0.0);
