@@ -1,6 +1,4 @@
 #include <testlib/testlib_test.h>
-#include <vcl_iostream.h>
-#include <vcl_vector.h>
 
 #include <brec/brec_part_base.h>
 #include <brec/brec_part_base_sptr.h>
@@ -9,17 +7,14 @@
 #include <brec/brec_hierarchy_edge.h>
 #include <brec/brec_hierarchy_edge_sptr.h>
 #include <brec/brec_part_hierarchy_builder.h>
-
-#include <vil/vil_save.h>
-#include <vil/vil_load.h>
-#include <vil/vil_math.h>
-#include <vil/vil_convert.h>
+#include <brec/brec_part_gaussian.h>
 
 #include <brip/brip_vil_float_ops.h>
-
-#include <brec/brec_part_gaussian.h>
 #include <bsta/algo/bsta_gaussian_updater.h>
 
+#include <vcl_iostream.h>
+#include <vcl_vector.h>
+
 static void test_brec_hierarchy_edge()
 {
   brec_part_gaussian_sptr p0 = new brec_part_gaussian(0.0f, 0.0f, 0.0f, 1.0f, 1.0f, -45.0f, false, 0);
@@ -28,7 +23,7 @@ static void test_brec_hierarchy_edge()
   brec_hierarchy_edge_sptr e = new brec_hierarchy_edge(p0->cast_to_base(), p1->cast_to_base(), false);
 
   vnl_vector_fixed<float,2> c(111.0f,119.0f); // center measured from the image
-  vnl_vector_fixed<float,2> p(107.0f,123.0f); 
+  vnl_vector_fixed<float,2> p(107.0f,123.0f);
   vnl_vector_fixed<float,2> sample = p - c;
 
 
@@ -38,4 +33,3 @@ static void test_brec_hierarchy_edge()
 }
 
 TESTMAIN( test_brec_hierarchy_edge );
-
