@@ -12,6 +12,8 @@ DECLARE( test_max_scale_response );
 DECLARE( test_mask );
 DECLARE( test_label_equivalence );
 DECLARE( test_extrema );
+DECLARE( test_filter_bank );
+DECLARE( test_gain_offset_solver );
 void
 register_tests()
 {
@@ -25,8 +27,9 @@ register_tests()
   REGISTER( test_quadtree );
   REGISTER( test_max_scale_response );
   REGISTER( test_mask );
-  REGISTER( test_label_equivalence );
   REGISTER( test_extrema );
+  REGISTER( test_filter_bank );
+  REGISTER( test_gain_offset_solver );
 }
 
 DEFINE_MAIN;
