@@ -1,4 +1,4 @@
-#include <bvpl/bvpl_octree/bvpl_octree_sample.h>
+#include <bvpl/bvpl_octree/sample/bvpl_octree_sample.h>
 #include <boct/boct_tree.h>
 #include <boxm/boxm_block.txx>
 #include <boxm/boxm_scene.txx>
