@@ -12,10 +12,10 @@
 //   <none yet>
 // \endverbatim
 
-#include "bvpl_octree_sample.h"
+#include <bvpl/bvpl_octree/sample/bvpl_octree_sample.h>
 #include <boct/boct_tree_cell.h>
 #include <bsta/bsta_attributes.h>
-#include <bsta/bsta_gauss_f1.h>
+#include <bsta/bsta_gauss_sf1.h>
 
 //: Float to float
 template <class T_loc>
@@ -26,7 +26,7 @@ float bvpl_cell_to_float(boct_tree_cell<T_loc, bvpl_octree_sample<float> >* cell
 
 //: Mixture of gaussians to float; return the mean
 template <class T_loc>
-float bvpl_cell_to_float(boct_tree_cell<T_loc, bvpl_octree_sample<bsta_num_obs<bsta_gauss_f1> > >* cell)
+float bvpl_cell_to_float(boct_tree_cell<T_loc, bvpl_octree_sample<bsta_num_obs<bsta_gauss_sf1> > >* cell)
 {
   return cell->data().response_.mean();
 }
