@@ -4,14 +4,16 @@
 #include <bprb/bprb_batch_process_manager.h>
 #include <bprb/bprb_func_process.h>
 #include "bvpl_processes.h"
-#include <bvpl/bvpl_kernel.h>
+#include <bvpl/kernels/bvpl_kernel.h>
 #include <bvpl/util/bvpl_corner_pair_finder.h>
+#include <bvpl/util/bvpl_bundler_features_2d.h>
 
 void bvpl_register::register_datatype()
 {
   REGISTER_DATATYPE( bvpl_kernel_sptr );
   REGISTER_DATATYPE( bvpl_kernel_vector_sptr );
   REGISTER_DATATYPE( bvpl_corner_pairs_sptr );
+  REGISTER_DATATYPE( bvpl_bundler_features_2d_sptr );
 }
 
 void bvpl_register::register_process()
@@ -20,6 +22,7 @@ void bvpl_register::register_process()
   REG_PROCESS_FUNC_CONS(bprb_func_process, bprb_batch_process_manager, bvpl_vector_operator_process, "bvplVectorOperatorProcess");
   REG_PROCESS_FUNC_CONS(bprb_func_process, bprb_batch_process_manager, bvpl_create_edge2d_kernel_process, "bvplCreateEdge2dKernelProcess");
   REG_PROCESS_FUNC_CONS(bprb_func_process, bprb_batch_process_manager, bvpl_create_edge3d_kernel_process, "bvplCreateEdge3dKernelProcess");
+  REG_PROCESS_FUNC_CONS(bprb_func_process, bprb_batch_process_manager, bvpl_create_gauss3d_x_kernel_process, "bvplCreateGauss3dXKernelProcess");
   REG_PROCESS_FUNC_CONS(bprb_func_process, bprb_batch_process_manager, bvpl_create_gauss3d_xx_kernel_process, "bvplCreateGauss3dXXKernelProcess");
   REG_PROCESS_FUNC_CONS(bprb_func_process, bprb_batch_process_manager, bvpl_create_edge2d_kernel_vector_process, "bvplCreateEdge2dKernelVectorProcess");
   REG_PROCESS_FUNC_CONS(bprb_func_process, bprb_batch_process_manager, bvpl_create_edge3d_kernel_vector_process, "bvplCreateEdge3dKernelVectorProcess");
@@ -45,4 +48,8 @@ void bvpl_register::register_process()
   REG_PROCESS_FUNC_CONS(bprb_func_process, bprb_batch_process_manager, bvpl_load_pair_grid_process, "bvplLoadPairGridProcess");
   REG_PROCESS_FUNC_CONS(bprb_func_process, bprb_batch_process_manager, bvpl_find_pairs_process_process, "bvplFindPairsProcess");
   REG_PROCESS_FUNC_CONS(bprb_func_process, bprb_batch_process_manager, bvpl_pair_to_float_process, "bvplPairToFloatProcess");
+  REG_PROCESS_FUNC_CONS(bprb_func_process, bprb_batch_process_manager, bvpl_bundler_features_2d_compute_process, "bvplBundlerFeatures2dComputeProcess");
+  REG_PROCESS_FUNC_CONS(bprb_func_process, bprb_batch_process_manager, bvpl_bundler_features_2d_write_txt_process, "bvplBundlerFeatures2dWriteTxtProcess");
+  REG_PROCESS_FUNC_CONS(bprb_func_process, bprb_batch_process_manager, bvpl_bundler_features_2d_read_bin_process, "bvplBundlerFeatures2dReadBinProcess");
+  REG_PROCESS_FUNC_CONS(bprb_func_process, bprb_batch_process_manager, bvpl_bundler_features_2d_write_bin_process, "bvplBundlerFeatures2dWriteBinProcess");
 }
