@@ -15,7 +15,7 @@
 #include <bprb/bprb_parameters.h>
 #include <bvxm/grid/bvxm_voxel_grid_base.h>
 #include <bvxm/grid/bvxm_voxel_grid.h>
-#include <bvpl/bvpl_kernel_factory.h>
+#include <bvpl/kernels/bvpl_kernel_factory.h>
 #include <bvpl/bvpl_direction_to_color_map.h>
 #include <vnl/vnl_float_4.h>
 
@@ -97,7 +97,7 @@ bool bvpl_convert_id_to_hue_process(bprb_func_process& pro)
       bvpl_write_colors_to_svg(kernel_vector,colors,map_output_file);
       return true;
     }
-    if (bvxm_voxel_grid<bsta_num_obs<bsta_gauss_f1 > > *response_grid = dynamic_cast< bvxm_voxel_grid<bsta_num_obs<bsta_gauss_f1 > >* >(response_base.ptr()))
+    if (bvxm_voxel_grid<bsta_num_obs<bsta_gauss_sf1 > > *response_grid = dynamic_cast< bvxm_voxel_grid<bsta_num_obs<bsta_gauss_sf1 > >* >(response_base.ptr()))
     {
       //assign hue values evenly dristributed on the color wheel
       //the wheel starts and ends on red, so we don't want to get back to the end
