@@ -17,11 +17,11 @@
 
 #include <bvxm/grid/bvxm_voxel_grid.h>
 #include <bvxm/grid/bvxm_opinion.h>
-#include <bvpl/bvpl_kernel_factory.h>
-#include <bvpl/bvpl_edge2d_functor.h>
-#include <bvpl/bvpl_edge_geometric_mean_functor.h>
-#include <bvpl/bvpl_edge_algebraic_mean_functor.h>
-#include <bvpl/bvpl_opinion_functor.h>
+#include <bvpl/kernels/bvpl_kernel_factory.h>
+#include <bvpl/functors/bvpl_edge2d_functor.h>
+#include <bvpl/functors/bvpl_edge_geometric_mean_functor.h>
+#include <bvpl/functors/bvpl_edge_algebraic_mean_functor.h>
+#include <bvpl/functors/bvpl_opinion_functor.h>
 #include <bvpl/bvpl_susan_opinion_operator.h>
 
 namespace bvpl_susan_opinion_operator_process_globals
@@ -82,7 +82,7 @@ bool bvpl_susan_opinion_operator_process(bprb_func_process& pro)
   bvxm_voxel_grid<bvxm_opinion> * in_opn_grid
       =dynamic_cast<bvxm_voxel_grid<bvxm_opinion> *>(in_opn_grid_base.ptr());
 
-  if(in_dir_grid)
+  if(in_opn_grid)
     vcl_cout<<"Successful cast"<<vcl_endl;
   bvxm_voxel_grid<bvxm_opinion> * output_grid=new bvxm_voxel_grid<bvxm_opinion>(out_grid_path,in_dir_grid->grid_size());
   bvpl_susan_opinion_operator oper;
