@@ -18,17 +18,17 @@
 #include <bvxm/grid/bvxm_voxel_grid.h>
 #include <bvxm/grid/bvxm_voxel_grid_base.h>
 #include <bvxm/grid/bvxm_opinion.h>
-#include <bvpl/bvpl_kernel_factory.h>
-#include <bvpl/bvpl_edge2d_functor.h>
-#include <bvpl/bvpl_edge_algebraic_mean_functor.h>
-#include <bvpl/bvpl_edge_geometric_mean_functor.h>
-#include <bvpl/bvpl_gauss_convolution_functor.h>
-#include <bvpl/bvpl_opinion_functor.h>
+#include <bvpl/kernels/bvpl_kernel_factory.h>
+#include <bvpl/functors/bvpl_edge2d_functor.h>
+#include <bvpl/functors/bvpl_edge_algebraic_mean_functor.h>
+#include <bvpl/functors/bvpl_edge_geometric_mean_functor.h>
+#include <bvpl/functors/bvpl_gauss_convolution_functor.h>
+#include <bvpl/functors/bvpl_opinion_functor.h>
 #include <bvpl/bvpl_neighb_operator.h>
 #include <bvpl/bvpl_vector_operator.h>
 
 #include <bsta/bsta_attributes.h>
-#include <bsta/bsta_gauss_f1.h>
+#include <bsta/bsta_gauss_sf1.h>
 
 namespace bvpl_vector_operator_process_globals
 {
@@ -52,6 +52,7 @@ namespace bvpl_vector_operator_process_globals
 bool bvpl_vector_operator_process_cons(bprb_func_process& pro)
 {
   using namespace bvpl_vector_operator_process_globals;
+
   vcl_vector<vcl_string> input_types_(n_inputs_);
   input_types_[0] = "bvxm_voxel_grid_base_sptr";
   input_types_[1] = "bvpl_kernel_vector_sptr";
@@ -144,7 +145,7 @@ bool bvpl_vector_operator_process(bprb_func_process& pro)
     return true;
   }
   else if (datatype == "bsta_gauss_f1") {
-    typedef bsta_num_obs<bsta_gauss_f1> gauss_type;
+    typedef bsta_num_obs<bsta_gauss_sf1> gauss_type;
     if (bvxm_voxel_grid<gauss_type>* grid=dynamic_cast<bvxm_voxel_grid<gauss_type> *>(grid_base.ptr())) {
       bvxm_voxel_grid<gauss_type> *grid_out= new bvxm_voxel_grid<gauss_type>(out_grid_path, grid->grid_size());
       bvxm_voxel_grid<int > *id_grid=new bvxm_voxel_grid<int >(id_grid_path, grid->grid_size());
