@@ -1,12 +1,10 @@
-//:
-// \file
 #include <testlib/testlib_test.h>
+
 #include <bvpl/bvpl_direction_to_color_map.h>
 #include <vgl/vgl_point_3d.h>
 #include <vcl_iostream.h>
-#include <vul/vul_timer.h>
 
-//: Test changes
+// Test changes
 static void test_direction_to_color_map()
 {
   double theta_res = vnl_math::pi_over_4;
@@ -26,7 +24,6 @@ static void test_direction_to_color_map()
   }
   bvpl_direction_to_color_map color_map(samples,"random");
   color_map.make_svg_color_map("cmap.svg");
-
 }
 
 TESTMAIN( test_direction_to_color_map );
