@@ -4,14 +4,17 @@
 
 // processes
 #include <bvpl/pro/bvpl_register.h>
+#include <bvpl/kernels/pro/bvpl_kernels_register.h>
 #include <bvxm/grid/pro/bvxm_grid_register.h>
+#include <bvxm/algo/pro/bvxm_algo_register.h>
 
 PyObject *
 register_processes(PyObject *self, PyObject *args)
 {
   bvpl_register::register_process();
+  bvpl_kernels_register::register_process();
   bvxm_grid_register::register_process();
-
+  bvxm_algo_register::register_process();
   Py_INCREF(Py_None);
   return Py_None;
 }
@@ -21,8 +24,9 @@ register_datatypes(PyObject *self, PyObject *args)
 {
   register_basic_datatypes();
   bvpl_register::register_datatype();
+  bvpl_kernels_register::register_datatype();
   bvxm_grid_register::register_datatype();
-
+  bvxm_algo_register::register_datatype();
   Py_INCREF(Py_None);
   return Py_None;
 }
