@@ -18,6 +18,8 @@
 #include <vpgl/vpgl_camera.h>
 #include <vul/vul_file.h>
 
+#include <vnl/vnl_math.h>
+
 #include <vgl/vgl_homg_point_2d.h>
 #include <vgl/algo/vgl_h_matrix_2d_compute_linear.h>
 
@@ -251,7 +253,7 @@ bool bvxm_voxel_world::update_lidar_impl(bvxm_image_metadata const& metadata,
 
   vcl_cout << "Pass 1:" << vcl_endl;
 
-  // get ocuppancy probability grid
+  // get occupancy probability grid
   bvxm_voxel_grid_base_sptr ocp_grid_base = this->get_grid<OCCUPANCY>(0,  scale);
   bvxm_voxel_grid<ocp_datatype> *ocp_grid  = static_cast<bvxm_voxel_grid<ocp_datatype>*>(ocp_grid_base.ptr());
 
@@ -266,7 +268,7 @@ bool bvxm_voxel_world::update_lidar_impl(bvxm_image_metadata const& metadata,
   //The default values for the LIDAR Gaussian error ellipsoid
   // X-Y standard deviation set to 1/Sqrt(2) pixel spacing (arbitrary)
   // standard deviation in z measured from actual Buckeye data (0.03 m)
-  double pix_sd = lidar_pixel_size*0.7071;
+  double pix_sd = lidar_pixel_size*vnl_math::sqrt1_2;
   float xy_var = static_cast<float>(pix_sd*pix_sd);
   // The vector of spherical Gaussian variances
   vnl_vector_fixed<float,3> vars(xy_var, xy_var, 0.0009f);
@@ -382,7 +384,7 @@ bool bvxm_voxel_world::update_lidar_impl(bvxm_image_metadata const& metadata,
       bvxm_util::add_slabs(PX_img,mask_slab,mask_slab);
     }
 
-    // note: doing scale and offset in image domain so invalid PLxels become 1.0 and dont affect visX
+    // note: doing scale and offset in image domain so invalid pixels become 1.0 and don't affect visX
     bvxm_voxel_slab<float>::iterator PX_img_it = PX_img.begin();
     visX_accum_it = visX_accum.begin();
     for (; visX_accum_it != visX_accum.end(); ++visX_accum_it, ++PX_img_it) {
@@ -607,7 +609,7 @@ bool bvxm_voxel_world::heightmap(vpgl_camera_double_sptr virtual_camera, vil_ima
   visX_accum_virtual.fill(1.0f);
   max_prob_image.fill(0.0f);
 
-  // get ocuppancy probability grid
+  // get occupancy probability grid
   bvxm_voxel_grid_base_sptr ocp_grid_base = this->get_grid<OCCUPANCY>(0,scale_idx);
   bvxm_voxel_grid<ocp_datatype> *ocp_grid  = static_cast<bvxm_voxel_grid<ocp_datatype>*>(ocp_grid_base.ptr());
 
@@ -638,7 +640,7 @@ bool bvxm_voxel_world::heightmap(vpgl_camera_double_sptr virtual_camera, vil_ima
 
 #define HMAP_DEBUG
 #ifdef  HMAP_DEBUG
-  bvxm_util::write_slab_as_image(heightmap_rough,"c:/research/registration/output/heightmap_rough.tiff");
+  bvxm_util::write_slab_as_image(heightmap_rough,"C:/research/registration/output/heightmap_rough.tiff");
 #endif
   // now clean up height map
   unsigned n_smooth_iterations = 70;
@@ -662,7 +664,7 @@ bool bvxm_voxel_world::heightmap(vpgl_camera_double_sptr virtual_camera, vil_ima
   vil_structuring_element strel(strel_vec,strel_vec);
   vil_median(*heightmap_rough_img,heightmap_med_img,strel);
 
-  // detect inliers as points which dont vary drastically from the median image
+  // detect inliers as points which don't vary drastically from the median image
   vil_image_view<float> med_abs_diff(heightmap.ni(),heightmap.nj());
   vil_math_image_abs_difference(heightmap_med_img,*heightmap_rough_img,med_abs_diff);
   vil_image_view<bool> inliers(heightmap.ni(),heightmap.nj());
@@ -675,8 +677,8 @@ bool bvxm_voxel_world::heightmap(vpgl_camera_double_sptr virtual_camera, vil_ima
   vil_threshold_above(*conf_img,conf_mask,conf_thresh);
 
 #ifdef HMAP_DEBUG
-  vil_save(*conf_img,"c:/research/registration/output/heightmap_conf.tiff");
-  vil_save(heightmap_med_img,"c:/research/registration/output/heightmap_med.tiff");
+  vil_save(*conf_img,"C:/research/registration/output/heightmap_conf.tiff");
+  vil_save(heightmap_med_img,"C:/research/registration/output/heightmap_med.tiff");
 #endif
 
   // initialize with rough heightmap
@@ -707,7 +709,7 @@ bool bvxm_voxel_world::heightmap(vpgl_camera_double_sptr virtual_camera, vil_ima
   vil_median(heightmap_filtered_img,heightmap_filtered_med,strel);
 
 #ifdef HMAP_DEBUG
-  vil_save(heightmap_filtered_med,"c:/research/registration/output/heightmap_filtered.tiff");
+  vil_save(heightmap_filtered_med,"C:/research/registration/output/heightmap_filtered.tiff");
 #endif
 
   // convert back to unsigned
@@ -726,7 +728,7 @@ vgl_point_3d<float> bvxm_voxel_world::voxel_index_to_xyz(unsigned vox_i, unsigne
   vgl_vector_3d<unsigned> num_vox = params_->num_voxels(scale_idx);
 
   // corner in parameters refers to the bottom. we want the top since slice 0 is the top-most slice.
-  vgl_point_3d<float> grid_origin = params_->corner() + (vgl_vector_3d<float>(0.5f, 0.5f, (num_vox.z() - 0.5f))*vox_len);
+  vgl_point_3d<float> grid_origin = params_->corner() + (vgl_vector_3d<float>(0.5f, 0.5f, (float(num_vox.z()) - 0.5f))*vox_len);
   vgl_vector_3d<float> step_i = vox_len*params_->base_x();
   vgl_vector_3d<float> step_j = vox_len*params_->base_y();
   vgl_vector_3d<float> step_k = (-vox_len)*params_->base_z();
