@@ -27,8 +27,8 @@
 #include <vsl/vsl_binary_io.h>
 #include <vgl/io/vgl_io_vector_3d.h>
 #include <vgl/io/vgl_io_point_3d.h>
-#include <vpgl/bgeo/bgeo_lvcs.h>
-#include <vpgl/bgeo/bgeo_lvcs_sptr.h>
+#include <vpgl/vpgl_lvcs.h>
+#include <vpgl/vpgl_lvcs_sptr.h>
 
 class bvxm_world_params : public vbl_ref_count
 {
@@ -44,10 +44,10 @@ class bvxm_world_params : public vbl_ref_count
     const vgl_point_3d<float>& corner,
     const vgl_vector_3d<unsigned int>& num_voxels,
     float voxel_length,
-    bgeo_lvcs_sptr lvcs = bgeo_lvcs_sptr(0),
+    vpgl_lvcs_sptr lvcs = vpgl_lvcs_sptr(0),
     float min_ocp_prob = 0.001f,
     float max_ocp_prob = 0.999f,
-    unsigned max_scale = 0,
+    unsigned max_scale = 1,
     vgl_vector_3d<float> basex = vgl_vector_3d<float>(1.0f,0.0f,0.0f),
     vgl_vector_3d<float> basey = vgl_vector_3d<float>(0.0f,1.0f,0.0f),
     vgl_vector_3d<float> basez = vgl_vector_3d<float>(0.0f,0.0f,1.0f));
@@ -69,7 +69,7 @@ class bvxm_world_params : public vbl_ref_count
 
   inline vgl_vector_3d<unsigned int> num_voxels(unsigned scale=0) {
     vgl_vector_3d<unsigned int> num_voxels_scaled;
-    double divisor=vcl_pow(2.0,-(double)scale); // actually, inverse of divisor
+    double divisor= 1.0 / double(1 << scale); // actually, inverse of divisor
     num_voxels_scaled.set((unsigned int)(num_voxels_.x()*divisor),
                           (unsigned int)(num_voxels_.y()*divisor),
                           (unsigned int)(num_voxels_.z()*divisor));
@@ -77,7 +77,7 @@ class bvxm_world_params : public vbl_ref_count
   }
 
   inline float voxel_length(unsigned scale=0) {
-    return (float)vcl_pow(2.0,(double)scale)*voxel_length_; }
+    return float(1<<scale)*voxel_length_; }
 
   inline vgl_vector_3d<float> base_x() const { return base_x_; }
   inline vgl_vector_3d<float> base_y() const { return base_y_; }
@@ -91,7 +91,7 @@ class bvxm_world_params : public vbl_ref_count
 
   inline float min_occupancy_prob() const { return min_occupancy_prob_; }
   inline float max_occupancy_prob() const { return max_occupancy_prob_; }
-  inline bgeo_lvcs_sptr lvcs() { return lvcs_; }
+  inline vpgl_lvcs_sptr lvcs() { return lvcs_; }
 
   inline float edges_n_normal() const { return edges_n_normal_; }
   inline void increment_edges_n_normal(float increment) { edges_n_normal_ += increment; }
@@ -117,7 +117,7 @@ class bvxm_world_params : public vbl_ref_count
   vgl_point_3d<float> rpc_origin_;
   vgl_vector_3d<unsigned int> num_voxels_;
   float voxel_length_;
-  bgeo_lvcs_sptr lvcs_;
+  vpgl_lvcs_sptr lvcs_;
   float min_occupancy_prob_;
   float max_occupancy_prob_;
   float edges_n_normal_;
