@@ -12,7 +12,16 @@
 bvxm_memory_chunk::bvxm_memory_chunk() : data_(0), size_(0) {}
 
 //: Allocate n bytes of memory
-bvxm_memory_chunk::bvxm_memory_chunk(vxl_uint_64 n) : data_(new char[(unsigned)n]), size_(n) {}
+bvxm_memory_chunk::bvxm_memory_chunk(vxl_uint_64 n)
+{
+  data_ = new (std::nothrow)char[(unsigned)n];
+  
+  if (data_ == 0) {
+    vcl_cout << "bvxm_memory_chunk: Could not allocate data!" << vcl_endl;
+  }
+  
+  size_ = n;
+}
 
 //: Destructor
 bvxm_memory_chunk::~bvxm_memory_chunk()
