@@ -20,7 +20,7 @@
 #include <vul/vul_file.h>
 
 #include <bsta/bsta_distribution.h>
-#include <bsta/bsta_gauss_f1.h>
+#include <bsta/bsta_gauss_sf1.h>
 #include <bsta/bsta_attributes.h>
 #include <bsta/bsta_mixture_fixed.h>
 #include <bsta/bsta_mixture.h>
@@ -38,24 +38,17 @@ namespace bvxm_load_grid_process_globals
 bool bvxm_load_grid_process_cons(bprb_func_process& pro)
 {
   using namespace bvxm_load_grid_process_globals;
-  //This process has no inputs nor outputs only parameters
+
+  // process takes 2 inputs and has 1 output.
   vcl_vector<vcl_string> input_types_(n_inputs_);
   unsigned i=0;
   input_types_[i++]="vcl_string"; //the input path
   input_types_[i++]="vcl_string";//the type e.g. "float","double"...
 
   vcl_vector<vcl_string> output_types_(n_outputs_);
-  i=0;
-  output_types_[i++]="bvxm_voxel_grid_base_sptr";  // The resulting grid
+  output_types_[0]="bvxm_voxel_grid_base_sptr";  // The resulting grid
 
-  vcl_cout<<input_types_.size();
-  if (!pro.set_input_types(input_types_))
-    return false;
-
-  if (!pro.set_output_types(output_types_))
-    return false;
-
-  return true;
+  return pro.set_input_types(input_types_) && pro.set_output_types(output_types_);
 }
 
 
@@ -107,7 +100,7 @@ bool bvxm_load_grid_process(bprb_func_process& pro)
   }
   else if (datatype == "bsta_gaussian_mixture_float_3"){
     //Only floating point are supported for now and mixtures with 3 components.
-    typedef bsta_num_obs<bsta_gauss_f1> gauss_type;
+    typedef bsta_num_obs<bsta_gauss_sf1> gauss_type;
     typedef bsta_mixture_fixed<gauss_type, 3> mix_gauss;
     typedef bsta_num_obs<mix_gauss> mix_gauss_type;
     bvxm_voxel_grid_base_sptr grid = new bvxm_voxel_grid<mix_gauss_type>(input_path);
@@ -115,7 +108,7 @@ bool bvxm_load_grid_process(bprb_func_process& pro)
     return true;
   }
   else if (datatype == "bsta_gauss_f1"){
-    typedef bsta_num_obs<bsta_gauss_f1> gauss_type;
+    typedef bsta_num_obs<bsta_gauss_sf1> gauss_type;
     bvxm_voxel_grid_base_sptr grid = new bvxm_voxel_grid<gauss_type>(input_path);
     pro.set_output_val<bvxm_voxel_grid_base_sptr>(0, grid);
     return true;
@@ -126,21 +119,21 @@ bool bvxm_load_grid_process(bprb_func_process& pro)
     return true;
   }
   else if (datatype == "vnl_float_3"){
-      bvxm_voxel_grid_base_sptr grid = new bvxm_voxel_grid<vnl_float_3>(input_path);
-      pro.set_output_val<bvxm_voxel_grid_base_sptr>(0, grid);
-      return true;
+    bvxm_voxel_grid_base_sptr grid = new bvxm_voxel_grid<vnl_float_3>(input_path);
+    pro.set_output_val<bvxm_voxel_grid_base_sptr>(0, grid);
+    return true;
   }
-    else if (datatype == "vnl_float_4"){
-      bvxm_voxel_grid_base_sptr grid = new bvxm_voxel_grid<vnl_float_4>(input_path);
-      pro.set_output_val<bvxm_voxel_grid_base_sptr>(0, grid);
-      return true;
+  else if (datatype == "vnl_float_4"){
+    bvxm_voxel_grid_base_sptr grid = new bvxm_voxel_grid<vnl_float_4>(input_path);
+    pro.set_output_val<bvxm_voxel_grid_base_sptr>(0, grid);
+    return true;
   }
-
   else if (datatype == "vnl_vector_fixed_float_4"){
     bvxm_voxel_grid_base_sptr grid = new bvxm_voxel_grid<vnl_vector_fixed<float,4> >(input_path);
     pro.set_output_val<bvxm_voxel_grid_base_sptr>(0, grid);
     return true;
-  }else{
+  }
+  else {
     vcl_cerr << "datatype not supported\n";
   }
 
