@@ -16,7 +16,8 @@
 //: globals
 namespace bvxm_display_edge_tangent_world_vrml_process_globals
 {
-  const unsigned n_inputs_ = 3;
+  const unsigned int n_inputs_ = 3;
+  const unsigned int n_outputs_ = 0;
 }
 
 //: set input and output types
