@@ -13,27 +13,37 @@
 #include <bvxm/bvxm_mog_grey_processor.h>
 #include <bvxm/bvxm_edge_ray_processor.h>
 
+namespace bvxm_save_edges_raw_process_globals
+{
+  unsigned int n_inputs_ = 3;
+  unsigned int n_outputs_ = 0;
+}
+
 bool bvxm_save_edges_raw_process_cons(bprb_func_process& pro)
 {
-  // process takes 3 inputs:
+  using namespace bvxm_save_edges_raw_process_globals;
+
+  // process takes 3 inputs and has no outputs:
   //input[0]: The voxel world
   //input[1]: The filename to write to
   //input[2]: Scale
-  unsigned n_inputs_ = 3;
 
   vcl_vector<vcl_string> input_types_(n_inputs_);
   input_types_[0] = "bvxm_voxel_world_sptr";
   input_types_[1] = "vcl_string";
   input_types_[2] = "unsigned";
-  return pro.set_input_types(input_types_);
+  vcl_vector<vcl_string> output_types_(n_outputs_);
+  return pro.set_input_types(input_types_)
+      && pro.set_output_types(output_types_);
 }
 
 bool bvxm_save_edges_raw_process(bprb_func_process& pro)
 {
-  unsigned n_inputs_ = 3;
+  using namespace bvxm_save_edges_raw_process_globals;
+
   if (pro.n_inputs()<n_inputs_)
   {
-    vcl_cout << pro.name() << " The input number should be " << n_inputs_<< vcl_endl;
+    vcl_cout << pro.name() << " The number of inputs should be " << n_inputs_<< vcl_endl;
     return false;
   }
 
