@@ -6,7 +6,8 @@ DECLARE( test_voxel_world );
 DECLARE( test_voxel_world_update );
 DECLARE( test_voxel_world_mog_image );
 DECLARE( test_platform_computations );
-
+DECLARE( test_tangent_update );
+DECLARE( test_illum );
 void register_tests()
 {
   REGISTER( test_apm_processors );
@@ -15,6 +16,8 @@ void register_tests()
   REGISTER( test_voxel_world_update );
   REGISTER( test_voxel_world_mog_image );
   REGISTER( test_platform_computations );
+  REGISTER( test_tangent_update );
+  REGISTER( test_illum );
 }
 
 DEFINE_MAIN;
