@@ -34,7 +34,7 @@ static void test_voxel_world()
   bvxm_world_params_sptr params = new bvxm_world_params();
 
   // NEEDS AN LVCS, TODO: initialize lvcs
-  bgeo_lvcs_sptr lvcs = new bgeo_lvcs();
+  vpgl_lvcs_sptr lvcs = new vpgl_lvcs();
   params->set_params(model_dir,grid_corner,grid_size,vox_len,lvcs);
 
   // create the world
