@@ -35,6 +35,7 @@ class segv_vil_menus
   SEGV_VIL_DLL_DATA static void harris_corners_callback();
   SEGV_VIL_DLL_DATA static void nonmaximal_suppression_callback();
   SEGV_VIL_DLL_DATA static void vd_edges_callback();
+  SEGV_VIL_DLL_DATA static void third_order_edges_callback();
   SEGV_VIL_DLL_DATA static void fit_lines_callback();
   SEGV_VIL_DLL_DATA static void fit_conics_callback();
   SEGV_VIL_DLL_DATA static void fit_overlay_conics_callback();
@@ -61,6 +62,14 @@ class segv_vil_menus
   SEGV_VIL_DLL_DATA static void rot_extrema_callback();
   SEGV_VIL_DLL_DATA static void beaudet_callback();
   SEGV_VIL_DLL_DATA static void parallel_coverage_callback();
+  SEGV_VIL_DLL_DATA static void gradient_mag_angle_callback();
+  SEGV_VIL_DLL_DATA static void fft_callback();
+  SEGV_VIL_DLL_DATA static void display_roi_callback();
+  SEGV_VIL_DLL_DATA static void create_roi_callback();
+  SEGV_VIL_DLL_DATA static void crop_image_callback();
+  SEGV_VIL_DLL_DATA static void gaussian_callback();
+  SEGV_VIL_DLL_DATA static void abs_value_callback();
+
   //JIM METHOD
   SEGV_VIL_DLL_DATA static void project_points_callback();
   //--JIM METHOD
