@@ -38,7 +38,7 @@ gevd_fold::gevd_fold(float smooth_sigma, // width of filter dG
     contourFactor(contour_factor), junctionFactor(junction_factor),
     filterFactor(6)              // factor from gevd_float_operators::Hessian
 {
-  if (smoothSigma < 0.5)        // no guarrantee for 2-pixel separation
+  if (smoothSigma < 0.5)        // no guarantee for 2-pixel separation
     vcl_cerr << "gevd_fold::gevd_fold -- too small smooth_sigma: "
              << smoothSigma << vcl_endl;
   if (smoothSigma > 2)          // smooth out too much the junctions
@@ -86,7 +86,7 @@ gevd_fold::DetectEdgels(const gevd_bufferxy& image,
   gevd_bufferxy *dirx = gevd_float_operators::SimilarBuffer(image);
   gevd_bufferxy *diry = gevd_float_operators::SimilarBuffer(image);
   filterFactor *= gevd_float_operators::Hessian(*smooth, // 2nd-order difference
-                                                 curvature, dirx, diry); // mult factor returned
+                                                curvature, dirx, diry); // mult factor returned
   //If only peaks or valleys are asked for
   for (int j = 0; j < image.GetSizeY(); j++)
     for (int i = 0; i < image.GetSizeX(); i++)
@@ -104,7 +104,7 @@ gevd_fold::DetectEdgels(const gevd_bufferxy& image,
   {
     mag = gevd_float_operators::SimilarBuffer(image);
     angle = gevd_float_operators::SimilarBuffer(image);
-    const float kdeg = 180.f*float(vnl_math::one_over_pi);
+    const float kdeg = float(vnl_math::deg_per_rad);
     for (int j = 0; j < image.GetSizeY(); j++)
       for (int i = 0; i < image.GetSizeX(); i++)
         if ((floatPixel(*mag, i, j) = floatPixel(*curvature, i, j)))
@@ -127,11 +127,13 @@ gevd_fold::DetectEdgels(const gevd_bufferxy& image,
         const float k = -noiseSigma; // given linear interpolation factor
         noiseSigma = ((1-k)*sensorNoise + k*textureNoise) /
           NoiseResponseToFilter(1, smoothSigma, filterFactor);
-      } else {
+      }
+      else {
         vcl_cout << "Can not estimate sensor & texture noise\n";
         noiseSigma = 1;         // reasonable default for 8-bit
       }
-    } else {
+    }
+    else {
       vcl_cout << "Not enough edge elements to estimate noise\n";
       noiseSigma = 1;
     }
@@ -260,7 +262,8 @@ BestFoldExtension(const gevd_bufferxy& smooth,
     }
     best_l = gevd_float_operators::InterpolateParabola(s_m, best_s, s_p, best_s);
     return best_s;
-  } else                        // not found
+  }
+  else                        // not found
     return 0;
 }
 
@@ -322,9 +325,9 @@ gevd_fold::RecoverJunctions(const gevd_bufferxy& image,
         int x = xloc[i], y = yloc[i];
         int dir = bytePixel(direction, x, y); // direction of fold
         curvature = BestFoldExtension(*smooth,
-                                  x, y, dir + xdir,     // current end pt
-                                  threshold,
-                                  x, y, dir, loc);
+                                      x, y, dir + xdir,     // current end pt
+                                      threshold,
+                                      x, y, dir, loc);
         if (curvature) {                 // next end point
           xloc[i] = x, yloc[i] = y; // update new end point
           xdir = LeftXorRightEnd(contour,    // mark completed if
@@ -348,7 +351,8 @@ gevd_fold::RecoverJunctions(const gevd_bufferxy& image,
           bytePixel(direction, x, y) = (unsigned char)(dir);
           floatPixel(locationx, x, y) = loc*DIS[dir];
           floatPixel(locationy, x, y) = loc*DJS[dir];
-        } else                  // no further extension found
+        }
+        else                  // no further extension found
           ndir[i] = 0;
       }
     //vcl_cout << "Touch " << ntouch << " contours.\n";
