@@ -69,9 +69,9 @@ void vsol_conic_2d::set_central_parameters(vsol_point_2d const& c, double rx, do
 }
 
 //---------------------------------------------------------------------------
-//: Parabola constructor from direction, top and excentricity parameter.
+//: Parabola constructor from direction, top and eccentricity parameter.
 //  This constructor can only be used for non-degenerate parabolas:
-//  specify the direction of the symmetry axis, the top, and an excentricity
+//  specify the direction of the symmetry axis, the top, and an eccentricity
 //  parameter theta.
 //---------------------------------------------------------------------------
 vsol_conic_2d::vsol_conic_2d(vgl_vector_2d<double> const& dir,
@@ -81,9 +81,9 @@ vsol_conic_2d::vsol_conic_2d(vgl_vector_2d<double> const& dir,
 }
 
 //---------------------------------------------------------------------------
-//: Set parabola from direction, top and excentricity parameter.
+//: Set parabola from direction, top and eccentricity parameter.
 //  This can only be used for non-degenerate parabolas:
-//  specify the direction of the symmetry axis, the top, and an excentricity
+//  specify the direction of the symmetry axis, the top, and an eccentricity
 //  parameter theta.
 //---------------------------------------------------------------------------
 void vsol_conic_2d::set_parabola_parameters(vgl_vector_2d<double> const& dir,
@@ -165,7 +165,7 @@ vsol_conic_2d::vsol_conic_type vsol_conic_2d::real_type() const
 }
 
 //---------------------------------------------------------------------------
-//: Is `this' an real ellipse ?
+//: Is `this' a real ellipse ?
 //---------------------------------------------------------------------------
 bool vsol_conic_2d::is_real_ellipse() const
 {
@@ -215,7 +215,7 @@ bool vsol_conic_2d::is_hyperbola() const
 }
 
 //---------------------------------------------------------------------------
-//: Is `this' an real intersecting lines ?
+//: Is `this' a pair of real intersecting lines ?
 //---------------------------------------------------------------------------
 bool vsol_conic_2d::is_real_intersecting_lines() const
 {
@@ -223,7 +223,7 @@ bool vsol_conic_2d::is_real_intersecting_lines() const
 }
 
 //---------------------------------------------------------------------------
-//: Is `this' an complex intersecting lines ?
+//: Is `this' a pair of complex intersecting lines ?
 //---------------------------------------------------------------------------
 bool vsol_conic_2d::is_complex_intersecting_lines() const
 {
@@ -231,7 +231,7 @@ bool vsol_conic_2d::is_complex_intersecting_lines() const
 }
 
 //---------------------------------------------------------------------------
-//: Is `this' an coincident lines ?
+//: Is `this' a pair of coincident lines ?
 //---------------------------------------------------------------------------
 bool vsol_conic_2d::is_coincident_lines() const
 {
@@ -358,6 +358,7 @@ void vsol_conic_2d::hyperbola_parameters(double &cx,
 //---------------------------------------------------------------------------
 //: Return 2 parabola parameters: top (`cx',`cy'), orientation (`cosphi',`sinphi')
 // Require: is_parabola()
+// \todo not yet fully implemented
 //---------------------------------------------------------------------------
 void vsol_conic_2d::parabola_parameters(double & /* cx */,
                                         double & /* cy */,
@@ -369,7 +370,7 @@ void vsol_conic_2d::parabola_parameters(double & /* cx */,
 
   // Note that for a parabola B*B == 4*A*C, hence the quadratic part
   // of the equation is a square: (nX+mY)^2, with n=sqrt(A), m=sqrt(C)
-  // Hence norm cannot be zero since the parabola is not degererate:
+  // Hence norm cannot be zero since the parabola is not degenerate:
   const double norm=a()+c();
   // The parabola direction is then (-m,n):
   cosphi=-vcl_sqrt(c()/norm);
@@ -553,7 +554,8 @@ vsol_conic_2d::closest_point_on_curve(vsol_point_2d_sptr const& pt) const
   if (b()==0 && a()==c()) {
     // this ellipse is a circle ==> degenerate hyperbola (line + line at infinity)
     candidates = intersection(vsol_line_2d(midpoint(),pt));
-  } else {
+  }
+  else {
     // Non-degenerate hyperbola:
     vsol_conic_2d conic(b()/2,
                         c()-a(),
