@@ -29,7 +29,7 @@
 //   2002-04-05 Peter Vanroose  axis() added
 //   2003-01-08 Peter Vanroose  moved static private methods to vsol_conic_2d.cxx
 //   2004-05-11 Joseph Mundy    added binary I/O methods
-//   2004-09-23 Ming-CHing Chang  Change cast_to_conic_2d() to cast_to_conic()
+//   2004-09-23 Ming-Ching Chang Changed cast_to_conic_2d() to cast_to_conic()
 // \endverbatim
 //*****************************************************************************
 
@@ -83,7 +83,7 @@ class vsol_conic_2d : public vsol_curve_2d, public vgl_conic<double>
     coincident_lines
   };
 
- private: // has been superceeded by is_a()
+ private: // has been superseded by is_a()
   //: Return the curve type
   virtual vsol_curve_2d_type curve_type() const { return vsol_curve_2d::CONIC; }
 
@@ -118,9 +118,9 @@ class vsol_conic_2d : public vsol_curve_2d, public vgl_conic<double>
   vsol_conic_2d(vsol_point_2d const& cntr, double rx, double ry, double theta);
 
   //---------------------------------------------------------------------------
-  //: Parabola constructor from direction, top and excentricity parameter.
+  //: Parabola constructor from direction, top and eccentricity parameter.
   //  This constructor can only be used for non-degenerate parabolas:
-  //  specify the direction of the symmetry axis, the top, and an excentricity
+  //  specify the direction of the symmetry axis, the top, and an eccentricity
   //  parameter theta.
   //---------------------------------------------------------------------------
   vsol_conic_2d(vgl_vector_2d<double> const& dir, vsol_point_2d const& top, double theta);
@@ -138,9 +138,9 @@ class vsol_conic_2d : public vsol_curve_2d, public vgl_conic<double>
   void set_central_parameters(vsol_point_2d const& cntr, double rx, double ry, double theta);
 
   //---------------------------------------------------------------------------
-  //: Set parabola from direction, top and excentricity parameter.
+  //: Set parabola from direction, top and eccentricity parameter.
   //  This can only be used for non-degenerate parabolas:
-  //  specify the direction of the symmetry axis, the top, and an excentricity
+  //  specify the direction of the symmetry axis, the top, and an eccentricity
   //  parameter theta.
   //---------------------------------------------------------------------------
   void set_parabola_parameters(vgl_vector_2d<double> const& dir,
@@ -208,7 +208,7 @@ class vsol_conic_2d : public vsol_curve_2d, public vgl_conic<double>
   vcl_string real_conic_type() const { return static_cast<vgl_conic<double> >(*this).real_type(); }
 
   //---------------------------------------------------------------------------
-  //: Is `this' an real ellipse ?
+  //: Is `this' a real ellipse ?
   //---------------------------------------------------------------------------
   bool is_real_ellipse() const;
 
@@ -238,17 +238,17 @@ class vsol_conic_2d : public vsol_curve_2d, public vgl_conic<double>
   bool is_hyperbola() const;
 
   //---------------------------------------------------------------------------
-  //: Is `this' an real intersecting lines ?
+  //: Is `this' a pair of real intersecting lines ?
   //---------------------------------------------------------------------------
   bool is_real_intersecting_lines() const;
 
   //---------------------------------------------------------------------------
-  //: Is `this' an complex intersecting lines ?
+  //: Is `this' a pair of complex intersecting lines ?
   //---------------------------------------------------------------------------
   bool is_complex_intersecting_lines() const;
 
   //---------------------------------------------------------------------------
-  //: Is `this' an coincident lines ?
+  //: Is `this' a pair of coincident lines ?
   //---------------------------------------------------------------------------
   bool is_coincident_lines() const;
 
@@ -380,7 +380,7 @@ class vsol_conic_2d : public vsol_curve_2d, public vgl_conic<double>
   }
 
   //---------------------------------------------------------------------------
-  //: Return `this' if `this' is an conic, 0 otherwise
+  //: Return `this' if `this' is a conic, 0 otherwise
   //---------------------------------------------------------------------------
   virtual vsol_conic_2d const*cast_to_conic() const { return this; }
   virtual vsol_conic_2d *cast_to_conic() { return this; }
