@@ -12,6 +12,8 @@ DECLARE( test_smo_1 );
 DECLARE( test_logit_loss_function );
 DECLARE( test_binary_hyperplane_logit );
 DECLARE( test_binary_1d_wrapper );
+DECLARE( test_binary_tree );
+DECLARE( test_random_forest );
 
 void
 register_tests()
@@ -28,6 +30,9 @@ register_tests()
   REGISTER( test_logit_loss_function );
   REGISTER( test_binary_hyperplane_logit );
   REGISTER( test_binary_1d_wrapper );
+  REGISTER( test_binary_tree );
+  REGISTER( test_random_forest );
+
 }
 
 DEFINE_MAIN;
