@@ -64,6 +64,28 @@ vcl_ostream& operator<<(vcl_ostream&os, mbl_logger::levels level)
 }
 
 
+vcl_ostream& operator<<(vcl_ostream&os, const mbl_log_categories::cat_spec& spec)
+{
+  os << "{ level: " << static_cast<mbl_logger::levels>(spec.level);
+  switch (spec.output)
+  {
+   case mbl_log_categories::cat_spec::FILE_OUT:
+    os << " file_output: " << spec.name;
+    break;
+   case mbl_log_categories::cat_spec::NAMED_STREAM:
+    os << " stream_output: " << spec.name;
+    break;
+   default:
+    assert(!"This should not happen: invalid spec.output");
+    break;
+  }
+  if (!spec.dump_prefix.empty())
+    os << " dump_prefix: " << spec.dump_prefix;
+
+  os << " }";
+  return os;
+}
+
 //Notes - use two different stream bufs to hendle the mt_log() and the log().
 // one should response to flushes with a terminate - the other not.
 
@@ -278,6 +300,16 @@ void mbl_log_output_file::terminate_flush()
   }
 }
 
+#if 0 // This logger causes gcc to throw a recursive_init
+      // Not entirely surprising, by MSVC didn't complain.
+      // FIXME This logger is useful - for finding every logger in use
+      // in a program
+static mbl_logger& local_logger()
+{
+  static mbl_logger l("mul.mbl.log");
+  return l;
+}
+#endif
 
 mbl_logger::mbl_logger(const char *id):
   output_(0),
@@ -285,10 +317,17 @@ mbl_logger::mbl_logger(const char *id):
   logstream_(&streambuf_),
   mt_logstream_(&logstream_)
 {
+#if 0 // FIXME
+  MBL_LOG(INFO, local_logger(), "Creating logger: " << id);
+#endif
   const mbl_log_categories::cat_spec &cat =
     mbl_logger::root().categories().get(id);
+#if 0 // FIXME
+  MBL_LOG(DEBUG, local_logger(), "Using cat_spec: " << cat);
+#endif
 
   level_ = cat.level;
+  dump_prefix_ = cat.dump_prefix;
 
   if (cat.output == mbl_log_categories::cat_spec::NAMED_STREAM)
   {
@@ -311,11 +350,12 @@ void mbl_logger::reinitialise()
     mbl_logger::root().categories().get(id);
 
   level_ = cat.level;
+  dump_prefix_ = cat.dump_prefix;
 
   if (cat.output == mbl_log_categories::cat_spec::NAMED_STREAM)
   {
     delete output_;
-    output_ = new mbl_log_output_stream(vcl_cout, id);
+    output_ = new mbl_log_output_stream(*cat.stream, id);
 //    logstream_.tie(output_.real_stream_);
   }
   else if (cat.output == mbl_log_categories::cat_spec::FILE_OUT)
@@ -459,7 +499,7 @@ mbl_log_categories::mbl_log_categories()
   default_spec.output = cat_spec::NAMED_STREAM;
   default_spec.name = "vcl_cerr";
   default_spec.stream = &vcl_cerr;
-
+  default_spec.dump_prefix = "";
   cat_list_[""] = default_spec;
 }
 
@@ -503,6 +543,8 @@ inline mbl_log_categories::cat_spec parse_cat_spec(const vcl_string &str,
     spec.level = mbl_logger::NOTICE;
   }
 
+  spec.dump_prefix = props.get_optional_property("dump_prefix");
+
   if (props.find("file_output") != props.end())
   {
     spec.output = mbl_log_categories::cat_spec::FILE_OUT;
@@ -582,6 +624,7 @@ void mbl_log_categories::clear()
   default_spec.name = "cerr";
   default_spec.stream = &vcl_cerr;
   default_spec.output = cat_spec::NAMED_STREAM;
+  default_spec.dump_prefix = "";
   cat_list_[""] = default_spec;
 }
 
@@ -622,25 +665,6 @@ const mbl_log_categories::cat_spec&
 }
 
 
-vcl_ostream& operator<<(vcl_ostream&os, const mbl_log_categories::cat_spec& spec)
-{
-  os << "{ level: " << static_cast<mbl_logger::levels>(spec.level);
-  switch (spec.output)
-  {
-   case mbl_log_categories::cat_spec::FILE_OUT:
-    os << " file_output: " << spec.name;
-    break;
-   case mbl_log_categories::cat_spec::NAMED_STREAM:
-    os << " stream_output: " << spec.name;
-    break;
-   default:
-    assert(!"This should not happen: invalid spec.output");
-    break;
-  }
-  os << " }";
-  return os;
-}
-
 void mbl_log_categories::print(vcl_ostream& os) const
 {
   typedef vcl_map<vcl_string, cat_spec>::const_iterator iter;
