@@ -16,8 +16,11 @@ char* mbl_read_str(char *reply, int max_str_len, const char *q_str, const char *
   vcl_printf("%s (%s) :",q_str,default_str);
 
   // Now read in a line of text
-  vcl_fgets(new_reply,max_str_len,stdin);
-  if (new_reply[0]=='\n')
+  if (!vcl_fgets(new_reply,max_str_len,stdin))
+  {
+    vcl_strncpy(reply,"*** Error from std::fgets() ***",max_str_len);
+  }
+  else if (new_reply[0]=='\n')
   {
     if (reply!=default_str)
       vcl_strncpy(reply,default_str,max_str_len);
