@@ -1,5 +1,5 @@
 #include <testlib/testlib_register.h>
-//#include <mipa/mipa_add_all_loaders.h>
+
 DECLARE( test_edge_finder );
 DECLARE( test_norm_corr1d );
 DECLARE( test_norm_corr2d );
@@ -10,10 +10,10 @@ DECLARE( test_pose );
 DECLARE( test_mr_point_finder );
 DECLARE( test_dp_snake );
 DECLARE( test_patch_data );
+DECLARE( test_pose_predictor );
 
 void register_tests()
 {
-//    mipa_add_all_loaders();
   REGISTER( test_edge_finder );
   REGISTER( test_norm_corr1d );
   REGISTER( test_norm_corr2d );
@@ -24,7 +24,7 @@ void register_tests()
   REGISTER( test_mr_point_finder );
   REGISTER( test_dp_snake );
   REGISTER( test_patch_data );
+  REGISTER( test_pose_predictor );
 }
 
-
 DEFINE_MAIN;
