@@ -22,8 +22,7 @@
 #include "test_algo_gaussian_filter.cxx"
 
 #undef TESTLIB_DEFINE_MAIN
-#define TESTLIB_DEFINE_MAIN(x) int main() \
-  { testlib_test_start(#x); x(); return testlib_test_summary(); }
+#define TESTLIB_DEFINE_MAIN(x) int main() { RUN_TEST_FUNC(x); }
 
 void run_test_mil()
 {
