@@ -14,6 +14,7 @@ DECLARE( test_correlate_2d );
 DECLARE( test_resample_bilin );
 DECLARE( test_image_bounds_and_centre_2d );
 DECLARE( test_v2i );
+DECLARE( test_reflect );
 
 void
 register_tests()
@@ -32,6 +33,7 @@ register_tests()
   REGISTER( test_resample_bilin );
   REGISTER( test_image_bounds_and_centre_2d );
   REGISTER( test_v2i );
+  REGISTER( test_reflect );
 }
 
 DEFINE_MAIN;
