@@ -10,7 +10,7 @@
 #include <testlib/testlib_test.h>
 
 
-static void test_save(int argc, char* argv[])
+static void test_save()
 {
   vcl_cout << "*********************\n"
            << " Testing vimt3d_save\n"
@@ -18,6 +18,7 @@ static void test_save(int argc, char* argv[])
 
   vimt3d_add_all_loaders();
 
+
   vimt3d_transform_3d tr_gold1;
   tr_gold1.set_zoom_only( 0.1, 0.2, 0.3, 4, 5, 6);
 
@@ -36,6 +37,24 @@ static void test_save(int argc, char* argv[])
 
   TEST("v3i image round-trip has same zoom transform",
        mbl_test_summaries_are_equal(tr_in1, tr_gold1 ), true);
+
+
+  {
+    vil3d_image_resource_sptr ir_out1 = vil3d_new_image_resource(
+      "test_save.v3m", 5, 5, 5, 1, VIL_PIXEL_FORMAT_FLOAT, "v3m");
+    vimt3d_save_transform(ir_out1, tr_gold1, true);
+  }
+
+  vil3d_image_resource_sptr im_in2 = vil3d_load_image_resource("test_save.v3m");
+  vimt3d_transform_3d tr_in2 = vimt3d_load_transform(im_in2, true);
+
+
+  vcl_cout << "Golden transform: " << tr_gold1
+           << "\nLoaded transform: " << tr_in2 << vcl_endl;
+
+  TEST("v3m image round-trip has same zoom transform",
+       mbl_test_summaries_are_equal(tr_in2, tr_gold1 ), true);
+
 }
 
-TESTMAIN_ARGS(test_save);
+TESTMAIN(test_save);
