@@ -4,15 +4,13 @@
 #undef TESTLIB_DEFINE_MAIN
 #define TESTLIB_DEFINE_MAIN(x)
 
-
 #include "test_mixture.cxx"
 #include "test_gaussian.cxx"
 #include "test_axis_gaussian.cxx"
 #include "test_pc_gaussian.cxx"
 
 #undef TESTLIB_DEFINE_MAIN
-#define TESTLIB_DEFINE_MAIN(x) int main() \
-  { testlib_test_start(#x); x(); return testlib_test_summary(); }
+#define TESTLIB_DEFINE_MAIN(x) int main() { RUN_TEST_FUNC(x); }
 
 void run_test_vpdfl()
 {
