@@ -197,7 +197,7 @@ void osl_canny_rothwell::detect_edges(vil1_image const &image, vcl_list<osl_edge
 void osl_canny_rothwell::Non_maximal_suppression()
 {
   float h1=0,h2=0;
-  float k = 180.0f/float(vnl_math::pi);
+  float k = float(vnl_math::deg_per_rad);
 
   // Add 1 to get rid of border effects
   for (unsigned int x=w0_; x+2+w0_<xsize_; ++x)  {
@@ -411,7 +411,7 @@ void osl_canny_rothwell::Final_hysteresis(vcl_list<osl_edge*> *edges)
       if ( count < 2 )
         continue;
 
-      // Create a osl_edgel_chain
+      // Create an osl_edgel_chain
       osl_edgel_chain *dc = new osl_edgel_chain(count);
       px = dc->GetX();     py = dc->GetY();
       pg = dc->GetGrad();  pt = dc->GetTheta();
@@ -436,7 +436,7 @@ void osl_canny_rothwell::Final_hysteresis(vcl_list<osl_edge*> *edges)
             *(pg++) = 0.0f;   // Mark the gradient as zero at a junction
           }
           if (theta_[tmpx][tmpy] == DUMMYTHETA) {
-            const float k = 180.0f/float(vnl_math::pi);
+            const float k = float(vnl_math::deg_per_rad);
             float *dx = dx_[tmpx];
             float *dy = dy_[tmpx];
 
@@ -654,7 +654,7 @@ void osl_canny_rothwell::Jump_single_breaks()
 void osl_canny_rothwell::Adaptive_Canny(vil1_image const &image)
 {
   // Reset the smoothing kernel parameters by
-  // halfing the size of the smoothing sigma
+  // halving the size of the smoothing sigma
   old_sigma_ = sigma_;  sigma_ /= 2.0f;
   old_width_ = width_;
   width_ = int(sigma_*vcl_sqrt(2*vcl_log(1.0/gauss_tail_))+1);
@@ -859,7 +859,7 @@ void osl_canny_rothwell::Find_junction_clusters()
         Follow_junctions(junction_, x,y,&xcoords,&ycoords);
 
         // Find the `centre' of the cluster. This is defined as the
-        // junction closest to the centre of gravity of the cluser
+        // junction closest to the centre of gravity of the cluster
         int x0,y0;
         Cluster_centre_of_gravity(jx_, jy_, xcoords,ycoords,x0,y0);
 
