@@ -70,12 +70,12 @@ void osl_fit_lines::simple_fit_to_list(vcl_list<osl_edge *> *myedges,
         {
           if (dc->GetTheta(ii) > 3.2 || dc->GetTheta(ii) < -3.2)
           {
-            using_degrees = vnl_math::pi / 180;
+            using_degrees = vnl_math::pi_over_180;
             break;
           }
         }
         data_->Reset();
-        double angle = 0.7853981;
+        double angle = vnl_math::pi_over_4;
         int  orient0 = int((dc->GetTheta(0) * using_degrees + angle/2.0) / angle);
         for (unsigned int ii=0;ii<dc->size();ii++)
         {
@@ -542,7 +542,7 @@ void osl_fit_lines::OutputLine(vcl_list<osl_edgel_chain*> *curves_,
   }
   old_finish_ = finish;
 
-  // Create a osl_edgel_chain from the fit
+  // Create an osl_edgel_chain from the fit
   osl_edgel_chain *line = new osl_edgel_chain(finish-start);
   for (int i=0,j=start;j<finish;i++,j++) {  // Copy the edgels into the new chain
     line->SetX(dc->GetX(j),i);
