@@ -949,7 +949,7 @@ rgrl_util_skip_empty_lines( vcl_istream& is )
   vcl_streampos pos;
   vcl_string str;
   static const vcl_string white_chars = " \t\r";
-  int non_empty_pos;
+  vcl_string::size_type non_empty_pos;
 
   // skip any empty lines
   do {
@@ -959,7 +959,7 @@ rgrl_util_skip_empty_lines( vcl_istream& is )
     vcl_getline( is, str );
 
     non_empty_pos = str.find_first_not_of( white_chars );
-  } while ( is.good() && !is.eof() && (str.empty() || non_empty_pos < 0 ||
+  } while ( is.good() && !is.eof() && (str.empty() || non_empty_pos == std::string::npos ||
             (str[non_empty_pos]=='#') ) );
 
   // back to the beginning of non-empty line
