@@ -1,6 +1,10 @@
 #include <testlib/testlib_test.h>
 
 #include <vnl/vnl_math.h>
+#include <vnl/vnl_double_2.h>
+#include <vnl/vnl_double_2x2.h>
+#include <vnl/vnl_double_3.h>
+#include <vnl/vnl_double_4.h>
 #include <vnl/vnl_transpose.h>
 #include <rgrl/rgrl_feature.h>
 #include <rgrl/rgrl_feature_point.h>
@@ -15,10 +19,7 @@ static
 void
 test_feature_caster()
 {
-  vnl_vector<double> loc2d( 2 );
-  loc2d[0] =  5.0;
-  loc2d[1] = -4.0;
-
+  vnl_double_2 loc2d(5.0, -4.0);
   rgrl_feature_point* pf2d = new rgrl_feature_point( loc2d );
   rgrl_feature_sptr fsptr = pf2d;
   TEST("feature sptr cast to 2D point feature", rgrl_feature_caster<rgrl_feature_point>(fsptr), pf2d);
@@ -30,20 +31,9 @@ test_feature_point()
 {
   vcl_cout << "Test normal point feature\n";
 
-  vnl_vector<double> loc2d( 2 );
-  loc2d[0] =  5.0;
-  loc2d[1] = -4.0;
-
-  vnl_vector<double> loc3d( 3 );
-  loc3d[0] =  5.0;
-  loc3d[1] = -4.0;
-  loc3d[2] =  2.0;
-
-  vnl_vector<double> loc4d( 4 );
-  loc4d[0] =  2.0;
-  loc4d[1] =  7.0;
-  loc4d[2] = -1.0;
-  loc4d[3] =  3.0;
+  vnl_double_2 loc2d(5.0, -4.0); 
+  vnl_double_3 loc3d(5.0, -4.0,  2.0);
+  vnl_double_4 loc4d(2.0,  7.0, -1.0, 3.0);
 
   rgrl_feature_sptr pf2d = new rgrl_feature_point( loc2d );
   TEST("2D point feature",
@@ -64,15 +54,10 @@ test_feature_point()
        pf4d->error_projector().is_identity(), true);
 
   {
-    vnl_matrix<double> A( 2, 2 );
-    vnl_vector<double> t( 2 );
-    vnl_matrix<double> covar( 6, 6 );
-
-    A(0,0) = 2.0;  A(1,0) =  1.0;
-    A(1,0) = 4.0;  A(1,1) = -3.0;
-
-    t[0] = -3.0;
-    t[1] =  5.0;
+    double a[] = {2.0,1.0,4.0,-3.0};
+    vnl_double_2x2 A(a);
+    vnl_double_2 t(-3.0, 5.0);
+    vnl_matrix_fixed<double,6,6> covar;
 
     rgrl_trans_affine xform( A, t, covar );
     rgrl_feature_sptr result = pf2d->transform( xform );
@@ -80,9 +65,8 @@ test_feature_point()
     TEST("Transform 2D point feature (feature is of point type)", result->is_type( rgrl_feature_point::type_id() ), true );
     TEST("Transform 2D point feature (mapped feature has location same as mapping location only)", result->location(), xform.map_location( loc2d ) );
     // vcl_cout << "Error projector: " << result->error_projector() << vcl_endl;
-    vnl_matrix<double> true_error_projector(2, 2);
-    true_error_projector.set_identity();
-    true_error_projector /= vnl_math_sqr(result->scale());
+    vnl_double_2x2 true_error_projector(0.0);
+    true_error_projector.fill_diagonal(1.0/result->scale()/result->scale());
     TEST("Transform 2D point feature (Error projector is identity matrix)", result->error_projector(), true_error_projector );
   }
 }
@@ -94,36 +78,12 @@ test_feature_trace_pt()
 {
   vcl_cout << "Test trace point feature\n";
 
-  vnl_vector<double> loc2d( 2 );
-  loc2d[0] =  5.0;
-  loc2d[1] = -4.0;
-
-  vnl_vector<double> dir2d( 2 );
-  dir2d[0] = 3.0;
-  dir2d[1] = 1.0;
-
-  vnl_vector<double> nor2d( 2 );
-  nor2d[0] = -dir2d[1];
-  nor2d[1] =  dir2d[0];
-  nor2d.normalize();
-
-  vnl_vector<double> loc4d( 4 );
-  loc4d[0] =  2.0;
-  loc4d[1] =  7.0;
-  loc4d[2] = -1.0;
-  loc4d[3] =  3.0;
-
-  vnl_vector<double> dir4d( 4 );
-  dir4d[0] = -2.0;
-  dir4d[1] =  4.0;
-  dir4d[2] = -1.5;
-  dir4d[3] =  1.0;
-
-  vnl_vector<double> err4d( 4 );
-  err4d[0] =  2.0;
-  err4d[1] = -1.0;
-  err4d[2] =  3.0;
-  err4d[3] = -8.0;
+  vnl_double_2 loc2d(5.0, -4.0);
+  vnl_double_2 dir2d(3.0, 1.0);
+  vnl_double_2 nor2d(-dir2d[1], dir2d[0]); nor2d.normalize();
+  vnl_double_4 loc4d( 2.0, 7.0,-1.0, 3.0);
+  vnl_double_4 dir4d(-2.0, 4.0,-1.5, 1.0);
+  vnl_double_4 err4d( 2.0,-1.0, 3.0,-8.0);
 
   rgrl_feature_sptr pf2d = new rgrl_feature_trace_pt( loc2d, dir2d );
   rgrl_feature_caster<rgrl_feature_trace_pt> trace_ptr( pf2d );
@@ -145,15 +105,10 @@ test_feature_trace_pt()
              dot_product( pf4d->error_projector() * err4d, dir4d ), 0.0, 1e-6 );
 
   {
-    vnl_matrix<double> A( 2, 2 );
-    vnl_vector<double> t( 2 );
-    vnl_matrix<double> covar( 6, 6 );
-
-    A(0,0) = 2.0;  A(0,1) =  1.0;
-    A(1,0) = 4.0;  A(1,1) = -3.0;
-
-    t[0] = -3.0;
-    t[1] =  5.0;
+    double a[] = {2.0,1.0,4.0,-3.0};
+    vnl_double_2x2 A(a);
+    vnl_double_2 t(-3.0, 5.0);
+    vnl_matrix_fixed<double,6,6> covar;
 
     rgrl_trans_affine xform( A, t, covar );
     rgrl_feature_sptr result = pf2d->transform( xform );
@@ -167,12 +122,10 @@ test_feature_trace_pt()
     // transformed normal by transforming the tangent and re-computing
     // the normal.
 
-    vnl_vector<double> x_nor( 2 );
-    vnl_vector<double> x_dir( 2 );
     dir2d.normalize();
+    vnl_vector<double> x_dir;
     xform.map_direction( loc2d, dir2d, x_dir );
-    x_nor[0] = -x_dir[1];
-    x_nor[1] =  x_dir[0];
+    vnl_double_2 x_nor(-x_dir[1], x_dir[0]);
 
     TEST_NEAR( "                        , error projector",
                ( result->error_projector() - outer_product( x_nor, x_nor ) ).absolute_value_max(), 0, 1e-6 );
@@ -186,14 +139,8 @@ test_feature_face()
 {
   vcl_cout << "Test face feature\n";
 
-  vnl_vector<double> loc2d( 2 );
-  loc2d[0] =  3.0;
-  loc2d[1] = -2.0;
-
-  vnl_vector<double> nor2d( 2 );
-  nor2d[0] = 3.0;
-  nor2d[1] = 1.0;
-  nor2d.normalize();
+  vnl_double_2 loc2d(3.0,-2.0);
+  vnl_double_2 nor2d(3.0, 1.0); nor2d.normalize();
 
   rgrl_feature_sptr pf2d = new rgrl_feature_face_pt( loc2d, nor2d );
   rgrl_feature_face_pt* face_ptr = rgrl_feature_caster<rgrl_feature_face_pt>( pf2d );
@@ -208,33 +155,25 @@ test_feature_face()
   TEST_NEAR( "2d face point normal",
              (face_ptr->normal() - nor2d).inf_norm(), 0.0, 1e-6 );   // need the downcast here
 
- //  Test error projector in 2d
+  //  Test error projector in 2d
 
-  vnl_vector<double> dir2d( 2 );
-  dir2d[0] = -nor2d[1];
-  dir2d[1] = nor2d[0];
+  vnl_double_2 dir2d(-nor2d[1], nor2d[0]);
 
   double dist = 3.0;
-  vnl_vector<double> test_pt2d( loc2d + 10.0 * dir2d + dist * nor2d );
-  vnl_vector<double> error_vect2d( test_pt2d - loc2d );
+  vnl_double_2 test_pt2d = loc2d + 10.0 * dir2d + dist * nor2d;
+  vnl_double_2 error_vect2d = test_pt2d - loc2d;
 
   TEST_NEAR( "2d face point error projector",
              vnl_math_abs( dot_product( pf2d->error_projector() * error_vect2d, error_vect2d ) ),
              dist*dist, 1e-6 );
 
-
   //  Onto testing the transformation
 
   {
-    vnl_matrix<double> A( 2, 2 );
-    vnl_vector<double> t( 2 );
-    vnl_matrix<double> covar( 6, 6, vnl_matrix_identity );
-
-    A(0,0) = 2.0;  A(0,1) =  1.0;
-    A(1,0) = 4.0;  A(1,1) = -3.0;
-
-    t[0] = -3.0;
-    t[1] =  5.0;
+    double a[] = {2.0,1.0,4.0,-3.0};
+    vnl_double_2x2 A(a);
+    vnl_double_2 t(-3.0, 5.0);
+    vnl_matrix_fixed<double,6,6> covar; covar.set_identity();
 
     rgrl_trans_affine xform( A, t, covar );
     rgrl_feature_sptr result = pf2d->transform( xform );
@@ -245,18 +184,17 @@ test_feature_face()
          !result->error_projector().is_identity(), true);
 
     // This matrix convert normal to tangent
-    vnl_matrix<double> B( 2, 2 );
-    B.fill( 0.0 );
-    B(0,1) = -1;  B(1,0) = 1;
+    double b[] = {0.0, -1.0, 1.0, 0.0};
+    vnl_double_2x2 B(b);
 
     // mapping tangent is easy:  A*tangent
-    vnl_matrix<double> C = vnl_transpose(B)*A*B;
+    vnl_double_2x2 C = vnl_transpose(B)*A*B;
 
     // affine transforms do not preseve angles, calculate the
     // transformed normal by transforming the tangent and re-computing
     // the normal.
 
-    vnl_vector<double> x_nor( 2 );
+    vnl_double_2 x_nor;
     // xform.map_normal( loc2d, nor2d, x_nor );
     x_nor = nor2d;
     x_nor.normalize();
@@ -267,8 +205,8 @@ test_feature_face()
     // the inverse has to be done analytically.
     double eig_val = x_nor.magnitude();
     x_nor.normalize();
-    // vnl_matrix<double> outer = outer_product( x_nor, x_nor );
-    vnl_matrix<double> real_proj = outer_product( x_nor, x_nor ) / vnl_math_sqr(eig_val);
+    // vnl_double_2x2 outer = outer_product( x_nor, x_nor );
+    vnl_double_2x2 real_proj = outer_product( x_nor, x_nor ) / vnl_math_sqr(eig_val);
 
     //vcl_cout << "error proj: " << result->error_projector() << vcl_endl;
     //vcl_cout << "transformed normal: " << x_nor << vcl_endl;
