@@ -1,4 +1,4 @@
 #ifndef INSTANTIATE_TEMPLATES
 #include <vepl/vepl_convert.txx>
-template vil1_image vepl_convert(vil1_image const&, int);
+template vil_image_resource vepl_convert(vil_image_resource_sptr, int);
 #endif
