@@ -6,20 +6,16 @@
 //  which is always a PGM file image.
 //
 // \author Peter Vanroose, K.U.Leuven, ESAT/PSI
-// \date   15 May 2001, from vipl/examples
+// \date   7 October 2002, from vepl1/examples
 //
-#include <vil1/vil1_memory_image_of.h>
-#include <vil1/vil1_pixel.h>
 #include <vepl/vepl_threshold.h>
 
-#include <vxl_config.h> // for vxl_byte
-typedef vil1_image img_type;
-
 // for I/O:
-#include <vil1/vil1_load.h>
-#include <vil1/vil1_save.h>
+#include <vil/vil_load.h>
+#include <vil/vil_save.h>
 #include <vcl_iostream.h>
 #include <vcl_cstdlib.h> // for atoi()
+#include <vxl_config.h> // for vxl_byte
 
 int
 main(int argc, char** argv)
@@ -27,27 +23,20 @@ main(int argc, char** argv)
   if (argc < 3) { vcl_cerr << "Syntax: example4_threshold file_in file_out [threshold]\n"; return 1; }
 
   // The input image:
-  vil1_image in = vil1_load(argv[1]);
-  if (vil1_pixel_format(in) != VIL1_BYTE) { vcl_cerr << "Please use a ubyte image as input\n"; return 2; }
-  int xs = in.width();
-  int ys = in.height();
-
-  // The output image:
-  vil1_memory_image_of<vxl_byte> out(in);
-  vxl_byte* buf = new vxl_byte[in.get_size_bytes()];
-  in.get_section(buf,0,0,xs,ys);
-  out.put_section(buf,0,0,xs,ys);
+  vil_image_resource_sptr in = vil_load_image_resource(argv[1]);
+  if (!in) { vcl_cerr << "Please use a ubyte image as input\n"; return 2; }
 
   // The threshold value:
   vxl_byte threshold = (argc < 4) ? 64 : vxl_byte(vcl_atoi(argv[3]));
 
   // perform thresholding:
-  vepl_threshold(out,threshold,0,255); // NOTE THAT dst == src
+  vil_image_resource_sptr out = vepl_threshold(in,threshold,0,255);
 
   // Write output:
-  vil1_save(out, argv[2], "pnm");
-  vcl_cout << "Written image of type PGM to " << argv[2] << vcl_endl;
+  if (vil_save_image_resource(out, argv[2], "pnm"))
+    vcl_cout << "Written thresholded image of type PNM to " << argv[2] << '\n';
+  else
+    vcl_cout << "Could not write thresholded image as PNM to "<< argv[2]<<'\n';
 
-  delete[] buf;
   return 0;
 }
