@@ -1,6 +1,5 @@
 #ifndef vepl_convert_h_
 #define vepl_convert_h_
-
 //:
 // \file
 // \brief convert between arbitrary image types
@@ -8,13 +7,18 @@
 //   This class actually copies one image to an other, pixel-wise.
 //
 // \author Peter Vanroose, K.U.Leuven (ESAT/PSI)
-// \date   28 April 2001
+// \date   7 October 2002
+//
+// \verbatim
+//  Modifications
+//   Peter Vanroose - 20 aug 2003 - changed parameter and return types from vil_image_view_base_sptr to vil_image_resource_sptr
+// \endverbatim
 
-#include <vil1/vil1_image.h>
+#include <vil/vil_image_resource.h>
 
 //: convert between arbitrary image types
 template <class D>
-vil1_image vepl_convert(vil1_image const& , D dummy);
+vil_image_resource_sptr vepl_convert(vil_image_resource_sptr, D dummy);
 
 #ifdef INSTANTIATE_TEMPLATES
 #include "vepl_convert.txx"
