@@ -1,6 +1,5 @@
 #ifndef vepl_gaussian_convolution_h_
 #define vepl_gaussian_convolution_h_
-
 //:
 // \file
 // \brief gaussian smoothing
@@ -19,11 +18,16 @@
 //   followed by a column-based 1-D step.
 //
 // \author Peter Vanroose, K.U.Leuven (ESAT/PSI)
-// \date   28 April 2001
+// \date   7 October 2002
+//
+// \verbatim
+//  Modifications
+//   Peter Vanroose - 20 aug 2003 - changed parameter and return types from vil_image_view_base_sptr to vil_image_resource_sptr
+// \endverbatim
 
-#include <vil1/vil1_image.h>
+#include <vil/vil_image_resource.h>
 
 //: gaussian smoothing with given sigma (default 1)
-vil1_image vepl_gaussian_convolution(vil1_image const& , double sigma=1, double cutoff=0.01);
+vil_image_resource_sptr vepl_gaussian_convolution(vil_image_resource_sptr , double sigma=1, double cutoff=0.01);
 
 #endif // vepl_gaussian_convolution_h_
