@@ -1,6 +1,5 @@
 #ifndef vepl_monadic_h_
 #define vepl_monadic_h_
-
 //:
 // \file
 // \brief apply any (fixed) function to all pixels
@@ -16,17 +15,22 @@
 //   Note that the input and output images are allowed to be identical.
 //
 // \author Peter Vanroose, K.U.Leuven (ESAT/PSI)
-// \date   28 April 2001
+// \date   7 October 2002
+//
+// \verbatim
+//  Modifications
+//   Peter Vanroose - 20 aug 2003 - changed parameter and return types from vil_image_view_base_sptr to vil_image_resource_sptr
+// \endverbatim
 
-#include <vil1/vil1_image.h>
+#include <vil/vil_image_resource.h>
 
 //: replace pixels by their absolute value
-vil1_image vepl_monadic_abs(vil1_image const& );
+vil_image_resource_sptr vepl_monadic_abs(vil_image_resource_sptr );
 //: replace pixels by their square root
-vil1_image vepl_monadic_sqrt(vil1_image const& );
+vil_image_resource_sptr vepl_monadic_sqrt(vil_image_resource_sptr );
 //: replace pixels by their square
-vil1_image vepl_monadic_sqr(vil1_image const& );
+vil_image_resource_sptr vepl_monadic_sqr(vil_image_resource_sptr );
 //: replace pixels by a linear distortion
-vil1_image vepl_monadic_shear(vil1_image const& , double shift, double scale);
+vil_image_resource_sptr vepl_monadic_shear(vil_image_resource_sptr , double shift, double scale);
 
 #endif // vepl_monadic_h_
