@@ -3,3 +3,5 @@
 #pragma implementation
 #endif
 #include "vipl_filter_abs.h"
+// the following is just for avoiding an empty library:
+char dummy = 'p';
