@@ -2,8 +2,11 @@
 #define vipl_accessors_vnl_vector_h_
 #include <vnl/vnl_vector.h>
 
+#undef FILTER_IMPTR_DEC_REFCOUNT
 #define FILTER_IMPTR_DEC_REFCOUNT(v) {delete (v); (v)=0;}
+#undef FILTER_IMPTR_INC_REFCOUNT
 #define FILTER_IMPTR_INC_REFCOUNT(v)
+#undef FILTER_KERNPTR_DEC_REFCOUNT
 #define FILTER_KERNPTR_DEC_REFCOUNT(v)
 
 template <class DataType> DataType fgetpixel(vnl_vector<DataType> const& i, int x, int y, DataType);
