@@ -184,7 +184,7 @@ vgl_point_2d<T> vgl_closest_point(vgl_point_2d<T> const& point,
 //
 // \author Paul Bourke, modified for use in VXL by Brendan McCane
 //
-// \notes This routine is adapted from code written by Paul Bourke and
+// \note This routine is adapted from code written by Paul Bourke and
 // available online at
 // http://astronomy.swin.edu.au/~pbourke/geometry/lineline3d/
 
@@ -229,6 +229,14 @@ vgl_point_3d<T> vgl_closest_point(vgl_infinite_line_3d<T> const& l,
                                   vgl_point_3d<T> const& p){
   return vgl_closest_point(p,l);}
 
+template <class T>
+vgl_point_3d<T> vgl_closest_point(vgl_point_3d<T> const& p,
+                                  vgl_ray_3d<T> const& r);
+
+template <class T> inline
+vgl_point_3d<T> vgl_closest_point(vgl_ray_3d<T> const& r,
+                                  vgl_point_3d<T> const& p){
+  return vgl_closest_point(p,r);}
 //: Return the point on the given line which is closest to the given point.
 // The closest point is expressed in parametric form.
 // \relatesalso vgl_line_3d_2_points
@@ -290,5 +298,27 @@ vgl_closest_points(const vgl_line_segment_3d<T>& l1,
                    const vgl_line_segment_3d<T>& l2,
                    bool* unique=0);
 
+//: Return the closest point on a line segment \a l to a point \a p in 2D
+// \relatesalso vgl_point_2d
+// \relatesalso vgl_line_segment_2d
+// \sa vgl_distance_to_linesegment()
+template <class T>
+vgl_point_2d<T> vgl_closest_point(vgl_line_segment_2d<T> const& l,
+                                  vgl_point_2d<T> const& p);
+template <class T> inline
+vgl_point_2d<T> vgl_closest_point(vgl_point_2d<T> const& p,
+                                  vgl_line_segment_2d<T> const& l) { return vgl_closest_point(l,p); }
+
+//: Return the closest point on a line segment \a l to a point \a p in 3D
+// \relatesalso vgl_point_3d
+// \relatesalso vgl_line_segment_3d
+// \sa vgl_distance_to_linesegment()
+template <class T>
+vgl_point_3d<T> vgl_closest_point(vgl_line_segment_3d<T> const& l,
+                                  vgl_point_3d<T> const& p);
+template <class T> inline
+vgl_point_3d<T> vgl_closest_point(vgl_point_3d<T> const& p,
+                                  vgl_line_segment_3d<T> const& l) { return vgl_closest_point(l,p); }
+
 
 #endif // vgl_closest_point_h_
