@@ -22,8 +22,6 @@
 #include <vcl_cassert.h>
 #include <vcl_vector.h>
 
-#include <vgl/vgl_tolerance.h>
-
 //: Represents a cartesian 3D point
 template <class Type>
 class vgl_point_3d
@@ -65,25 +63,26 @@ class vgl_point_3d
 #endif
 
   //: Test for equality
-  inline bool operator==(const vgl_point_3d<Type> &p) const
-  { return this==&p || (x_>=p.x()-vgl_tolerance<Type>::position && x_<=p.x()+vgl_tolerance<Type>::position &&
-                        y_>=p.y()-vgl_tolerance<Type>::position && y_<=p.y()+vgl_tolerance<Type>::position &&
-                        z_>=p.z()-vgl_tolerance<Type>::position && z_<=p.z()+vgl_tolerance<Type>::position ); }
-  inline bool operator!=(vgl_point_3d<Type>const& p)const
-  { return !operator==(p); }
+  bool operator==(const vgl_point_3d<Type> &p) const;
+  inline bool operator!=(vgl_point_3d<Type>const& p) const { return !operator==(p); }
 
   // Data Access-------------------------------------------------------------
 
+  inline Type &x() {return x_;}
+  inline Type &y() {return y_;}
+  inline Type &z() {return z_;}
+
   inline Type x() const {return x_;}
   inline Type y() const {return y_;}
   inline Type z() const {return z_;}
 
   //: Set \a x, \a y and \a z
-  //  Note that \a x, \a y, or \a z cannot be set individually
-  inline void set (Type px, Type py, Type pz){ x_ = px; y_ = py; z_ = pz; }
+  //  Note that \a x, \a y, and \a z can also be set individually
+  inline void set(Type px, Type py, Type pz) { x_ = px; y_ = py; z_ = pz; }
+
   //: Set \a x, \a y and \a z
-  //  Note that \a x, \a y, or \a z cannot be set individually
-  inline void set (Type const p[3]) { x_ = p[0]; y_ = p[1]; z_ = p[2]; }
+  //  Note that \a x, \a y, and \a z can also be set individually
+  inline void set(Type const p[3]) { x_ = p[0]; y_ = p[1]; z_ = p[2]; }
 
   //: Return true iff the point is at infinity (an ideal point).
   //  Always returns false.
@@ -261,35 +260,27 @@ vgl_point_3d<Type> centre(vgl_point_3d<Type> const& p1,
 template <class Type> inline
 vgl_point_3d<Type> centre(vcl_vector<vgl_point_3d<Type> > const& v)
 {
-  int n=v.size();
+  int n = (int)(v.size());
   assert(n>0); // it is *not* correct to return the point (0,0) when n==0.
   Type x = 0, y = 0, z = 0;
   for (int i=0; i<n; ++i) x+=v[i].x(), y+=v[i].y(), z+=v[i].z();
   return vgl_point_3d<Type>(x/n,y/n,z/n);
 }
 
+//: Return the "average deviation" of a set of given points from its centre of gravity.
+//  "Average" in the sense of the standard deviation (2-norm, i.e., square root
+//  of sum of squares) of the distances from that centre of gravity.
+// \relatesalso vgl_point_3d
+template <class Type>
+double stddev(vcl_vector<vgl_point_3d<Type> > const& v);
+
 //: Return true iff the 4 points are coplanar, i.e., they belong to a common plane
 // \relatesalso vgl_point_3d
-template <class Type> inline
+template <class Type>
 bool coplanar(vgl_point_3d<Type> const& p1,
               vgl_point_3d<Type> const& p2,
               vgl_point_3d<Type> const& p3,
-              vgl_point_3d<Type> const& p4)
-{
-  Type r = ( (p1.x()*p2.y()-p1.y()*p2.x())*p3.z()
-            +(p3.x()*p1.y()-p3.y()*p1.x())*p2.z()
-            +(p2.x()*p3.y()-p2.y()*p3.x())*p1.z()
-            +(p1.x()*p4.y()-p1.y()*p4.x())*p2.z()
-            +(p4.x()*p2.y()-p4.y()*p2.x())*p1.z()
-            +(p2.x()*p1.y()-p2.y()*p1.x())*p4.z()
-            +(p3.x()*p4.y()-p3.y()*p4.x())*p1.z()
-            +(p1.x()*p3.y()-p1.y()*p3.x())*p4.z()
-            +(p4.x()*p1.y()-p4.y()*p1.x())*p3.z()
-            +(p3.x()*p2.y()-p3.y()*p2.x())*p4.z()
-            +(p2.x()*p4.y()-p2.y()*p4.x())*p3.z()
-            +(p4.x()*p3.y()-p4.y()*p3.x())*p2.z() );
-  return r <= vgl_tolerance<Type>::point_3d_coplanarity && r >= -vgl_tolerance<Type>::point_3d_coplanarity;
-}
+              vgl_point_3d<Type> const& p4);
 
 #define VGL_POINT_3D_INSTANTIATE(T) extern "please include vgl/vgl_point_3d.txx first"
 
