@@ -164,6 +164,7 @@ BEGIN_MESSAGE_MAP(CDlgWnd, CWnd)
         ON_BN_CLICKED(IDC_OPEN, OnOpen)
 END_MESSAGE_MAP()
 
+
 void CDlgWnd::OnOpen()
 {
     // Get the text and check whether it is a valid directory
@@ -312,7 +313,7 @@ void CDlgWnd::CheckDir(const CString &ss)
     // put in the edit control due to OnFolderChange.  One exception is if the user has
     // used "..", "..." etc to change to an ancestor directory in which case we don't want to
     // leave this the same as it will cause repeated changes to ancestor directories whenever
-    // the user types backslash (\).  Also don;t set the edit string back to what the user
+    // the user types backslash (\).  Also don't set the edit string back to what the user
     // typed if it would be empty or unchanged except for case (as the case probably looks
     // better the way it was filled in).
     if (strSaved.IsEmpty() || strSaved[0] == '.' ||
@@ -429,7 +430,7 @@ void CDirEdit::OnChar(UINT nChar, UINT nRepCnt, UINT nFlags)
                 }
             }
             pp->CheckDir(ss);
-            // Make sure the directory name ends with backslash so user can type sub-drectory name
+            // Make sure the directory name ends with backslash so user can type sub-directory name
             GetWindowText(ss);
             if (ss[ss.GetLength()-1] != '\\')
             {
@@ -613,9 +614,15 @@ UINT CDirEdit::OnGetDlgCode()
 
 // class vgui_dir_dialog
 vgui_dir_dialog::vgui_dir_dialog(LPCTSTR initial, LPCTSTR filter, CWnd* pParentWnd)
+#if WINVER >= 0x0600
+    : CFileDialog(TRUE, NULL, NULL,
+                  OFN_HIDEREADONLY | OFN_OVERWRITEPROMPT | OFN_PATHMUSTEXIST,
+                  NULL, pParentWnd,0,0), // Set bVistaStyle to FALSE 
+#else
     : CFileDialog(TRUE, NULL, NULL,
                   OFN_HIDEREADONLY | OFN_OVERWRITEPROMPT | OFN_PATHMUSTEXIST,
                   NULL, pParentWnd),
+#endif
       m_strPath(initial)
 {
     // Note: m_strFilter is a member variable so it doesn't disappear because
@@ -713,6 +720,7 @@ void vgui_dir_dialog::OnFolderChange()
 {
     CWnd *pp;                           // Parent window = the dialog itself
     VERIFY(pp = GetParent());
+    pp = GetParent();
     ASSERT(::IsWindow(pp->m_hWnd));
 
     ASSERT(pp->GetDlgItem(IDC_DIR) != NULL);
