@@ -6,7 +6,6 @@
 #include <vgui/vgui_gl.h>
 #include "vgui_accelerate.h"
 #include "vgui_accelerate_x11.h"
-//#include "vgui_accelerate_mfc.h"
 #include <vgui/vgui_tag.h>
 #include <vul/vul_trace.h>
 
@@ -18,11 +17,14 @@ vgui_tag(accelerate_x11) {
   return 0;
 }
 #endif
-// #ifdef HAS_MFC
-// vgui_tag(accelerate_mfc) {
-//   vul_trace;
-//   vgui_accelerate::register_accelerator(new vgui_accelerate_mfc, 1);
-//   vul_trace;
-//   return 0;
-// }
-// #endif
+
+#if 0 // #ifdef HAS_MFC
+#include "vgui_accelerate_mfc.h"
+
+vgui_tag(accelerate_mfc) {
+  vul_trace;
+  vgui_accelerate::register_accelerator(new vgui_accelerate_mfc, 1);
+  vul_trace;
+  return 0;
+}
+#endif
