@@ -226,7 +226,7 @@ bool vgui_vrml_draw_visitor::Visit(QvCylinder* node)
 {
   float r = node->radius.value;
   float h = node->height.value;
-  int parts = (int)node->parts.value;
+  bool parts = (int)node->parts.value != 0;
 
   glRotated(-90, 1, 0, 0);
 
@@ -240,10 +240,10 @@ bool vgui_vrml_draw_visitor::Visit(QvCylinder* node)
 
   // fsm : GLU_OUTSIDE/GLU_INSIDE are not GLenums. cast avoids warning (egcs).
   gluQuadricOrientation(quadric, GLenum(GLU_OUTSIDE) );
-  if (parts && (QvCylinder::SIDES | QvCylinder::ALL))
+  if (parts && (QvCylinder::SIDES | QvCylinder::ALL)!=0)
     gluCylinder(quadric, r,r, h, QUADRIC_COMPLEXITY, 2);
 
-  if (parts && (QvCylinder::BOTTOM | QvCylinder::ALL)) {
+  if (parts && (QvCylinder::BOTTOM | QvCylinder::ALL)!=0) {
     gluQuadricOrientation(quadric, GLenum(GLU_INSIDE) );
     gluDisk(quadric, 0, r, QUADRIC_COMPLEXITY, 3);
     gluQuadricOrientation(quadric, GLenum(GLU_OUTSIDE) );
@@ -251,7 +251,7 @@ bool vgui_vrml_draw_visitor::Visit(QvCylinder* node)
 
   glTranslatef(0,0,h);
 
-  if (parts && (QvCylinder::TOP | QvCylinder::ALL))
+  if (parts && (QvCylinder::TOP | QvCylinder::ALL)!=0)
     gluDisk(quadric, 0, r, QUADRIC_COMPLEXITY, 3); // z = h
 
   glTranslatef(0,0,-h/2);
@@ -264,7 +264,7 @@ bool vgui_vrml_draw_visitor::Visit(QvCone* node)
 {
   float r = node->bottomRadius.value;
   float h = node->height.value;
-  int parts = (int)node->parts.value;
+  bool parts = (int)node->parts.value != 0;
   float tz = h/2;
 
   glRotated(90, 1, 0, 0);
@@ -275,12 +275,12 @@ bool vgui_vrml_draw_visitor::Visit(QvCone* node)
   else
     gluQuadricDrawStyle(quadric, GLenum(GLU_FILL));
 
-  if (parts && (QvCone::SIDES | QvCone::ALL))
+  if (parts && (QvCone::SIDES | QvCone::ALL)!=0)
     gluCylinder(quadric, 0, r, h, QUADRIC_COMPLEXITY, 2);
 
   glTranslatef(0,0, 2 * tz);
 
-  if (parts && (QvCone::BOTTOM | QvCone::ALL))
+  if (parts && (QvCone::BOTTOM | QvCone::ALL)!=0)
     gluDisk(quadric, 0, r, QUADRIC_COMPLEXITY, 3);
 
   glTranslatef(0,0, -tz);
@@ -417,7 +417,7 @@ bool vgui_vrml_draw_visitor::Visit(QvAsciiText* /*node*/)
 
 static void GlRotate(double angle_rad, const float* axis)
 {
-  static const float RAD2DEG = 180.0f / float(vnl_math::pi);
+  static const float RAD2DEG = float(vnl_math::deg_per_rad);
   glRotatef(static_cast<float>(angle_rad) * RAD2DEG, axis[0], axis[1], axis[2]);
 }
 
@@ -528,7 +528,8 @@ bool vgui_vrml_draw_visitor::Visit(QvTexture2* node)
                    0,
                    GL_RGB, GL_UNSIGNED_BYTE, tm->rgb.get_buffer());
       remake_texture = false;
-    } else {
+    }
+    else {
       glDisable(GL_TEXTURE_2D);
     }
   }
