@@ -46,6 +46,16 @@ vidl_image_list_istream(const vcl_string& glob)
   open(glob);
 }
 
+//: Constructor
+vidl_image_list_istream::
+vidl_image_list_istream(const vcl_vector<vcl_string>& paths)
+  : index_(INIT_INDEX),
+    ni_(0), nj_(0),
+    format_(VIDL_PIXEL_FORMAT_UNKNOWN),
+    current_frame_(NULL)
+{
+  open(paths);
+}
 
 //: Open a new stream using a file glob (see vul_file_iterator)
 // \note files are loaded in alphanumeric order by path name
@@ -76,7 +86,7 @@ open(const vcl_string& glob)
   if (!can_open) {
     vcl_cerr << "In vidl_image_list_istream(.) -can't open files as images\n";
     for (vcl_vector<vcl_string>::iterator fit = filenames.begin();
-        fit != filenames.end(); ++fit)
+         fit != filenames.end(); ++fit)
       vcl_cerr << *fit << '\n';
     return false;
   }
