@@ -13,13 +13,11 @@ DECLARE( test_algo_line_filter );
 DECLARE( test_algo_threshold );
 DECLARE( test_algo_grid_merge );
 DECLARE( test_algo_find_4con_boundary );
-DECLARE( test_algo_trace_4con_boundary );
-DECLARE( test_algo_trace_8con_boundary );
 DECLARE( test_algo_fft );
 DECLARE( test_algo_histogram );
 DECLARE( test_algo_histogram_equalise );
 DECLARE( test_algo_distance_transform );
-DECLARE( test_algo_blob_finder );
+DECLARE( test_algo_blob );
 DECLARE( test_algo_find_peaks );
 DECLARE( test_algo_find_plateaus );
 DECLARE( test_algo_region_finder );
@@ -55,13 +53,11 @@ register_tests()
   REGISTER( test_algo_threshold );
   REGISTER( test_algo_grid_merge );
   REGISTER( test_algo_find_4con_boundary );
-  REGISTER( test_algo_trace_4con_boundary );
-  REGISTER( test_algo_trace_8con_boundary );
   REGISTER( test_algo_fft );
   REGISTER( test_algo_histogram );
   REGISTER( test_algo_histogram_equalise );
   REGISTER( test_algo_distance_transform );
-  REGISTER( test_algo_blob_finder );
+  REGISTER( test_algo_blob );
   REGISTER( test_algo_find_peaks );
   REGISTER( test_algo_find_plateaus );
   REGISTER( test_algo_region_finder );
