@@ -57,7 +57,7 @@ vil_gauss_filter_5tap_params::vil_gauss_filter_5tap_params(double val_sigma)
 // If you want just a normal gaussian, set diff to 0.
 // \param sd The width of the gaussian.
 //
-// The taps will be calculated using the itegeral of the above equation over
+// The taps will be calculated using the integral of the above equation over
 // the pixel width. However, aliasing will reduce the meaningfulness of
 // your filter when sd << (diff+1). In most applications you will
 // want filter.size() ~= sd*7, which will avoid significant truncation,
@@ -101,7 +101,7 @@ void vil_gauss_filter_gen_ntap(double sd, unsigned diff,
     const double offset = filter.size() % 2 == 0 ? 0.0 : -0.5;
     vnl_real_polynomial poly(1.0);
     const double eta = -0.5/(sd*sd);
-    const vnl_real_polynomial d_gauss(vnl_double_2(eta, 0.0));
+    const vnl_real_polynomial d_gauss(vnl_double_2(eta, 0.0).as_ref());
     for (unsigned i=1; i<diff; ++i)
     {
       // Evaluate d/dx (poly * gauss) where gauss = exp(-0.5*x^2/sd^2)
