@@ -6,9 +6,11 @@
 // \brief 2D normalised correlation
 // \author Tim Cootes
 
+#include <vil/vil_image_view.h>
 #include <vcl_compiler.h>
 #include <vcl_cassert.h>
-#include <vcl_cmath.h>  // for vcl_sqrt()
+#include <vcl_cmath.h>    // for std::sqrt()
+#include <vcl_cstddef.h>  // for std::ptrdiff_t
 
 //: Evaluate dot product between kernel and src_im
 // Assumes that the kernel has been normalised to have zero mean
@@ -50,8 +52,8 @@ inline accumT vil_norm_corr_2d_at_pt(const srcT *src_im, vcl_ptrdiff_t s_istep,
   }
 
   long n=ni*nj*np;
-  mean/=n;
-  accumT var = sum_sq/n - mean*mean;
+  mean/=(accumT)n;
+  accumT var = sum_sq/(accumT)n - mean*mean;
   return var<=0 ? 0 : sum/vcl_sqrt(var);
 }
 
