@@ -45,6 +45,13 @@ static void read_long_tag(TIFF* tif, ttag_t tag, ulong_tag& utag, vxl_uint_32 de
     utag.val = deflt;
 }
 
+static void read_float_tag(TIFF* tif, ttag_t tag, float& val, bool& valid, float deflt = 0)
+{
+  valid = TIFFGetField(tif, tag, &(val))>0;
+  if (!valid)
+    val = deflt;
+}
+
 #if 0 // unused static function
 //assumes array is resized properly
 static bool read_long_array(TIFF* tif, ttag_t tag,
@@ -72,6 +79,14 @@ static void write_long_tag(TIFF* tif, ttag_t tag, ulong_tag const& ultag)
     TIFFSetField(tif, tag, ultag.val);
 }
 
+#if 0 // not currently used...
+static void write_float_tag(TIFF* tif, ttag_t tag, float const val, bool const valid)
+{
+  if (valid)
+    TIFFSetField(tif, tag, val);
+}
+#endif
+
 static void write_string(TIFF* tif, ttag_t tag, vcl_string const& stag)
 {
   TIFFSetField(tif, tag, stag.c_str());
@@ -133,8 +148,10 @@ bool vil_tiff_header::read_header()
   // EXTRASAMPLES tag requires two input arguments, which is different
   // from other 16bit values.
   vxl_uint_16* sample_info=0;
-  TIFFGetField(tif_, TIFFTAG_EXTRASAMPLES, &extra_samples.val, &sample_info);
-  if (extra_samples.val > 0)
+  extra_samples.val=0;
+  extra_samples.valid = false;
+  int const ret_extrasamples = TIFFGetField(tif_, TIFFTAG_EXTRASAMPLES, &extra_samples.val, &sample_info);
+  if (ret_extrasamples && extra_samples.val > 0)
     extra_samples.valid = true;
 
   read_short_tag(tif_,TIFFTAG_FILLORDER, fill_order);
@@ -156,7 +173,7 @@ bool vil_tiff_header::read_header()
   read_string(tif_,TIFFTAG_SOFTWARE, software);
   read_short_tag(tif_,TIFFTAG_SAMPLEFORMAT, sample_format, 1);
   strip_byte_counts_valid = false;
-  if (rows_per_strip.valid&&samples_per_pixel.valid)
+  if (rows_per_strip.valid)
   {
     strip_byte_counts_valid =
       TIFFGetField(tif_,TIFFTAG_STRIPBYTECOUNTS , &strip_byte_counts)>0;
@@ -170,7 +187,7 @@ bool vil_tiff_header::read_header()
 
   strip_offsets_valid = false;
 #ifdef DEBUG
-  if (rows_per_strip.valid&&samples_per_pixel.valid)
+  if (rows_per_strip.valid)
   {
     strip_offsets_valid =
       TIFFGetField(tif_, TIFFTAG_STRIPOFFSETS, &strip_offsets)>0;
@@ -181,28 +198,17 @@ bool vil_tiff_header::read_header()
   }
 #endif
   read_short_tag(tif_,TIFFTAG_THRESHHOLDING, thresholding);
-  vxl_uint_32 xneu, xden, yneu, yden;
-  x_resolution_valid = false;
-  x_resolution = 0;
-  if (TIFFGetField(tif_,TIFFTAG_XRESOLUTION, &xneu, &xden))
-  {
-    x_resolution = static_cast<double>(xneu)/static_cast<double>(xden);
-    x_resolution_valid = true;
-  }
-  y_resolution_valid = false;
-  y_resolution = 0;
-  if (TIFFGetField(tif_,TIFFTAG_XRESOLUTION, &yneu, &yden))
-  {
-    y_resolution = static_cast<double>(yneu)/static_cast<double>(yden);
-    y_resolution_valid = true;
-  }
+
+  read_float_tag(tif_, TIFFTAG_XRESOLUTION, x_resolution, x_resolution_valid);
+  read_float_tag(tif_, TIFFTAG_YRESOLUTION, y_resolution, y_resolution_valid);
+
   read_long_tag(tif_, TIFFTAG_TILEWIDTH, tile_width, 0);
   read_long_tag(tif_, TIFFTAG_TILELENGTH, tile_length, 0);
 
   tile_offsets_valid = false;
 
 #ifdef DEBUG
-  if (tile_width.valid&&tile_length.valid&&samples_per_pixel.valid)
+  if (tile_width.valid&&tile_length.valid)
   {
     tile_offsets_valid =
       TIFFGetField(tif_, TIFFTAG_TILEOFFSETS, &tile_offsets)>0;
@@ -215,7 +221,7 @@ bool vil_tiff_header::read_header()
 
   tile_byte_counts_valid = false;
 #ifdef DEBUG
-  if (tile_width.valid&&tile_length.valid&&samples_per_pixel.valid)
+  if (tile_width.valid&&tile_length.valid)
   {
     tile_byte_counts_valid =
      TIFFGetField(tif_, TIFFTAG_TILEBYTECOUNTS, &tile_byte_counts)>0;
@@ -233,7 +239,7 @@ bool vil_tiff_header::read_header()
 // for example a multi-band image.
 unsigned vil_tiff_header::n_separate_image_planes() const
 {
-  if (planar_config.valid&&samples_per_pixel.valid)
+  if (planar_config.valid)
   {
     if (planar_config.val == PLANARCONFIG_SEPARATE)
       return samples_per_pixel.val;
@@ -281,7 +287,7 @@ unsigned vil_tiff_header::encoded_bytes_per_block() const
 // the number of samples in a scan line
 unsigned vil_tiff_header::samples_per_line() const
 {
-  if (samples_per_pixel.valid&&image_width.valid)
+  if (image_width.valid)
     return samples_per_pixel.val*image_width.val;
   return 0;
 }
@@ -345,7 +351,8 @@ vxl_uint_16  vil_tiff_header::n_images()
 bool vil_tiff_header::compute_pixel_format()
 {
   //also need sample_format.valid but use default (1) for images that don't have it
-  if (!(bits_per_sample.valid) || !(samples_per_pixel.valid) ||
+  // -GY- use default (1) for images that do not have SamplesPerPixel tag
+  if (!(bits_per_sample.valid) || /*!(samples_per_pixel.valid) ||*/
       !(planar_config.valid) || !photometric.valid           )
   {
     pix_fmt = VIL_PIXEL_FORMAT_UNKNOWN;
@@ -361,36 +368,15 @@ bool vil_tiff_header::compute_pixel_format()
     //handle sample formats (unsigned, signed, float, double)
     switch (sample_format.val)
     {
-      case 1: //unsigned values
-        if (b==1){
-          pix_fmt = VIL_PIXEL_FORMAT_BOOL;
-          return true;}
-        else
-          switch (bbs)
-          {
-           case 1:
-            pix_fmt = VIL_PIXEL_FORMAT_BYTE;
-            return true;
-           case 2:
-            pix_fmt = VIL_PIXEL_FORMAT_UINT_16;
-            return true;
-           case 3:
-           case 4:
-            pix_fmt = VIL_PIXEL_FORMAT_UINT_32;
-            return true;
-           default:
-            pix_fmt = VIL_PIXEL_FORMAT_UNKNOWN;
-            return true;
-          }
       case 2: //2s complement signed
         switch (b)
         {
           case 8:
             pix_fmt = VIL_PIXEL_FORMAT_SBYTE;
-            return false;
+            return true;
           case 16:
             pix_fmt = VIL_PIXEL_FORMAT_INT_16;
-            return false;
+            return true;
           case 32:
             pix_fmt = VIL_PIXEL_FORMAT_INT_32;
             return false;
@@ -412,9 +398,28 @@ bool vil_tiff_header::compute_pixel_format()
             return false;
         }
       case 4: //undefined format
+      case 1: //unsigned values
       default:
-        pix_fmt = VIL_PIXEL_FORMAT_UNKNOWN;
-        return false;
+        if (b==1){
+          pix_fmt = VIL_PIXEL_FORMAT_BOOL;
+          return true;}
+        else
+          switch (bbs)
+          {
+           case 1:
+            pix_fmt = VIL_PIXEL_FORMAT_BYTE;
+            return true;
+           case 2:
+            pix_fmt = VIL_PIXEL_FORMAT_UINT_16;
+            return true;
+           case 3:
+           case 4:
+            pix_fmt = VIL_PIXEL_FORMAT_UINT_32;
+            return true;
+           default:
+            pix_fmt = VIL_PIXEL_FORMAT_UNKNOWN;
+            return true;
+          }
     }
   }
 
@@ -632,6 +637,7 @@ bool vil_tiff_header::set_header(unsigned ni, unsigned nj, unsigned nplns,
   switch ( nplanes )
   {
     case 1:
+    case 2:
       photometric.val = 1;
       break;
     case 3:
@@ -692,12 +698,14 @@ vil_tiff_header(TIFF* tif, const unsigned ni, const unsigned nj,
   write_short_tag(tif_,TIFFTAG_SAMPLEFORMAT, sample_format);
   write_long_tag(tif_, TIFFTAG_TILEWIDTH, tile_width);
   write_long_tag(tif_, TIFFTAG_TILELENGTH, tile_length);
-#if 0  //may not be needed to handle four planes, seems to work ok without it
-  if (nplanes == 4)
+#if 1  // Handle Alpha channel, assuming it is the last channel
+  if (nplanes == 2 || nplanes == 4)
   {
-    extra_samples.val = 1;
-    extra_samples.valid = true;
-    write_short_tag(tif_,TIFFTAG_EXTRASAMPLES, extra_samples);
+    //extra_samples.val = 1;
+    //extra_samples.valid = true;
+    vxl_uint_32 num_extra_samples = 1;
+    vxl_uint_16 extra_sample_values[] = { EXTRASAMPLE_ASSOCALPHA/*1*/ };  // Indicate Associated Alpha Data
+    TIFFSetField(tif_, TIFFTAG_EXTRASAMPLES, num_extra_samples, extra_sample_values);
   }
 #endif
   //initialize other flags to false
