@@ -71,6 +71,16 @@ inline void vsl_b_read(vsl_b_istream &is, vil_image_view<T>& image)
       }
       vsl_b_read(is, offset);
       const T* data = reinterpret_cast<const T*>(chunk->data());
+
+      if (chunk->size() < np*ni*nj*sizeof(T) ||
+          offset < 0 || offset*sizeof(T) >= chunk->size())
+      {
+        vcl_cerr << "I/O ERROR: vsl_b_read(vsl_b_istream&, vil_image_view<T>&)\n"
+                 << "           Image details not compatible with chunk data.\n";
+        is.is().clear(vcl_ios::badbit); // Set an unrecoverable IO error on stream
+        return;
+      }
+
       image = vil_image_view<T>(chunk,data+offset,
                                 ni,nj,np,istep,jstep,pstep);
     }
@@ -80,7 +90,7 @@ inline void vsl_b_read(vsl_b_istream &is, vil_image_view<T>& image)
     vcl_cerr << "I/O ERROR: vsl_b_read(vsl_b_istream&, vil_image_view<T>&)\n"
              << "           Unknown version number "<< w << '\n';
     is.is().clear(vcl_ios::badbit); // Set an unrecoverable IO error on stream
-    return;
+    break;
   }
 }
 
