@@ -15,7 +15,7 @@ static vcl_ios_openmode modeflags(char const* mode)
     return vcl_ios_openmode(0);
 
   if (*mode == 'r') {
-    if (mode[1] == '+')
+    if (mode[1] == '+' || mode[1] == 'w')
       return vcl_ios_in | vcl_ios_out | modeflags(mode+2);
     else
       return vcl_ios_in | modeflags(mode+1);
@@ -25,7 +25,7 @@ static vcl_ios_openmode modeflags(char const* mode)
     if (mode[1] == '+')
       return vcl_ios_in | vcl_ios_out | vcl_ios_trunc | modeflags(mode+2);
     else
-      return vcl_ios_out | modeflags(mode+1);
+      return vcl_ios_out | vcl_ios_trunc | modeflags(mode+1);
   }
 
   vcl_cerr << vcl_endl << __FILE__ ": DODGY MODE " << mode << vcl_endl;
@@ -84,7 +84,7 @@ vil_streampos vil_stream_fstream::write(void const* buf, vil_streampos n)
 #endif
 
   if (!(flags_ & vcl_ios_out)) {
-    vcl_cerr << "vil_stream_fstream: write failed, not an vcl_ostream\n";
+    vcl_cerr << "vil_stream_fstream: write failed, not a vcl_ostream\n";
     return 0;
   }
 
