@@ -1,6 +1,7 @@
 #include <testlib/testlib_register.h>
 
 DECLARE( test_bignum );
+DECLARE( test_decnum );
 DECLARE( test_complex );
 DECLARE( test_inverse );
 DECLARE( test_diag_matrix );
@@ -19,6 +20,7 @@ DECLARE( test_numeric_traits );
 DECLARE( test_power );
 DECLARE( test_quaternion );
 DECLARE( test_rational );
+DECLARE( test_polynomial );
 DECLARE( test_real_polynomial );
 DECLARE( test_real_npolynomial );
 DECLARE( test_resize );
@@ -39,11 +41,14 @@ DECLARE( test_bessel );
 DECLARE( test_crs_index );
 DECLARE( test_sparse_lst_sqr_function );
 DECLARE( test_sparse_matrix );
+DECLARE( test_pow_log );
+DECLARE( test_vnl_index_sort );
 
 void
 register_tests()
 {
   REGISTER( test_bignum );
+  REGISTER( test_decnum );
   REGISTER( test_complex );
   REGISTER( test_inverse );
   REGISTER( test_diag_matrix );
@@ -61,6 +66,7 @@ register_tests()
   REGISTER( test_power );
   REGISTER( test_quaternion );
   REGISTER( test_rational );
+  REGISTER( test_polynomial );
   REGISTER( test_real_polynomial );
   REGISTER( test_real_npolynomial );
   REGISTER( test_resize );
@@ -81,6 +87,8 @@ register_tests()
   REGISTER( test_crs_index );
   REGISTER( test_sparse_lst_sqr_function );
   REGISTER( test_sparse_matrix );
+  REGISTER( test_pow_log );
+  REGISTER( test_vnl_index_sort );
 }
 
 DEFINE_MAIN;
