@@ -7,6 +7,31 @@
 //:
 // \file
 // \brief An ordinary mathematical matrix
+// \verbatim
+//  Modifications
+//   Apr 21, 1989 - MBN - Initial design and implementation
+//   Jun 22, 1989 - MBN - Removed non-destructive methods
+//   Aug 09, 1989 - LGO - Inherit from Generic
+//   Aug 20, 1989 - MBN - Changed template usage to reflect new syntax
+//   Sep 11, 1989 - MBN - Added conditional exception handling and base class
+//   Oct 05, 1989 - LGO - Don't re-allocate data in operator= when same size
+//   Oct 19, 1989 - LGO - Add extra parameter to varargs constructor
+//   Oct 19, 1989 - MBN - Added optional argument to set_compare method
+//   Dec 08, 1989 - LGO - Allocate column data in one chunk
+//   Dec 08, 1989 - LGO - Clean-up get and put, add const everywhere.
+//   Dec 19, 1989 - LGO - Remove the map and reduce methods
+//   Feb 22, 1990 - MBN - Changed size arguments from int to unsigned int
+//   Jun 30, 1990 - MJF - Added base class name to constructor initializer
+//   Feb 21, 1992 - VDN - New lite version
+//   May 05, 1992 - VDN - Use envelope to avoid unnecessary copying
+//   Sep 30, 1992 - VDN - Matrix inversion with singular value decomposition
+//   Aug 21, 1996 - AWF - set_identity, normalize_rows, scale_row.
+//   Sep 30, 1996 - AWF - set_row/column methods. Const-correct data_block().
+//   14 Feb 1997  - AWF - get_n_rows, get_n_columns.
+//   20 Mar 1997  - PVR - get_row, get_column.
+//   24-Oct-2010 - Peter Vanroose - mutators and filling methods now return *this
+//   18-Jan-2011 - Peter Vanroose - added methods set_diagonal() & get_diagonal()
+// \endverbatim
 
 #include <vcl_iosfwd.h>
 #include <vnl/vnl_tag.h>
@@ -96,7 +121,7 @@ class vnl_matrix
   // Complexity $O(1)$
   vnl_matrix(unsigned r, unsigned c);                           // r rows, c cols.
 
-  //: Construct a matrix of size r rows by c columns, and all emelemnts equal to v0
+  //: Construct a matrix of size r rows by c columns, and all elements equal to v0
   // Complexity $O(r.c)$
   vnl_matrix(unsigned r, unsigned c, T const& v0);              // r rows, c cols, value v0.
 
@@ -193,30 +218,66 @@ class vnl_matrix
   }
 
 
-// Filling and copying------------------------------------------------
+  // ----------------------- Filling and copying -----------------------
 
-  //: Set all elements of matrix to specified value.
-  // Complexity $O(r.c)$
-  void fill(T const&);
+  //: Sets all elements of matrix to specified value, and returns "*this".
+  //  Complexity $O(r.c)$
+  //  Returning "*this" allows "chaining" two or more operations:
+  //  e.g., to set a matrix to a column-normalized all-elements-equal matrix, say
+  //  \code
+  //     M.fill(1).normalize_columns();
+  //  \endcode
+  //  Returning "*this" also allows passing such a matrix as argument
+  //  to a function f, without having to name the constructed matrix:
+  //  \code
+  //     f(vnl_matrix<double>(5,5,1.0).normalize_columns());
+  //  \endcode
+  vnl_matrix& fill(T const&);
 
-  //: Set all diagonal elements of matrix to specified value.
-  // Complexity $O(\min(r,c))$
-  void fill_diagonal(T const&);
+  //: Sets all diagonal elements of matrix to specified value; returns "*this".
+  //  Complexity $O(\min(r,c))$
+  //  Returning "*this" allows "chaining" two or more operations:
+  //  e.g., to set a 3x3 matrix to [5 0 0][0 10 0][0 0 15], just say
+  //  \code
+  //     M.fill_diagonal(5).scale_row(1,2).scale_column(2,3);
+  //  \endcode
+  //  Returning "*this" also allows passing a diagonal-filled matrix as argument
+  //  to a function f, without having to name the constructed matrix:
+  //  \code
+  //     f(vnl_matrix<double>(3,3).fill_diagonal(5));
+  //  \endcode
+  vnl_matrix& fill_diagonal(T const&);
 
-  //: Fill (laminate) this matrix with the given data.
-  // We assume that p points to a contiguous rows*cols array, stored rowwise.
-  void copy_in(T const *);
+  //: Sets the diagonal elements of this matrix to the specified list of values.
+  //  Returning "*this" allows "chaining" two or more operations: see the
+  //  reasoning (and the examples) in the documentation for method
+  //  fill_diagonal().
+  vnl_matrix& set_diagonal(vnl_vector<T> const&);
 
-  //: Fill (laminate) this matrix with the given data.
+  //: Fills (laminates) this matrix with the given data, then returns it.
+  //  We assume that the argument points to a contiguous rows*cols array, stored rowwise.
+  //  No bounds checking on the array.
+  //  Returning "*this" allows "chaining" two or more operations:
+  //  e.g., to fill a square matrix column-wise, fill it rowwise then transpose:
+  //  \code
+  //     M.copy_in(array).inplace_transpose();
+  //  \endcode
+  //  Returning "*this" also allows passing a filled-in matrix as argument
+  //  to a function f, without having to name the constructed matrix:
+  //  \code
+  //     f(vnl_matrix<double>(3,3).copy_in(array));
+  //  \endcode
+  vnl_matrix& copy_in(T const *);
+
+  //: Fills (laminates) this matrix with the given data, then returns it.
   // A synonym for copy_in()
-  void set(T const *d) { copy_in(d); }
+  vnl_matrix& set(T const *d) { return copy_in(d); }
 
-  //: Fill the given array with this matrix.
-  // We assume that p points to a contiguous rows*cols array, stored rowwise.
+  //: Fills the given array with this matrix.
+  //  We assume that the argument points to a contiguous rows*cols array, stored rowwise.
   // No bounds checking on the array.
   void copy_out(T *) const;
 
-
   //: Set all elements to value v
   // Complexity $O(r.c)$
   vnl_matrix<T>& operator=(T const&v) { fill(v); return *this; }
@@ -225,7 +286,7 @@ class vnl_matrix
   // Complexity $O(\min(r,c))$
   vnl_matrix<T>& operator=(vnl_matrix<T> const&);
 
-// Arithmetic ----------------------------------------------------
+  // ----------------------- Arithmetic --------------------------------
   // note that these functions should not pass scalar as a const&.
   // Look what would happen to A /= A(0,0).
 
@@ -288,26 +349,26 @@ class vnl_matrix
   //: Set values of this matrix to those of M, starting at [top,left]
   vnl_matrix<T>& update(vnl_matrix<T> const&, unsigned top=0, unsigned left=0);
 
-  //: Set the elements of the i'th column to v[j]  (No bounds checking)
-  void set_column(unsigned i, T const * v);
+  //: Set the elements of the i'th column to v[i]  (No bounds checking)
+  vnl_matrix& set_column(unsigned i, T const * v);
 
-  //: Set the elements of the i'th column to value
-  void set_column(unsigned i, T value );
+  //: Set the elements of the i'th column to value, then return *this.
+  vnl_matrix& set_column(unsigned i, T value );
 
-  //: Set j-th column to v
-  void set_column(unsigned j, vnl_vector<T> const& v);
+  //: Set j-th column to v, then return *this.
+  vnl_matrix& set_column(unsigned j, vnl_vector<T> const& v);
 
-  //: Set columns to those in M, starting at starting_column
-  void set_columns(unsigned starting_column, vnl_matrix<T> const& M);
+  //: Set columns to those in M, starting at starting_column, then return *this.
+  vnl_matrix& set_columns(unsigned starting_column, vnl_matrix<T> const& M);
 
-  //: Set the elements of the i'th row to v[j]  (No bounds checking)
-  void set_row(unsigned i, T const * v);
+  //: Set the elements of the i'th row to v[i]  (No bounds checking)
+  vnl_matrix& set_row(unsigned i, T const * v);
 
-  //: Set the elements of the i'th row to value
-  void set_row(unsigned i, T value );
+  //: Set the elements of the i'th row to value, then return *this.
+  vnl_matrix& set_row(unsigned i, T value );
 
   //: Set the i-th row
-  void set_row(unsigned i, vnl_vector<T> const&);
+  vnl_matrix& set_row(unsigned i, vnl_vector<T> const&);
 
   //: Extract a sub-matrix of size r x c, starting at (top,left)
   //  Thus it contains elements  [top,top+r-1][left,left+c-1]
@@ -335,33 +396,92 @@ class vnl_matrix
   //: Get n columns beginning at colstart
   vnl_matrix<T> get_n_columns(unsigned colstart, unsigned n) const;
 
-  // mutators
+  //: Return a vector with the content of the (main) diagonal
+  vnl_vector<T> get_diagonal() const;
 
-  //: Set this matrix to an identity matrix
-  //  Abort if the matrix is not square
-  void set_identity();
+  // ==== mutators ====
 
-  //: Transpose this matrix efficiently
-  void inplace_transpose();
+  //: Sets this matrix to an identity matrix, then returns "*this".
+  //  Returning "*this" allows e.g. passing an identity matrix as argument to
+  //  a function f, without having to name the constructed matrix:
+  //  \code
+  //     f(vnl_matrix<double>(5,5).set_identity());
+  //  \endcode
+  //  Returning "*this" also allows "chaining" two or more operations:
+  //  e.g., to set a 3x3 matrix to [3 0 0][0 2 0][0 0 1], one could say
+  //  \code
+  //     M.set_identity().scale_row(0,3).scale_column(1,2);
+  //  \endcode
+  //  If the matrix is not square, anyhow set main diagonal to 1, the rest to 0.
+  vnl_matrix& set_identity();
 
-  //: Reverse order of rows.
-  void flipud();
-  //: Reverse order of columns.
-  void fliplr();
+  //: Transposes this matrix efficiently, and returns it.
+  //  Returning "*this" allows "chaining" two or more operations:
+  //  e.g., to fill a square matrix column-wise, fill it rowwise then transpose:
+  //  \code
+  //     M.copy_in(array).inplace_transpose();
+  //  \endcode
+  vnl_matrix& inplace_transpose();
 
-  //: Normalize each row so it is a unit vector
-  //  Zero rows are ignored
-  void normalize_rows();
+  //: Reverses the order of rows, and returns "*this".
+  //  Returning "*this" allows "chaining" two or more operations:
+  //  e.g., to flip both up-down and left-right, one could just say
+  //  \code
+  //     M.flipud().fliplr();
+  //  \endcode
+  vnl_matrix& flipud();
 
-  //: Normalize each column so it is a unit vector
-  //  Zero columns are ignored
-  void normalize_columns();
+  //: Reverses the order of columns, and returns "*this".
+  //  Returning "*this" allows "chaining" two or more operations:
+  //  e.g., to flip both up-down and left-right, one could just say
+  //  \code
+  //     M.flipud().fliplr();
+  //  \endcode
+  vnl_matrix& fliplr();
 
-  //: Scale elements in given row by a factor of T
-  void scale_row(unsigned row, T value);
+  //: Normalizes each row so it is a unit vector, and returns "*this".
+  //  Zero rows are not modified
+  //  Returning "*this" allows "chaining" two or more operations:
+  //  e.g., to set a matrix to a row-normalized all-elements-equal matrix, say
+  //  \code
+  //     M.fill(1).normalize_rows();
+  //  \endcode
+  //  Returning "*this" also allows passing such a matrix as argument
+  //  to a function f, without having to name the constructed matrix:
+  //  \code
+  //     f(vnl_matrix<double>(5,5,1.0).normalize_rows());
+  //  \endcode
+  vnl_matrix& normalize_rows();
 
-  //: Scale elements in given column by a factor of T
-  void scale_column(unsigned col, T value);
+  //: Normalizes each column so it is a unit vector, and returns "*this".
+  //  Zero columns are not modified
+  //  Returning "*this" allows "chaining" two or more operations:
+  //  e.g., to set a matrix to a column-normalized all-elements-equal matrix, say
+  //  \code
+  //     M.fill(1).normalize_columns();
+  //  \endcode
+  //  Returning "*this" also allows passing such a matrix as argument
+  //  to a function f, without having to name the constructed matrix:
+  //  \code
+  //     f(vnl_matrix<double>(5,5,1.0).normalize_columns());
+  //  \endcode
+  vnl_matrix& normalize_columns();
+
+  //: Scales elements in given row by a factor T, and returns "*this".
+  //  Returning "*this" allows "chaining" two or more operations:
+  //  e.g., to set a 3x3 matrix to [3 0 0][0 2 0][0 0 1], one could say
+  //  \code
+  //     M.set_identity().scale_row(0,3).scale_column(1,2);
+  //  \endcode
+  vnl_matrix& scale_row(unsigned row, T value);
+
+  //: Scales elements in given column by a factor T, and returns "*this".
+  //  Returning "*this" allows "chaining" two or more operations:
+  //  e.g., to set a 3x3 matrix to [3 0 0][0 2 0][0 0 1], one could say
+  //  \code
+  //     M.set_identity().scale_row(0,3).scale_column(1,2);
+  //  \endcode
+  vnl_matrix& scale_column(unsigned col, T value);
 
   //: Swap this matrix with that matrix
   void swap(vnl_matrix<T> & that);
@@ -431,6 +551,9 @@ class vnl_matrix
   //: Return true if all elements equal to zero, within given tolerance
   bool is_zero(double tol) const;
 
+  //:  Return true if all elements of both matrices are equal, within given tolerance
+  bool is_equal(vnl_matrix<T> const& rhs, double tol) const;
+
   //: Return true if finite
   bool is_finite() const;
 
