@@ -32,8 +32,8 @@ template <class T, unsigned int d>
 vnl_matrix_fixed<T,d,d> vnl_power(vnl_matrix_fixed<T,d,d> const& m, int n)
 {
   assert(n >= 0 || d <= 4); // to allow the use of vnl_inverse()
-  if (n == 0) {
-    vnl_matrix_fixed<T,d,d> r; r.set_identity(); return r; }
+  if (n == 0)
+    return vnl_matrix_fixed<T,d,d>().set_identity();
   else if (n == 1 || m.is_identity())
     return m;
   else if (n < 0)
@@ -60,18 +60,18 @@ vnl_matrix<T> vnl_power(vnl_matrix<T> const& m, int n)
 {
   assert(m.rows() == m.columns());
   assert(n >= 0 || m.rows() <= 4);
-  if (n == 0) {
-    vnl_matrix<T> r = m; r.set_identity(); return r; }
+  if (n == 0)
+    return vnl_matrix<T>(m.rows(),m.columns()).set_identity();
   else if (n == 1 || m.is_identity())
     return m;
   else if (n < 0 && m.rows() == 1)
-    return vnl_matrix<T>(vnl_power(vnl_matrix_fixed<T,1,1>(m),n));
+    return vnl_power(vnl_matrix_fixed<T,1,1>(m),n).as_ref();
   else if (n < 0 && m.rows() == 2)
-    return vnl_matrix<T>(vnl_power(vnl_matrix_fixed<T,2,2>(m),n));
+    return vnl_power(vnl_matrix_fixed<T,2,2>(m),n).as_ref();
   else if (n < 0 && m.rows() == 3)
-    return vnl_matrix<T>(vnl_power(vnl_matrix_fixed<T,3,3>(m),n));
+    return vnl_power(vnl_matrix_fixed<T,3,3>(m),n).as_ref();
   else if (n < 0 && m.rows() == 4)
-    return vnl_matrix<T>(vnl_power(vnl_matrix_fixed<T,4,4>(m),n));
+    return vnl_power(vnl_matrix_fixed<T,4,4>(m),n).as_ref();
   else {
     vnl_matrix<T> r = vnl_power(m, n/2);
     return n%2==0 ? r * r : r * r * m;
