@@ -56,7 +56,7 @@ void test_vlarge_block(void * block, vcl_size_t s, T scale)
 
   vcl_size_t errors=0;
   for (vcl_size_t i=0; i<n; ++i)
-    if (numbers[i] != static_cast<T>(vcl_numeric_limits<T>::max() - T(i)) )
+    if (numbers[i] != static_cast<T>(vcl_numeric_limits<T>::max() - T(i) * scale) )
       errors++;
 
   TEST_NEAR("No errors in stored numbers", static_cast<double>(errors), 0, 0);
@@ -147,6 +147,8 @@ void test_vlarge_block_io()
   test_vlarge_block(blocks.back(), s-1, (float) 0);
   test_vlarge_block(blocks.back(), s-1019, (float) 0);
   test_vlarge_block(blocks.back(), s, (double) 0);
+  test_vlarge_block(blocks.back(), s, (vxl_int_64) 0);
+
   free_blocks(blocks);
 }
 
