@@ -1,6 +1,6 @@
 // This is core/vul/tests/test_ios_state.cxx
 #include <vcl_iostream.h>
-// not used? #include <vcl_iomanip.h>
+#include <vcl_sstream.h>
 #include <testlib/testlib_test.h>
 #include <vul/vul_ios_state.h>
 
