@@ -6,7 +6,6 @@
 
 
 void test_sleep_timer()
-// vul_timer, vpl_sleep
 {
   vul_timer tic;
   vpl_sleep(1);
@@ -16,12 +15,4 @@ void test_sleep_timer()
   TEST_NEAR_REL("Sleep for between 0.4 and 2.5 seconds", t, 1.0, 0.6);
 }
 
-//TESTMAIN(test_sleep_timer);
-int test_sleep_timer(int, char*[])
-{
-  testlib_test_start("test_sleep_timer");
-
-  test_sleep_timer();
-
-  return testlib_test_summary();
-}
+TEST_MAIN(test_sleep_timer);
