@@ -79,6 +79,14 @@ void test_string()
   TEST("vul_string_to_bool(Not \"0\")", vul_string_to_bool("0"), false);
   TEST("vul_string_to_bool(Not \"onwibble\")", vul_string_to_bool("onwibble"), false);
 
+  int int_list_data[] = {1,2,10,21,24,-1,-3,-5,-7};
+  vcl_vector<int> int_list(int_list_data, int_list_data+9);
+  TEST("vul_string_to_int_list(\"1:2,10,21:3:25,-1:-2:-7\")",
+       vul_string_to_int_list("1:2,10,21:3:25,-1:-2:-7"), int_list);
+  TEST("vul_string_to_int_list(\"1:2,10, 21:3:25\")",
+       vul_string_to_int_list("1:2,10, 21:3:25").empty(), true);
+  TEST("vul_string_to_int_list(\"1:2,10,\")",
+       vul_string_to_int_list("1:2,10,").empty(), true);
 
   vpl_putenv("VUL_1=foo");
   vpl_putenv("VUL_2=bar");
@@ -116,6 +124,12 @@ void test_string()
     vul_string_replace( s, "hate", "love" );
     TEST( "vul_string_replace", s== "I love mices to pieces", true);
   }
+
+  {
+    vcl_string s("Too many \r\003\t\v\a\f\x05 control chars.\n");
+    TEST("vul_string_escape_dodgy_chars(\"Too many \\r\\003\\t\\v\\a\\f\\x05 control chars.\\n\")",
+         vul_string_escape_ctrl_chars(s), "Too many \\r\\x03\\t\\v\\a\\f\\x05 control chars.\n");
+  }
 }
 
 TEST_MAIN(test_string);
