@@ -28,6 +28,7 @@
 // \endverbatim
 
 #include <vcl_string.h>
+#include <vxl_config.h>
 
 //: Expand given path.
 vcl_string vul_expand_path/*cached*/(vcl_string path);
@@ -35,4 +36,14 @@ vcl_string vul_expand_path/*cached*/(vcl_string path);
 //: Expand given path.
 vcl_string vul_expand_path_uncached (vcl_string path);
 
+#if defined(VCL_WIN32) && VXL_USE_WIN_WCHAR_T
+
+//: Expand given path.
+std::wstring vul_expand_path/*cached*/(std::wstring path);
+
+//: Expand given path.
+std::wstring vul_expand_path_uncached (std::wstring path);
+
+#endif 
+
 #endif // vul_expand_path_h_
