@@ -128,7 +128,7 @@ vul_reg_exp::vul_reg_exp (vul_reg_exp const& rxp)
   int ind;
   this->progsize = rxp.progsize;      // Copy regular expression size
   this->program = new char[this->progsize]; // Allocate storage
-  for (ind=this->progsize; ind-- != 0;)   // Copy regular expresion
+  for (ind=this->progsize; ind-- != 0;)   // Copy regular expression
   this->program[ind] = rxp.program[ind];
   this->startp[0] = rxp.startp[0];      // Copy pointers into last
   this->endp[0] = rxp.endp[0];        // Successful "find" operation
@@ -240,7 +240,7 @@ bool vul_reg_exp::deep_equal (vul_reg_exp const& rxp) const
 // because of operator precedence.)  The operand of some types of node is
 // a literal string; for others, it is a node leading into a sub-FSM.  In
 // particular, the operand of a BRANCH node is the first node of the branch.
-// (NB this is *not* a tree structure:  the tail of the branch connects
+// (NB this is \e not a tree structure:  the tail of the branch connects
 // to the thing following the set of BRANCHes.)  The opcodes are:
 //
 
@@ -474,7 +474,7 @@ void vul_reg_exp::compile (char const* exp)
       for (; scan != NULL; scan = regnext(scan))
         if (OP(scan) == EXACTLY && vcl_strlen(OPERAND(scan)) >= len) {
           longest = OPERAND(scan);
-          len = vcl_strlen(OPERAND(scan));
+          len = (unsigned long)vcl_strlen(OPERAND(scan));
         }
       this->regmust = longest;
       this->regmlen = (int)len;
@@ -781,7 +781,7 @@ static char* regatom (int *flagp)
     register char   ender;
 
     regparse--;
-    len = vcl_strcspn(regparse, META);
+    len = (int)vcl_strcspn(regparse, META);
     if (len <= 0) {
       //RAISE Error, SYM(vul_reg_exp), SYM(Internal_Error),
       vcl_cout << "vul_reg_exp::compile(): Internal error.\n";
@@ -1075,7 +1075,7 @@ static int regmatch(const char* prog)
       // Inline the first character, for speed.
       if (*opnd != *reginput)
         return 0;
-      len = vcl_strlen(opnd);
+      len = (int)vcl_strlen(opnd);
       if (len > 1 && vcl_strncmp(opnd, reginput, len) != 0)
         return 0;
       reginput += len;
@@ -1219,7 +1219,7 @@ static int regrepeat(const char* p)
   switch (OP(p))
   {
    case ANY:
-    count = vcl_strlen(scan);
+    count = (int)vcl_strlen(scan);
     scan += count;
     break;
    case EXACTLY:
