@@ -10,6 +10,8 @@
 #include <vcl_algorithm.h>
 #include <vcl_sstream.h>
 #include <vcl_cmath.h>
+#include <vul/vul_reg_exp.h>
+#include <vul/vul_sprintf.h>
 
 #ifndef END_OF_STRING                           // If END_OF_STRING not defined
 #define END_OF_STRING (0)
@@ -110,7 +112,7 @@ char* vul_string_c_right_trim(char* str, const char* rem) // Trim suffix from st
 // Reverses the order of the characters in char*.
 char* vul_string_c_reverse(char* c)     // Reverse the order of characters
 {
-  int length = vcl_strlen(c);           // Number of characters in string
+  int length = (int)vcl_strlen(c);      // Number of characters in string
   char temp;
 
   for (int i = 0, j = length-1;         // Counting from front and rear
@@ -126,7 +128,7 @@ char* vul_string_c_reverse(char* c)     // Reverse the order of characters
 // Reverses the order of the characters in string
 vcl_string& vul_string_reverse(vcl_string& s)
 {
-  for (int i=0, j=vcl_strlen(s.c_str())-1; i<j; ++i,--j)
+  for (int i=0, j=(int)vcl_strlen(s.c_str())-1; i<j; ++i,--j)
   {
     char c = s[i]; s[i] = s[j]; s[j] = c;
   }
@@ -166,7 +168,8 @@ vcl_string& vul_string_capitalize(vcl_string& s)
     if ( !in_word && vcl_isalnum( *si ) ) {
       *si = (char)vcl_toupper( *si );
       in_word = true;
-    } else if ( in_word && !vcl_isalnum( *si ) ) {
+    }
+    else if ( in_word && !vcl_isalnum( *si ) ) {
       in_word = false;
     }
   }
@@ -177,7 +180,7 @@ vcl_string& vul_string_capitalize(vcl_string& s)
 // from the string sr, and returns the modified string sr.
 vcl_string& vul_string_trim(vcl_string& sr, const char* rem)
 {
-  int l = vcl_strlen(rem);
+  int l = (int)vcl_strlen(rem);
   for (;;) {
     vcl_string::size_type loc = sr.find(rem);
     if (loc == vcl_string::npos)
@@ -191,7 +194,7 @@ vcl_string& vul_string_trim(vcl_string& sr, const char* rem)
 // from the string sr, and returns the modified string sr.
 vcl_string& vul_string_left_trim(vcl_string& sr, const char* rem)
 {
-  int l = vcl_strlen(rem);
+  int l = (int)vcl_strlen(rem);
   if (vcl_strncmp(sr.c_str(), rem, l) == 0)
     sr.erase(0, l);
   return sr;
@@ -201,8 +204,8 @@ vcl_string& vul_string_left_trim(vcl_string& sr, const char* rem)
 // from the string sr, and returns the modified string sr.
 vcl_string& vul_string_right_trim(vcl_string& sr, const char* rem)
 {
-  int l = vcl_strlen(rem);
-  int lsr = sr.length();
+  int l = (int)vcl_strlen(rem);
+  int lsr = int(sr.length());
   if (vcl_strncmp(sr.c_str() + lsr - l, rem, l) == 0)
     sr.erase(lsr - l, l);
   return sr;
@@ -219,8 +222,7 @@ double vul_string_atof(vcl_string const& s)
 }
 
 
-
-//: Reads an double from a string, with k, kb, M, etc suffix.
+//: Reads a double from a string, with k, kb, M, etc suffix.
 // No space is allowed between the number and the suffix.
 // k=10^3, kb=2^10, M=10^6, Mb=2^20, G=10^9, Gb=2^30, T=10^12, Tb=2^40
 // If parse fails, return 0.0;
@@ -288,6 +290,86 @@ bool vul_string_to_bool(const vcl_string &str)
      ||  myequals(begin, end, son, son+2);
 }
 
+
+//: Convert a string to a list of ints, using the matlab index format.
+// e.g. "0,1,10:14,20:-2:10" results in 0,1,10,11,12,13,14,20,18,16,14,12,10
+// No spaces are allowed.
+// \return empty on error.
+vcl_vector<int> vul_string_to_int_list(vcl_string str)
+{
+  vcl_vector<int> rv;
+
+
+#define REGEXP_INTEGER "\\-?[0123456789]+"
+
+  vul_reg_exp range_regexp("(" REGEXP_INTEGER ")"      // int
+                           "([:-]" REGEXP_INTEGER ")?" // :int [optional]
+                           "([:-]" REGEXP_INTEGER ")?" // :int [optional]
+                          );
+
+
+  while (str.length() > 0 && range_regexp.find(str)) {
+    // the start/end positions (ref from 0) of the
+    //    current ',' separated token.
+    vcl_ptrdiff_t start= range_regexp.start(0);
+    vcl_ptrdiff_t endp = range_regexp.end(0);
+    if (start != 0)
+    {
+      rv.clear();
+      return rv;
+    }
+
+
+    vcl_string match1 = range_regexp.match(1);
+    vcl_string match2 = range_regexp.match(2);
+    vcl_string match3 = range_regexp.match(3);
+
+
+    // Remove this match from the front of string.
+    str.erase(0, endp);
+    if (str.size() > 1 && str[0] == ',' ) str.erase(0, 1);
+
+    bool matched2 = range_regexp.match(2).size() > 0;
+    bool matched3 = range_regexp.match(3).size() > 0;
+
+    int s = vul_string_atoi(match1);
+    int d = 1;
+    int e = s;
+    if (matched3) {
+      // "1:2:10"
+      d = vul_string_atoi(match2.substr(1));
+      e = vul_string_atoi(match3.substr(1));
+    }
+    else if (matched2)
+      e = vul_string_atoi(match2.substr(1));
+
+    if (d==0)
+    {
+      rv.clear();
+      return rv;
+    }
+
+    if (e >= s)
+    {
+      if (d < 0) d = -d;
+      for (int i = s; i <= e; i += d)
+        rv.push_back(i);
+    }
+    else
+    {
+      if (d > 0) d = -d;
+      for (int i = s; i >= e; i += d)
+        rv.push_back(i);
+    }
+  }
+
+  if (!str.empty())
+    rv.clear();
+
+  return rv;
+}
+
+
 //Leave verbatim in to avoid $->LaTeX munging.
 
 //: Expand any environment variables in the string.
@@ -404,7 +486,7 @@ bool vul_string_replace(vcl_string& full_str,
   bool rep=false;
   for (int i = 0; i<num_times; i++)
   {
-    int loc = full_str.find( find_str,0);
+    int loc = int(full_str.find( find_str,0));
     if (loc >= 0)
     {
       full_str.replace( loc, find_str.length(), replace_str );
@@ -417,3 +499,34 @@ bool vul_string_replace(vcl_string& full_str,
   }
   return rep;
 }
+
+
+//: Replace control chars with escaped representations.
+// Space and "\n" are preserved, but tabs, CR, etc are escaped.
+// This is not aimed and is not suitable for any particular input-validation
+// security problem, such as sql-injection.
+vcl_string vul_string_escape_ctrl_chars(const vcl_string &in)
+{
+  vcl_string out;
+
+  const static vcl_string special("\t\v\b\r\f\a\\");
+  const static vcl_string special_tr("tvbrfa\\");
+
+  for (vcl_string::const_iterator it=in.begin(), end=in.end(); it!=end; ++it)
+  {
+    if (!vcl_iscntrl(*it) || *it=='\n')
+      out+=*it;
+    else
+    {
+      vcl_string::size_type i=special.find(*it);
+      if (i==vcl_string::npos)
+        out+=vul_sprintf("\\x%02x",static_cast<int>(*it));
+      else
+      {
+        out+='\\';
+        out+=special_tr[i];
+      }
+    }
+  }
+  return out;
+}
