@@ -6,6 +6,7 @@
 // \brief Utility functions for C strings and vcl_strings
 
 #include <vcl_string.h>
+#include <vcl_vector.h>
 
 // C string functions:
 
@@ -46,10 +47,10 @@ extern vcl_string& vul_string_reverse(vcl_string&);
 //: Reads an integer from a string
 extern int vul_string_atoi(vcl_string const&);
 
-//: Reads an double from a string
+//: Reads a double from a string
 extern double vul_string_atof(vcl_string const& s);
 
-//: Reads an double from a string, with k, kb, M, etc suffix.
+//: Reads a double from a string, with k, kb, M, etc suffix.
 // No space is allowed between the number and the suffix.
 // k=10^3, ki=2^10, M=10^6, Mi=2^20, G=10^9, Gi=2^30, T=10^12, Ti=2^40
 // The i suffix is from the IEC 60027 standard.
@@ -60,6 +61,9 @@ extern double vul_string_atof_withsuffix(vcl_string const& s);
 // It ignores leading and trailing whitespace and capitalisation.
 extern bool vul_string_to_bool(const vcl_string &str);
 
+//: Convert a string to a list of ints.
+extern vcl_vector<int> vul_string_to_int_list(vcl_string str);
+
 //: Expand any environment variables in the string.
 // \verbatim
 // Expands "foo$VARfoo" to "foobarfoo" when $VAR=bar. If
@@ -80,4 +84,11 @@ extern bool vul_string_replace( vcl_string& full_str,
                                 const vcl_string& replace_str,
                                 int num_times=1000);
 
+//: Replace control chars with escaped representations.
+// Space and \n are preserved, but tabs, CR, etc are escaped.
+// This is not aimed and is not suitable for any particular input-validation
+// security problem, such as sql-injection.
+vcl_string vul_string_escape_ctrl_chars(const vcl_string &in);
+
+
 #endif // vul_string_h
