@@ -200,6 +200,10 @@
 # define VCL_KAI
 #endif
 
+#if defined(__CYGWIN__) // Cygwin GCC Compiler
+# define VCL_CYGWIN_GCC
+#endif
+
 #if defined(__ICC) ||defined(__ECC) // Intel compiler?
 # define VCL_ICC
 #  if __ICC >= 800
@@ -336,4 +340,12 @@ typedef int saw_VCL_FOR_SCOPE_HACK;
    typedef void (safe_bool_dummy::* safe_bool)()
 #endif
 
+//----------------------------------------------------------------------------
+// Check if the compiler (claims to) support C++11.
+#if __cplusplus > 199711L
+# define VXL_CXX11 1
+#else
+# define VXL_CXX11 0
+#endif
+
 #endif // vcl_compiler_h_
